<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'Kuss: Erwuessenen, Erwuessenen, hell Hautfaarf, mëttelhell Hautfaarf',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'Kuss: Erwuessenen, Erwuessenen, hell Hautfaarf, mëttel Hautfaarf',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'Kuss: Erwuessenen, Erwuessenen, hell Hautfaarf, mëtteldäischter Hautfaarf',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'Kuss: Erwuessenen, Erwuessenen, hell Hautfaarf, däischter Hautfaarf',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'Kuss: Erwuessenen, Erwuessenen, mëttelhell Hautfaarf, hell Hautfaarf',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'Kuss: Erwuessenen, Erwuessenen, mëttelhell Hautfaarf, mëttel Hautfaarf',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'Kuss: Erwuessenen, Erwuessenen, mëttelhell Hautfaarf, mëtteldäischter Hautfaarf',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'Kuss: Erwuessenen, Erwuessenen, mëttelhell Hautfaarf, däischter Hautfaarf',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'Kuss: Erwuessenen, Erwuessenen, mëttel Hautfaarf, hell Hautfaarf',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'Kuss: Erwuessenen, Erwuessenen, mëttel Hautfaarf, mëttelhell Hautfaarf',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'Kuss: Erwuessenen, Erwuessenen, mëttel Hautfaarf, mëtteldäischter Hautfaarf',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'Kuss: Erwuessenen, Erwuessenen, mëttel Hautfaarf, däischter Hautfaarf',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'Kuss: Erwuessenen, Erwuessenen, mëtteldäischter Hautfaarf, hell Hautfaarf',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'Kuss: Erwuessenen, Erwuessenen, mëtteldäischter Hautfaarf, mëttelhell Hautfaarf',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'Kuss: Erwuessenen, Erwuessenen, mëtteldäischter Hautfaarf, mëttel Hautfaarf',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'Kuss: Erwuessenen, Erwuessenen, mëtteldäischter Hautfaarf, däischter Hautfaarf',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'Kuss: Erwuessenen, Erwuessenen, däischter Hautfaarf, hell Hautfaarf',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'Kuss: Erwuessenen, Erwuessenen, däischter Hautfaarf, mëttelhell Hautfaarf',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'Kuss: Erwuessenen, Erwuessenen, däischter Hautfaarf, mëttel Hautfaarf',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'Kuss: Erwuessenen, Erwuessenen, däischter Hautfaarf, mëtteldäischter Hautfaarf',
    '👨🏻‍❤‍💋‍👨🏻' => 'Kuss: Mann, Mann, hell Hautfaarf',
    '👨🏻‍❤‍💋‍👨🏼' => 'Kuss: Mann, Mann, hell Hautfaarf, mëttelhell Hautfaarf',
    '👨🏻‍❤‍💋‍👨🏽' => 'Kuss: Mann, Mann, hell Hautfaarf, mëttel Hautfaarf',
    '👨🏻‍❤‍💋‍👨🏾' => 'Kuss: Mann, Mann, hell Hautfaarf, mëtteldäischter Hautfaarf',
    '👨🏻‍❤‍💋‍👨🏿' => 'Kuss: Mann, Mann, hell Hautfaarf, däischter Hautfaarf',
    '👨🏼‍❤‍💋‍👨🏻' => 'Kuss: Mann, Mann, mëttelhell Hautfaarf, hell Hautfaarf',
    '👨🏼‍❤‍💋‍👨🏼' => 'Kuss: Mann, Mann, mëttelhell Hautfaarf',
    '👨🏼‍❤‍💋‍👨🏽' => 'Kuss: Mann, Mann, mëttelhell Hautfaarf, mëttel Hautfaarf',
    '👨🏼‍❤‍💋‍👨🏾' => 'Kuss: Mann, Mann, mëttelhell Hautfaarf, mëtteldäischter Hautfaarf',
    '👨🏼‍❤‍💋‍👨🏿' => 'Kuss: Mann, Mann, mëttelhell Hautfaarf, däischter Hautfaarf',
    '👨🏽‍❤‍💋‍👨🏻' => 'Kuss: Mann, Mann, mëttel Hautfaarf, hell Hautfaarf',
    '👨🏽‍❤‍💋‍👨🏼' => 'Kuss: Mann, Mann, mëttel Hautfaarf, mëttelhell Hautfaarf',
    '👨🏽‍❤‍💋‍👨🏽' => 'Kuss: Mann, Mann, mëttel Hautfaarf',
    '👨🏽‍❤‍💋‍👨🏾' => 'Kuss: Mann, Mann, mëttel Hautfaarf, mëtteldäischter Hautfaarf',
    '👨🏽‍❤‍💋‍👨🏿' => 'Kuss: Mann, Mann, mëttel Hautfaarf, däischter Hautfaarf',
    '👨🏾‍❤‍💋‍👨🏻' => 'Kuss: Mann, Mann, mëtteldäischter Hautfaarf, hell Hautfaarf',
    '👨🏾‍❤‍💋‍👨🏼' => 'Kuss: Mann, Mann, mëtteldäischter Hautfaarf, mëttelhell Hautfaarf',
    '👨🏾‍❤‍💋‍👨🏽' => 'Kuss: Mann, Mann, mëtteldäischter Hautfaarf, mëttel Hautfaarf',
    '👨🏾‍❤‍💋‍👨🏾' => 'Kuss: Mann, Mann, mëtteldäischter Hautfaarf',
    '👨🏾‍❤‍💋‍👨🏿' => 'Kuss: Mann, Mann, mëtteldäischter Hautfaarf, däischter Hautfaarf',
    '👨🏿‍❤‍💋‍👨🏻' => 'Kuss: Mann, Mann, däischter Hautfaarf, hell Hautfaarf',
    '👨🏿‍❤‍💋‍👨🏼' => 'Kuss: Mann, Mann, däischter Hautfaarf, mëttelhell Hautfaarf',
    '👨🏿‍❤‍💋‍👨🏽' => 'Kuss: Mann, Mann, däischter Hautfaarf, mëttel Hautfaarf',
    '👨🏿‍❤‍💋‍👨🏾' => 'Kuss: Mann, Mann, däischter Hautfaarf, mëtteldäischter Hautfaarf',
    '👨🏿‍❤‍💋‍👨🏿' => 'Kuss: Mann, Mann, däischter Hautfaarf',
    '👩🏻‍❤‍💋‍👨🏻' => 'Kuss: Fra, Mann, hell Hautfaarf',
    '👩🏻‍❤‍💋‍👨🏼' => 'Kuss: Fra, Mann, hell Hautfaarf, mëttelhell Hautfaarf',
    '👩🏻‍❤‍💋‍👨🏽' => 'Kuss: Fra, Mann, hell Hautfaarf, mëttel Hautfaarf',
    '👩🏻‍❤‍💋‍👨🏾' => 'Kuss: Fra, Mann, hell Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏻‍❤‍💋‍👨🏿' => 'Kuss: Fra, Mann, hell Hautfaarf, däischter Hautfaarf',
    '👩🏼‍❤‍💋‍👨🏻' => 'Kuss: Fra, Mann, mëttelhell Hautfaarf, hell Hautfaarf',
    '👩🏼‍❤‍💋‍👨🏼' => 'Kuss: Fra, Mann, mëttelhell Hautfaarf',
    '👩🏼‍❤‍💋‍👨🏽' => 'Kuss: Fra, Mann, mëttelhell Hautfaarf, mëttel Hautfaarf',
    '👩🏼‍❤‍💋‍👨🏾' => 'Kuss: Fra, Mann, mëttelhell Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏼‍❤‍💋‍👨🏿' => 'Kuss: Fra, Mann, mëttelhell Hautfaarf, däischter Hautfaarf',
    '👩🏽‍❤‍💋‍👨🏻' => 'Kuss: Fra, Mann, mëttel Hautfaarf, hell Hautfaarf',
    '👩🏽‍❤‍💋‍👨🏼' => 'Kuss: Fra, Mann, mëttel Hautfaarf, mëttelhell Hautfaarf',
    '👩🏽‍❤‍💋‍👨🏽' => 'Kuss: Fra, Mann, mëttel Hautfaarf',
    '👩🏽‍❤‍💋‍👨🏾' => 'Kuss: Fra, Mann, mëttel Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏽‍❤‍💋‍👨🏿' => 'Kuss: Fra, Mann, mëttel Hautfaarf, däischter Hautfaarf',
    '👩🏾‍❤‍💋‍👨🏻' => 'Kuss: Fra, Mann, mëtteldäischter Hautfaarf, hell Hautfaarf',
    '👩🏾‍❤‍💋‍👨🏼' => 'Kuss: Fra, Mann, mëtteldäischter Hautfaarf, mëttelhell Hautfaarf',
    '👩🏾‍❤‍💋‍👨🏽' => 'Kuss: Fra, Mann, mëtteldäischter Hautfaarf, mëttel Hautfaarf',
    '👩🏾‍❤‍💋‍👨🏾' => 'Kuss: Fra, Mann, mëtteldäischter Hautfaarf',
    '👩🏾‍❤‍💋‍👨🏿' => 'Kuss: Fra, Mann, mëtteldäischter Hautfaarf, däischter Hautfaarf',
    '👩🏿‍❤‍💋‍👨🏻' => 'Kuss: Fra, Mann, däischter Hautfaarf, hell Hautfaarf',
    '👩🏿‍❤‍💋‍👨🏼' => 'Kuss: Fra, Mann, däischter Hautfaarf, mëttelhell Hautfaarf',
    '👩🏿‍❤‍💋‍👨🏽' => 'Kuss: Fra, Mann, däischter Hautfaarf, mëttel Hautfaarf',
    '👩🏿‍❤‍💋‍👨🏾' => 'Kuss: Fra, Mann, däischter Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏿‍❤‍💋‍👨🏿' => 'Kuss: Fra, Mann, däischter Hautfaarf',
    '👩🏻‍❤‍💋‍👩🏻' => 'Kuss: Fra, Fra, hell Hautfaarf',
    '👩🏻‍❤‍💋‍👩🏼' => 'Kuss: Fra, Fra, hell Hautfaarf, mëttelhell Hautfaarf',
    '👩🏻‍❤‍💋‍👩🏽' => 'Kuss: Fra, Fra, hell Hautfaarf, mëttel Hautfaarf',
    '👩🏻‍❤‍💋‍👩🏾' => 'Kuss: Fra, Fra, hell Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏻‍❤‍💋‍👩🏿' => 'Kuss: Fra, Fra, hell Hautfaarf, däischter Hautfaarf',
    '👩🏼‍❤‍💋‍👩🏻' => 'Kuss: Fra, Fra, mëttelhell Hautfaarf, hell Hautfaarf',
    '👩🏼‍❤‍💋‍👩🏼' => 'Kuss: Fra, Fra, mëttelhell Hautfaarf',
    '👩🏼‍❤‍💋‍👩🏽' => 'Kuss: Fra, Fra, mëttelhell Hautfaarf, mëttel Hautfaarf',
    '👩🏼‍❤‍💋‍👩🏾' => 'Kuss: Fra, Fra, mëttelhell Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏼‍❤‍💋‍👩🏿' => 'Kuss: Fra, Fra, mëttelhell Hautfaarf, däischter Hautfaarf',
    '👩🏽‍❤‍💋‍👩🏻' => 'Kuss: Fra, Fra, mëttel Hautfaarf, hell Hautfaarf',
    '👩🏽‍❤‍💋‍👩🏼' => 'Kuss: Fra, Fra, mëttel Hautfaarf, mëttelhell Hautfaarf',
    '👩🏽‍❤‍💋‍👩🏽' => 'Kuss: Fra, Fra, mëttel Hautfaarf',
    '👩🏽‍❤‍💋‍👩🏾' => 'Kuss: Fra, Fra, mëttel Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏽‍❤‍💋‍👩🏿' => 'Kuss: Fra, Fra, mëttel Hautfaarf, däischter Hautfaarf',
    '👩🏾‍❤‍💋‍👩🏻' => 'Kuss: Fra, Fra, mëtteldäischter Hautfaarf, hell Hautfaarf',
    '👩🏾‍❤‍💋‍👩🏼' => 'Kuss: Fra, Fra, mëtteldäischter Hautfaarf, mëttelhell Hautfaarf',
    '👩🏾‍❤‍💋‍👩🏽' => 'Kuss: Fra, Fra, mëtteldäischter Hautfaarf, mëttel Hautfaarf',
    '👩🏾‍❤‍💋‍👩🏾' => 'Kuss: Fra, Fra, mëtteldäischter Hautfaarf',
    '👩🏾‍❤‍💋‍👩🏿' => 'Kuss: Fra, Fra, mëtteldäischter Hautfaarf, däischter Hautfaarf',
    '👩🏿‍❤‍💋‍👩🏻' => 'Kuss: Fra, Fra, däischter Hautfaarf, hell Hautfaarf',
    '👩🏿‍❤‍💋‍👩🏼' => 'Kuss: Fra, Fra, däischter Hautfaarf, mëttelhell Hautfaarf',
    '👩🏿‍❤‍💋‍👩🏽' => 'Kuss: Fra, Fra, däischter Hautfaarf, mëttel Hautfaarf',
    '👩🏿‍❤‍💋‍👩🏾' => 'Kuss: Fra, Fra, däischter Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏿‍❤‍💋‍👩🏿' => 'Kuss: Fra, Fra, däischter Hautfaarf',
    '🧑🏻‍🫯‍🧑🏼' => 'Wrestling: hell Hautfaarf, mëttelhell Hautfaarf',
    '🧑🏻‍🫯‍🧑🏽' => 'Wrestling: hell Hautfaarf, mëttel Hautfaarf',
    '🧑🏻‍🫯‍🧑🏾' => 'Wrestling: hell Hautfaarf, mëtteldäischter Hautfaarf',
    '🧑🏻‍🫯‍🧑🏿' => 'Wrestling: hell Hautfaarf, däischter Hautfaarf',
    '🧑🏼‍🫯‍🧑🏻' => 'Wrestling: mëttelhell Hautfaarf, hell Hautfaarf',
    '🧑🏼‍🫯‍🧑🏽' => 'Wrestling: mëttelhell Hautfaarf, mëttel Hautfaarf',
    '🧑🏼‍🫯‍🧑🏾' => 'Wrestling: mëttelhell Hautfaarf, mëtteldäischter Hautfaarf',
    '🧑🏼‍🫯‍🧑🏿' => 'Wrestling: mëttelhell Hautfaarf, däischter Hautfaarf',
    '🧑🏽‍🫯‍🧑🏻' => 'Wrestling: mëttel Hautfaarf, hell Hautfaarf',
    '🧑🏽‍🫯‍🧑🏼' => 'Wrestling: mëttel Hautfaarf, mëttelhell Hautfaarf',
    '🧑🏽‍🫯‍🧑🏾' => 'Wrestling: mëttel Hautfaarf, mëtteldäischter Hautfaarf',
    '🧑🏽‍🫯‍🧑🏿' => 'Wrestling: mëttel Hautfaarf, däischter Hautfaarf',
    '🧑🏾‍🫯‍🧑🏻' => 'Wrestling: mëtteldäischter Hautfaarf, hell Hautfaarf',
    '🧑🏾‍🫯‍🧑🏼' => 'Wrestling: mëtteldäischter Hautfaarf, mëttelhell Hautfaarf',
    '🧑🏾‍🫯‍🧑🏽' => 'Wrestling: mëtteldäischter Hautfaarf, mëttel Hautfaarf',
    '🧑🏾‍🫯‍🧑🏿' => 'Wrestling: mëtteldäischter Hautfaarf, däischter Hautfaarf',
    '🧑🏿‍🫯‍🧑🏻' => 'Wrestling: däischter Hautfaarf, hell Hautfaarf',
    '🧑🏿‍🫯‍🧑🏼' => 'Wrestling: däischter Hautfaarf, mëttelhell Hautfaarf',
    '🧑🏿‍🫯‍🧑🏽' => 'Wrestling: däischter Hautfaarf, mëttel Hautfaarf',
    '🧑🏿‍🫯‍🧑🏾' => 'Wrestling: däischter Hautfaarf, mëtteldäischter Hautfaarf',
    '🧑🏻‍❤‍🧑🏼' => 'verléift Koppel: Erwuessenen, Erwuessenen, hell Hautfaarf, mëttelhell Hautfaarf',
    '🧑🏻‍❤‍🧑🏽' => 'verléift Koppel: Erwuessenen, Erwuessenen, hell Hautfaarf, mëttel Hautfaarf',
    '🧑🏻‍❤‍🧑🏾' => 'verléift Koppel: Erwuessenen, Erwuessenen, hell Hautfaarf, mëtteldäischter Hautfaarf',
    '🧑🏻‍❤‍🧑🏿' => 'verléift Koppel: Erwuessenen, Erwuessenen, hell Hautfaarf, däischter Hautfaarf',
    '🧑🏼‍❤‍🧑🏻' => 'verléift Koppel: Erwuessenen, Erwuessenen, mëttelhell Hautfaarf, hell Hautfaarf',
    '🧑🏼‍❤‍🧑🏽' => 'verléift Koppel: Erwuessenen, Erwuessenen, mëttelhell Hautfaarf, mëttel Hautfaarf',
    '🧑🏼‍❤‍🧑🏾' => 'verléift Koppel: Erwuessenen, Erwuessenen, mëttelhell Hautfaarf, mëtteldäischter Hautfaarf',
    '🧑🏼‍❤‍🧑🏿' => 'verléift Koppel: Erwuessenen, Erwuessenen, mëttelhell Hautfaarf, däischter Hautfaarf',
    '🧑🏽‍❤‍🧑🏻' => 'verléift Koppel: Erwuessenen, Erwuessenen, mëttel Hautfaarf, hell Hautfaarf',
    '🧑🏽‍❤‍🧑🏼' => 'verléift Koppel: Erwuessenen, Erwuessenen, mëttel Hautfaarf, mëttelhell Hautfaarf',
    '🧑🏽‍❤‍🧑🏾' => 'verléift Koppel: Erwuessenen, Erwuessenen, mëttel Hautfaarf, mëtteldäischter Hautfaarf',
    '🧑🏽‍❤‍🧑🏿' => 'verléift Koppel: Erwuessenen, Erwuessenen, mëttel Hautfaarf, däischter Hautfaarf',
    '🧑🏾‍❤‍🧑🏻' => 'verléift Koppel: Erwuessenen, Erwuessenen, mëtteldäischter Hautfaarf, hell Hautfaarf',
    '🧑🏾‍❤‍🧑🏼' => 'verléift Koppel: Erwuessenen, Erwuessenen, mëtteldäischter Hautfaarf, mëttelhell Hautfaarf',
    '🧑🏾‍❤‍🧑🏽' => 'verléift Koppel: Erwuessenen, Erwuessenen, mëtteldäischter Hautfaarf, mëttel Hautfaarf',
    '🧑🏾‍❤‍🧑🏿' => 'verléift Koppel: Erwuessenen, Erwuessenen, mëtteldäischter Hautfaarf, däischter Hautfaarf',
    '🧑🏿‍❤‍🧑🏻' => 'verléift Koppel: Erwuessenen, Erwuessenen, däischter Hautfaarf, hell Hautfaarf',
    '🧑🏿‍❤‍🧑🏼' => 'verléift Koppel: Erwuessenen, Erwuessenen, däischter Hautfaarf, mëttelhell Hautfaarf',
    '🧑🏿‍❤‍🧑🏽' => 'verléift Koppel: Erwuessenen, Erwuessenen, däischter Hautfaarf, mëttel Hautfaarf',
    '🧑🏿‍❤‍🧑🏾' => 'verléift Koppel: Erwuessenen, Erwuessenen, däischter Hautfaarf, mëtteldäischter Hautfaarf',
    '🧑🏻‍🐰‍🧑🏼' => 'Persoun mat Huesoueren: hell Hautfaarf, mëttelhell Hautfaarf',
    '🧑🏻‍🐰‍🧑🏽' => 'Persoun mat Huesoueren: hell Hautfaarf, mëttel Hautfaarf',
    '🧑🏻‍🐰‍🧑🏾' => 'Persoun mat Huesoueren: hell Hautfaarf, mëtteldäischter Hautfaarf',
    '🧑🏻‍🐰‍🧑🏿' => 'Persoun mat Huesoueren: hell Hautfaarf, däischter Hautfaarf',
    '🧑🏼‍🐰‍🧑🏻' => 'Persoun mat Huesoueren: mëttelhell Hautfaarf, hell Hautfaarf',
    '🧑🏼‍🐰‍🧑🏽' => 'Persoun mat Huesoueren: mëttelhell Hautfaarf, mëttel Hautfaarf',
    '🧑🏼‍🐰‍🧑🏾' => 'Persoun mat Huesoueren: mëttelhell Hautfaarf, mëtteldäischter Hautfaarf',
    '🧑🏼‍🐰‍🧑🏿' => 'Persoun mat Huesoueren: mëttelhell Hautfaarf, däischter Hautfaarf',
    '🧑🏽‍🐰‍🧑🏻' => 'Persoun mat Huesoueren: mëttel Hautfaarf, hell Hautfaarf',
    '🧑🏽‍🐰‍🧑🏼' => 'Persoun mat Huesoueren: mëttel Hautfaarf, mëttelhell Hautfaarf',
    '🧑🏽‍🐰‍🧑🏾' => 'Persoun mat Huesoueren: mëttel Hautfaarf, mëtteldäischter Hautfaarf',
    '🧑🏽‍🐰‍🧑🏿' => 'Persoun mat Huesoueren: mëttel Hautfaarf, däischter Hautfaarf',
    '🧑🏾‍🐰‍🧑🏻' => 'Persoun mat Huesoueren: mëtteldäischter Hautfaarf, hell Hautfaarf',
    '🧑🏾‍🐰‍🧑🏼' => 'Persoun mat Huesoueren: mëtteldäischter Hautfaarf, mëttelhell Hautfaarf',
    '🧑🏾‍🐰‍🧑🏽' => 'Persoun mat Huesoueren: mëtteldäischter Hautfaarf, mëttel Hautfaarf',
    '🧑🏾‍🐰‍🧑🏿' => 'Persoun mat Huesoueren: mëtteldäischter Hautfaarf, däischter Hautfaarf',
    '🧑🏿‍🐰‍🧑🏻' => 'Persoun mat Huesoueren: däischter Hautfaarf, hell Hautfaarf',
    '🧑🏿‍🐰‍🧑🏼' => 'Persoun mat Huesoueren: däischter Hautfaarf, mëttelhell Hautfaarf',
    '🧑🏿‍🐰‍🧑🏽' => 'Persoun mat Huesoueren: däischter Hautfaarf, mëttel Hautfaarf',
    '🧑🏿‍🐰‍🧑🏾' => 'Persoun mat Huesoueren: däischter Hautfaarf, mëtteldäischter Hautfaarf',
    '👨🏻‍🫯‍👨🏼' => 'Wrestler: hell Hautfaarf, mëttelhell Hautfaarf',
    '👨🏻‍🫯‍👨🏽' => 'Wrestler: hell Hautfaarf, mëttel Hautfaarf',
    '👨🏻‍🫯‍👨🏾' => 'Wrestler: hell Hautfaarf, mëtteldäischter Hautfaarf',
    '👨🏻‍🫯‍👨🏿' => 'Wrestler: hell Hautfaarf, däischter Hautfaarf',
    '👨🏼‍🫯‍👨🏻' => 'Wrestler: mëttelhell Hautfaarf, hell Hautfaarf',
    '👨🏼‍🫯‍👨🏽' => 'Wrestler: mëttelhell Hautfaarf, mëttel Hautfaarf',
    '👨🏼‍🫯‍👨🏾' => 'Wrestler: mëttelhell Hautfaarf, mëtteldäischter Hautfaarf',
    '👨🏼‍🫯‍👨🏿' => 'Wrestler: mëttelhell Hautfaarf, däischter Hautfaarf',
    '👨🏽‍🫯‍👨🏻' => 'Wrestler: mëttel Hautfaarf, hell Hautfaarf',
    '👨🏽‍🫯‍👨🏼' => 'Wrestler: mëttel Hautfaarf, mëttelhell Hautfaarf',
    '👨🏽‍🫯‍👨🏾' => 'Wrestler: mëttel Hautfaarf, mëtteldäischter Hautfaarf',
    '👨🏽‍🫯‍👨🏿' => 'Wrestler: mëttel Hautfaarf, däischter Hautfaarf',
    '👨🏾‍🫯‍👨🏻' => 'Wrestler: mëtteldäischter Hautfaarf, hell Hautfaarf',
    '👨🏾‍🫯‍👨🏼' => 'Wrestler: mëtteldäischter Hautfaarf, mëttelhell Hautfaarf',
    '👨🏾‍🫯‍👨🏽' => 'Wrestler: mëtteldäischter Hautfaarf, mëttel Hautfaarf',
    '👨🏾‍🫯‍👨🏿' => 'Wrestler: mëtteldäischter Hautfaarf, däischter Hautfaarf',
    '👨🏿‍🫯‍👨🏻' => 'Wrestler: däischter Hautfaarf, hell Hautfaarf',
    '👨🏿‍🫯‍👨🏼' => 'Wrestler: däischter Hautfaarf, mëttelhell Hautfaarf',
    '👨🏿‍🫯‍👨🏽' => 'Wrestler: däischter Hautfaarf, mëttel Hautfaarf',
    '👨🏿‍🫯‍👨🏾' => 'Wrestler: däischter Hautfaarf, mëtteldäischter Hautfaarf',
    '👨🏻‍❤‍👨🏻' => 'verléift Koppel: Mann, Mann, hell Hautfaarf',
    '👨🏻‍❤‍👨🏼' => 'verléift Koppel: Mann, Mann, hell Hautfaarf, mëttelhell Hautfaarf',
    '👨🏻‍❤‍👨🏽' => 'verléift Koppel: Mann, Mann, hell Hautfaarf, mëttel Hautfaarf',
    '👨🏻‍❤‍👨🏾' => 'verléift Koppel: Mann, Mann, hell Hautfaarf, mëtteldäischter Hautfaarf',
    '👨🏻‍❤‍👨🏿' => 'verléift Koppel: Mann, Mann, hell Hautfaarf, däischter Hautfaarf',
    '👨🏼‍❤‍👨🏻' => 'verléift Koppel: Mann, Mann, mëttelhell Hautfaarf, hell Hautfaarf',
    '👨🏼‍❤‍👨🏼' => 'verléift Koppel: Mann, Mann, mëttelhell Hautfaarf',
    '👨🏼‍❤‍👨🏽' => 'verléift Koppel: Mann, Mann, mëttelhell Hautfaarf, mëttel Hautfaarf',
    '👨🏼‍❤‍👨🏾' => 'verléift Koppel: Mann, Mann, mëttelhell Hautfaarf, mëtteldäischter Hautfaarf',
    '👨🏼‍❤‍👨🏿' => 'verléift Koppel: Mann, Mann, mëttelhell Hautfaarf, däischter Hautfaarf',
    '👨🏽‍❤‍👨🏻' => 'verléift Koppel: Mann, Mann, mëttel Hautfaarf, hell Hautfaarf',
    '👨🏽‍❤‍👨🏼' => 'verléift Koppel: Mann, Mann, mëttel Hautfaarf, mëttelhell Hautfaarf',
    '👨🏽‍❤‍👨🏽' => 'verléift Koppel: Mann, Mann, mëttel Hautfaarf',
    '👨🏽‍❤‍👨🏾' => 'verléift Koppel: Mann, Mann, mëttel Hautfaarf, mëtteldäischter Hautfaarf',
    '👨🏽‍❤‍👨🏿' => 'verléift Koppel: Mann, Mann, mëttel Hautfaarf, däischter Hautfaarf',
    '👨🏾‍❤‍👨🏻' => 'verléift Koppel: Mann, Mann, mëtteldäischter Hautfaarf, hell Hautfaarf',
    '👨🏾‍❤‍👨🏼' => 'verléift Koppel: Mann, Mann, mëtteldäischter Hautfaarf, mëttelhell Hautfaarf',
    '👨🏾‍❤‍👨🏽' => 'verléift Koppel: Mann, Mann, mëtteldäischter Hautfaarf, mëttel Hautfaarf',
    '👨🏾‍❤‍👨🏾' => 'verléift Koppel: Mann, Mann, mëtteldäischter Hautfaarf',
    '👨🏾‍❤‍👨🏿' => 'verléift Koppel: Mann, Mann, mëtteldäischter Hautfaarf, däischter Hautfaarf',
    '👨🏿‍❤‍👨🏻' => 'verléift Koppel: Mann, Mann, däischter Hautfaarf, hell Hautfaarf',
    '👨🏿‍❤‍👨🏼' => 'verléift Koppel: Mann, Mann, däischter Hautfaarf, mëttelhell Hautfaarf',
    '👨🏿‍❤‍👨🏽' => 'verléift Koppel: Mann, Mann, däischter Hautfaarf, mëttel Hautfaarf',
    '👨🏿‍❤‍👨🏾' => 'verléift Koppel: Mann, Mann, däischter Hautfaarf, mëtteldäischter Hautfaarf',
    '👨🏿‍❤‍👨🏿' => 'verléift Koppel: Mann, Mann, däischter Hautfaarf',
    '👨🏻‍🐰‍👨🏼' => 'Männer mat Huesoueren: hell Hautfaarf, mëttelhell Hautfaarf',
    '👨🏻‍🐰‍👨🏽' => 'Männer mat Huesoueren: hell Hautfaarf, mëttel Hautfaarf',
    '👨🏻‍🐰‍👨🏾' => 'Männer mat Huesoueren: hell Hautfaarf, mëtteldäischter Hautfaarf',
    '👨🏻‍🐰‍👨🏿' => 'Männer mat Huesoueren: hell Hautfaarf, däischter Hautfaarf',
    '👨🏼‍🐰‍👨🏻' => 'Männer mat Huesoueren: mëttelhell Hautfaarf, hell Hautfaarf',
    '👨🏼‍🐰‍👨🏽' => 'Männer mat Huesoueren: mëttelhell Hautfaarf, mëttel Hautfaarf',
    '👨🏼‍🐰‍👨🏾' => 'Männer mat Huesoueren: mëttelhell Hautfaarf, mëtteldäischter Hautfaarf',
    '👨🏼‍🐰‍👨🏿' => 'Männer mat Huesoueren: mëttelhell Hautfaarf, däischter Hautfaarf',
    '👨🏽‍🐰‍👨🏻' => 'Männer mat Huesoueren: mëttel Hautfaarf, hell Hautfaarf',
    '👨🏽‍🐰‍👨🏼' => 'Männer mat Huesoueren: mëttel Hautfaarf, mëttelhell Hautfaarf',
    '👨🏽‍🐰‍👨🏾' => 'Männer mat Huesoueren: mëttel Hautfaarf, mëtteldäischter Hautfaarf',
    '👨🏽‍🐰‍👨🏿' => 'Männer mat Huesoueren: mëttel Hautfaarf, däischter Hautfaarf',
    '👨🏾‍🐰‍👨🏻' => 'Männer mat Huesoueren: mëtteldäischter Hautfaarf, hell Hautfaarf',
    '👨🏾‍🐰‍👨🏼' => 'Männer mat Huesoueren: mëtteldäischter Hautfaarf, mëttelhell Hautfaarf',
    '👨🏾‍🐰‍👨🏽' => 'Männer mat Huesoueren: mëtteldäischter Hautfaarf, mëttel Hautfaarf',
    '👨🏾‍🐰‍👨🏿' => 'Männer mat Huesoueren: mëtteldäischter Hautfaarf, däischter Hautfaarf',
    '👨🏿‍🐰‍👨🏻' => 'Männer mat Huesoueren: däischter Hautfaarf, hell Hautfaarf',
    '👨🏿‍🐰‍👨🏼' => 'Männer mat Huesoueren: däischter Hautfaarf, mëttelhell Hautfaarf',
    '👨🏿‍🐰‍👨🏽' => 'Männer mat Huesoueren: däischter Hautfaarf, mëttel Hautfaarf',
    '👨🏿‍🐰‍👨🏾' => 'Männer mat Huesoueren: däischter Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏻‍🫯‍👩🏼' => 'Wrestlerinnen: hell Hautfaarf, mëttelhell Hautfaarf',
    '👩🏻‍🫯‍👩🏽' => 'Wrestlerinnen: hell Hautfaarf, mëttel Hautfaarf',
    '👩🏻‍🫯‍👩🏾' => 'Wrestlerinnen: hell Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏻‍🫯‍👩🏿' => 'Wrestlerinnen: hell Hautfaarf, däischter Hautfaarf',
    '👩🏼‍🫯‍👩🏻' => 'Wrestlerinnen: mëttelhell Hautfaarf, hell Hautfaarf',
    '👩🏼‍🫯‍👩🏽' => 'Wrestlerinnen: mëttelhell Hautfaarf, mëttel Hautfaarf',
    '👩🏼‍🫯‍👩🏾' => 'Wrestlerinnen: mëttelhell Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏼‍🫯‍👩🏿' => 'Wrestlerinnen: mëttelhell Hautfaarf, däischter Hautfaarf',
    '👩🏽‍🫯‍👩🏻' => 'Wrestlerinnen: mëttel Hautfaarf, hell Hautfaarf',
    '👩🏽‍🫯‍👩🏼' => 'Wrestlerinnen: mëttel Hautfaarf, mëttelhell Hautfaarf',
    '👩🏽‍🫯‍👩🏾' => 'Wrestlerinnen: mëttel Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏽‍🫯‍👩🏿' => 'Wrestlerinnen: mëttel Hautfaarf, däischter Hautfaarf',
    '👩🏾‍🫯‍👩🏻' => 'Wrestlerinnen: mëtteldäischter Hautfaarf, hell Hautfaarf',
    '👩🏾‍🫯‍👩🏼' => 'Wrestlerinnen: mëtteldäischter Hautfaarf, mëttelhell Hautfaarf',
    '👩🏾‍🫯‍👩🏽' => 'Wrestlerinnen: mëtteldäischter Hautfaarf, mëttel Hautfaarf',
    '👩🏾‍🫯‍👩🏿' => 'Wrestlerinnen: mëtteldäischter Hautfaarf, däischter Hautfaarf',
    '👩🏿‍🫯‍👩🏻' => 'Wrestlerinnen: däischter Hautfaarf, hell Hautfaarf',
    '👩🏿‍🫯‍👩🏼' => 'Wrestlerinnen: däischter Hautfaarf, mëttelhell Hautfaarf',
    '👩🏿‍🫯‍👩🏽' => 'Wrestlerinnen: däischter Hautfaarf, mëttel Hautfaarf',
    '👩🏿‍🫯‍👩🏾' => 'Wrestlerinnen: däischter Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏻‍❤‍👨🏻' => 'verléift Koppel: Fra, Mann, hell Hautfaarf',
    '👩🏻‍❤‍👨🏼' => 'verléift Koppel: Fra, Mann, hell Hautfaarf, mëttelhell Hautfaarf',
    '👩🏻‍❤‍👨🏽' => 'verléift Koppel: Fra, Mann, hell Hautfaarf, mëttel Hautfaarf',
    '👩🏻‍❤‍👨🏾' => 'verléift Koppel: Fra, Mann, hell Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏻‍❤‍👨🏿' => 'verléift Koppel: Fra, Mann, hell Hautfaarf, däischter Hautfaarf',
    '👩🏼‍❤‍👨🏻' => 'verléift Koppel: Fra, Mann, mëttelhell Hautfaarf, hell Hautfaarf',
    '👩🏼‍❤‍👨🏼' => 'verléift Koppel: Fra, Mann, mëttelhell Hautfaarf',
    '👩🏼‍❤‍👨🏽' => 'verléift Koppel: Fra, Mann, mëttelhell Hautfaarf, mëttel Hautfaarf',
    '👩🏼‍❤‍👨🏾' => 'verléift Koppel: Fra, Mann, mëttelhell Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏼‍❤‍👨🏿' => 'verléift Koppel: Fra, Mann, mëttelhell Hautfaarf, däischter Hautfaarf',
    '👩🏽‍❤‍👨🏻' => 'verléift Koppel: Fra, Mann, mëttel Hautfaarf, hell Hautfaarf',
    '👩🏽‍❤‍👨🏼' => 'verléift Koppel: Fra, Mann, mëttel Hautfaarf, mëttelhell Hautfaarf',
    '👩🏽‍❤‍👨🏽' => 'verléift Koppel: Fra, Mann, mëttel Hautfaarf',
    '👩🏽‍❤‍👨🏾' => 'verléift Koppel: Fra, Mann, mëttel Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏽‍❤‍👨🏿' => 'verléift Koppel: Fra, Mann, mëttel Hautfaarf, däischter Hautfaarf',
    '👩🏾‍❤‍👨🏻' => 'verléift Koppel: Fra, Mann, mëtteldäischter Hautfaarf, hell Hautfaarf',
    '👩🏾‍❤‍👨🏼' => 'verléift Koppel: Fra, Mann, mëtteldäischter Hautfaarf, mëttelhell Hautfaarf',
    '👩🏾‍❤‍👨🏽' => 'verléift Koppel: Fra, Mann, mëtteldäischter Hautfaarf, mëttel Hautfaarf',
    '👩🏾‍❤‍👨🏾' => 'verléift Koppel: Fra, Mann, mëtteldäischter Hautfaarf',
    '👩🏾‍❤‍👨🏿' => 'verléift Koppel: Fra, Mann, mëtteldäischter Hautfaarf, däischter Hautfaarf',
    '👩🏿‍❤‍👨🏻' => 'verléift Koppel: Fra, Mann, däischter Hautfaarf, hell Hautfaarf',
    '👩🏿‍❤‍👨🏼' => 'verléift Koppel: Fra, Mann, däischter Hautfaarf, mëttelhell Hautfaarf',
    '👩🏿‍❤‍👨🏽' => 'verléift Koppel: Fra, Mann, däischter Hautfaarf, mëttel Hautfaarf',
    '👩🏿‍❤‍👨🏾' => 'verléift Koppel: Fra, Mann, däischter Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏿‍❤‍👨🏿' => 'verléift Koppel: Fra, Mann, däischter Hautfaarf',
    '👩🏻‍❤‍👩🏻' => 'verléift Koppel: Fra, Fra, hell Hautfaarf',
    '👩🏻‍❤‍👩🏼' => 'verléift Koppel: Fra, Fra, hell Hautfaarf, mëttelhell Hautfaarf',
    '👩🏻‍❤‍👩🏽' => 'verléift Koppel: Fra, Fra, hell Hautfaarf, mëttel Hautfaarf',
    '👩🏻‍❤‍👩🏾' => 'verléift Koppel: Fra, Fra, hell Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏻‍❤‍👩🏿' => 'verléift Koppel: Fra, Fra, hell Hautfaarf, däischter Hautfaarf',
    '👩🏼‍❤‍👩🏻' => 'verléift Koppel: Fra, Fra, mëttelhell Hautfaarf, hell Hautfaarf',
    '👩🏼‍❤‍👩🏼' => 'verléift Koppel: Fra, Fra, mëttelhell Hautfaarf',
    '👩🏼‍❤‍👩🏽' => 'verléift Koppel: Fra, Fra, mëttelhell Hautfaarf, mëttel Hautfaarf',
    '👩🏼‍❤‍👩🏾' => 'verléift Koppel: Fra, Fra, mëttelhell Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏼‍❤‍👩🏿' => 'verléift Koppel: Fra, Fra, mëttelhell Hautfaarf, däischter Hautfaarf',
    '👩🏽‍❤‍👩🏻' => 'verléift Koppel: Fra, Fra, mëttel Hautfaarf, hell Hautfaarf',
    '👩🏽‍❤‍👩🏼' => 'verléift Koppel: Fra, Fra, mëttel Hautfaarf, mëttelhell Hautfaarf',
    '👩🏽‍❤‍👩🏽' => 'verléift Koppel: Fra, Fra, mëttel Hautfaarf',
    '👩🏽‍❤‍👩🏾' => 'verléift Koppel: Fra, Fra, mëttel Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏽‍❤‍👩🏿' => 'verléift Koppel: Fra, Fra, mëttel Hautfaarf, däischter Hautfaarf',
    '👩🏾‍❤‍👩🏻' => 'verléift Koppel: Fra, Fra, mëtteldäischter Hautfaarf, hell Hautfaarf',
    '👩🏾‍❤‍👩🏼' => 'verléift Koppel: Fra, Fra, mëtteldäischter Hautfaarf, mëttelhell Hautfaarf',
    '👩🏾‍❤‍👩🏽' => 'verléift Koppel: Fra, Fra, mëtteldäischter Hautfaarf, mëttel Hautfaarf',
    '👩🏾‍❤‍👩🏾' => 'verléift Koppel: Fra, Fra, mëtteldäischter Hautfaarf',
    '👩🏾‍❤‍👩🏿' => 'verléift Koppel: Fra, Fra, mëtteldäischter Hautfaarf, däischter Hautfaarf',
    '👩🏿‍❤‍👩🏻' => 'verléift Koppel: Fra, Fra, däischter Hautfaarf, hell Hautfaarf',
    '👩🏿‍❤‍👩🏼' => 'verléift Koppel: Fra, Fra, däischter Hautfaarf, mëttelhell Hautfaarf',
    '👩🏿‍❤‍👩🏽' => 'verléift Koppel: Fra, Fra, däischter Hautfaarf, mëttel Hautfaarf',
    '👩🏿‍❤‍👩🏾' => 'verléift Koppel: Fra, Fra, däischter Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏿‍❤‍👩🏿' => 'verléift Koppel: Fra, Fra, däischter Hautfaarf',
    '👩🏻‍🐰‍👩🏼' => 'Frae mat Huesoueren: hell Hautfaarf, mëttelhell Hautfaarf',
    '👩🏻‍🐰‍👩🏽' => 'Frae mat Huesoueren: hell Hautfaarf, mëttel Hautfaarf',
    '👩🏻‍🐰‍👩🏾' => 'Frae mat Huesoueren: hell Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏻‍🐰‍👩🏿' => 'Frae mat Huesoueren: hell Hautfaarf, däischter Hautfaarf',
    '👩🏼‍🐰‍👩🏻' => 'Frae mat Huesoueren: mëttelhell Hautfaarf, hell Hautfaarf',
    '👩🏼‍🐰‍👩🏽' => 'Frae mat Huesoueren: mëttelhell Hautfaarf, mëttel Hautfaarf',
    '👩🏼‍🐰‍👩🏾' => 'Frae mat Huesoueren: mëttelhell Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏼‍🐰‍👩🏿' => 'Frae mat Huesoueren: mëttelhell Hautfaarf, däischter Hautfaarf',
    '👩🏽‍🐰‍👩🏻' => 'Frae mat Huesoueren: mëttel Hautfaarf, hell Hautfaarf',
    '👩🏽‍🐰‍👩🏼' => 'Frae mat Huesoueren: mëttel Hautfaarf, mëttelhell Hautfaarf',
    '👩🏽‍🐰‍👩🏾' => 'Frae mat Huesoueren: mëttel Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏽‍🐰‍👩🏿' => 'Frae mat Huesoueren: mëttel Hautfaarf, däischter Hautfaarf',
    '👩🏾‍🐰‍👩🏻' => 'Frae mat Huesoueren: mëtteldäischter Hautfaarf, hell Hautfaarf',
    '👩🏾‍🐰‍👩🏼' => 'Frae mat Huesoueren: mëtteldäischter Hautfaarf, mëttelhell Hautfaarf',
    '👩🏾‍🐰‍👩🏽' => 'Frae mat Huesoueren: mëtteldäischter Hautfaarf, mëttel Hautfaarf',
    '👩🏾‍🐰‍👩🏿' => 'Frae mat Huesoueren: mëtteldäischter Hautfaarf, däischter Hautfaarf',
    '👩🏿‍🐰‍👩🏻' => 'Frae mat Huesoueren: däischter Hautfaarf, hell Hautfaarf',
    '👩🏿‍🐰‍👩🏼' => 'Frae mat Huesoueren: däischter Hautfaarf, mëttelhell Hautfaarf',
    '👩🏿‍🐰‍👩🏽' => 'Frae mat Huesoueren: däischter Hautfaarf, mëttel Hautfaarf',
    '👩🏿‍🐰‍👩🏾' => 'Frae mat Huesoueren: däischter Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏻‍🤝‍👩🏼' => 'zwou Fraen Hand an Hand: hell Hautfaarf, mëttelhell Hautfaarf',
    '👩🏻‍🤝‍👩🏽' => 'zwou Fraen Hand an Hand: hell Hautfaarf, mëttel Hautfaarf',
    '👩🏻‍🤝‍👩🏾' => 'zwou Fraen Hand an Hand: hell Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏻‍🤝‍👩🏿' => 'zwou Fraen Hand an Hand: hell Hautfaarf, däischter Hautfaarf',
    '👩🏼‍🤝‍👩🏻' => 'zwou Fraen Hand an Hand: mëttelhell Hautfaarf, hell Hautfaarf',
    '👩🏼‍🤝‍👩🏽' => 'zwou Fraen Hand an Hand: mëttelhell Hautfaarf, mëttel Hautfaarf',
    '👩🏼‍🤝‍👩🏾' => 'zwou Fraen Hand an Hand: mëttelhell Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏼‍🤝‍👩🏿' => 'zwou Fraen Hand an Hand: mëttelhell Hautfaarf, däischter Hautfaarf',
    '👩🏽‍🤝‍👩🏻' => 'zwou Fraen Hand an Hand: mëttel Hautfaarf, hell Hautfaarf',
    '👩🏽‍🤝‍👩🏼' => 'zwou Fraen Hand an Hand: mëttel Hautfaarf, mëttelhell Hautfaarf',
    '👩🏽‍🤝‍👩🏾' => 'zwou Fraen Hand an Hand: mëttel Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏽‍🤝‍👩🏿' => 'zwou Fraen Hand an Hand: mëttel Hautfaarf, däischter Hautfaarf',
    '👩🏾‍🤝‍👩🏻' => 'zwou Fraen Hand an Hand: mëtteldäischter Hautfaarf, hell Hautfaarf',
    '👩🏾‍🤝‍👩🏼' => 'zwou Fraen Hand an Hand: mëtteldäischter Hautfaarf, mëttelhell Hautfaarf',
    '👩🏾‍🤝‍👩🏽' => 'zwou Fraen Hand an Hand: mëtteldäischter Hautfaarf, mëttel Hautfaarf',
    '👩🏾‍🤝‍👩🏿' => 'zwou Fraen Hand an Hand: mëtteldäischter Hautfaarf, däischter Hautfaarf',
    '👩🏿‍🤝‍👩🏻' => 'zwou Fraen Hand an Hand: däischter Hautfaarf, hell Hautfaarf',
    '👩🏿‍🤝‍👩🏼' => 'zwou Fraen Hand an Hand: däischter Hautfaarf, mëttelhell Hautfaarf',
    '👩🏿‍🤝‍👩🏽' => 'zwou Fraen Hand an Hand: däischter Hautfaarf, mëttel Hautfaarf',
    '👩🏿‍🤝‍👩🏾' => 'zwou Fraen Hand an Hand: däischter Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏻‍🤝‍👨🏼' => 'Mann a Fra Hand an Hand: hell Hautfaarf, mëttelhell Hautfaarf',
    '👩🏻‍🤝‍👨🏽' => 'Mann a Fra Hand an Hand: hell Hautfaarf, mëttel Hautfaarf',
    '👩🏻‍🤝‍👨🏾' => 'Mann a Fra Hand an Hand: hell Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏻‍🤝‍👨🏿' => 'Mann a Fra Hand an Hand: hell Hautfaarf, däischter Hautfaarf',
    '👩🏼‍🤝‍👨🏻' => 'Mann a Fra Hand an Hand: mëttelhell Hautfaarf, hell Hautfaarf',
    '👩🏼‍🤝‍👨🏽' => 'Mann a Fra Hand an Hand: mëttelhell Hautfaarf, mëttel Hautfaarf',
    '👩🏼‍🤝‍👨🏾' => 'Mann a Fra Hand an Hand: mëttelhell Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏼‍🤝‍👨🏿' => 'Mann a Fra Hand an Hand: mëttelhell Hautfaarf, däischter Hautfaarf',
    '👩🏽‍🤝‍👨🏻' => 'Mann a Fra Hand an Hand: mëttel Hautfaarf, hell Hautfaarf',
    '👩🏽‍🤝‍👨🏼' => 'Mann a Fra Hand an Hand: mëttel Hautfaarf, mëttelhell Hautfaarf',
    '👩🏽‍🤝‍👨🏾' => 'Mann a Fra Hand an Hand: mëttel Hautfaarf, mëtteldäischter Hautfaarf',
    '👩🏽‍🤝‍👨🏿' => 'Mann a Fra Hand an Hand: mëttel Hautfaarf, däischter Hautfaarf',
    '👩🏾‍🤝‍👨🏻' => 'Mann a Fra Hand an Hand: mëtteldäischter Hautfaarf, hell Hautfaarf',
    '👩🏾‍🤝‍👨🏼' => 'Mann a Fra Hand an Hand: mëtteldäischter Hautfaarf, mëttelhell Hautfaarf',
    '👩🏾‍🤝‍👨🏽' => 'Mann a Fra Hand an Hand: mëtteldäischter Hautfaarf, mëttel Hautfaarf',
    '👩🏾‍🤝‍👨🏿' => 'Mann a Fra Hand an Hand: mëtteldäischter Hautfaarf, däischter Hautfaarf',
    '👩🏿‍🤝‍👨🏻' => 'Mann a Fra Hand an Hand: däischter Hautfaarf, hell Hautfaarf',
    '👩🏿‍🤝‍👨🏼' => 'Mann a Fra Hand an Hand: däischter Hautfaarf, mëttelhell Hautfaarf',
    '👩🏿‍🤝‍👨🏽' => 'Mann a Fra Hand an Hand: däischter Hautfaarf, mëttel Hautfaarf',
    '👩🏿‍🤝‍👨🏾' => 'Mann a Fra Hand an Hand: däischter Hautfaarf, mëtteldäischter Hautfaarf',
    '👨🏻‍🤝‍👨🏼' => 'zwee Männer Hand an Hand: hell Hautfaarf, mëttelhell Hautfaarf',
    '👨🏻‍🤝‍👨🏽' => 'zwee Männer Hand an Hand: hell Hautfaarf, mëttel Hautfaarf',
    '👨🏻‍🤝‍👨🏾' => 'zwee Männer Hand an Hand: hell Hautfaarf, mëtteldäischter Hautfaarf',
    '👨🏻‍🤝‍👨🏿' => 'zwee Männer Hand an Hand: hell Hautfaarf, däischter Hautfaarf',
    '👨🏼‍🤝‍👨🏻' => 'zwee Männer Hand an Hand: mëttelhell Hautfaarf, hell Hautfaarf',
    '👨🏼‍🤝‍👨🏽' => 'zwee Männer Hand an Hand: mëttelhell Hautfaarf, mëttel Hautfaarf',
    '👨🏼‍🤝‍👨🏾' => 'zwee Männer Hand an Hand: mëttelhell Hautfaarf, mëtteldäischter Hautfaarf',
    '👨🏼‍🤝‍👨🏿' => 'zwee Männer Hand an Hand: mëttelhell Hautfaarf, däischter Hautfaarf',
    '👨🏽‍🤝‍👨🏻' => 'zwee Männer Hand an Hand: mëttel Hautfaarf, hell Hautfaarf',
    '👨🏽‍🤝‍👨🏼' => 'zwee Männer Hand an Hand: mëttel Hautfaarf, mëttelhell Hautfaarf',
    '👨🏽‍🤝‍👨🏾' => 'zwee Männer Hand an Hand: mëttel Hautfaarf, mëtteldäischter Hautfaarf',
    '👨🏽‍🤝‍👨🏿' => 'zwee Männer Hand an Hand: mëttel Hautfaarf, däischter Hautfaarf',
    '👨🏾‍🤝‍👨🏻' => 'zwee Männer Hand an Hand: mëtteldäischter Hautfaarf, hell Hautfaarf',
    '👨🏾‍🤝‍👨🏼' => 'zwee Männer Hand an Hand: mëtteldäischter Hautfaarf, mëttelhell Hautfaarf',
    '👨🏾‍🤝‍👨🏽' => 'zwee Männer Hand an Hand: mëtteldäischter Hautfaarf, mëttel Hautfaarf',
    '👨🏾‍🤝‍👨🏿' => 'zwee Männer Hand an Hand: mëtteldäischter Hautfaarf, däischter Hautfaarf',
    '👨🏿‍🤝‍👨🏻' => 'zwee Männer Hand an Hand: däischter Hautfaarf, hell Hautfaarf',
    '👨🏿‍🤝‍👨🏼' => 'zwee Männer Hand an Hand: däischter Hautfaarf, mëttelhell Hautfaarf',
    '👨🏿‍🤝‍👨🏽' => 'zwee Männer Hand an Hand: däischter Hautfaarf, mëttel Hautfaarf',
    '👨🏿‍🤝‍👨🏾' => 'zwee Männer Hand an Hand: däischter Hautfaarf, mëtteldäischter Hautfaarf',
    '👩‍❤‍💋‍👨' => 'Kuss: Fra, Mann',
    '👨‍❤‍💋‍👨' => 'Kuss: Mann, Mann',
    '👩‍❤‍💋‍👩' => 'Kuss: Fra, Fra',
    '👨‍👩‍👧‍👦' => 'Famill: Mann, Fra, Meedchen, Jong',
    '👨‍👩‍👦‍👦' => 'Famill: Mann, Fra, Jong, Jong',
    '👨‍👩‍👧‍👧' => 'Famill: Mann, Fra, Meedchen, Meedchen',
    '👨‍👨‍👧‍👦' => 'Famill: Mann, Mann, Meedchen, Jong',
    '👨‍👨‍👦‍👦' => 'Famill: Mann, Mann, Jong, Jong',
    '👨‍👨‍👧‍👧' => 'Famill: Mann, Mann, Meedchen, Meedchen',
    '👩‍👩‍👧‍👦' => 'Famill: Fra, Fra, Meedchen, Jong',
    '👩‍👩‍👦‍👦' => 'Famill: Fra, Fra, Jong, Jong',
    '👩‍👩‍👧‍👧' => 'Famill: Fra, Fra, Meedchen, Meedchen',
    '🫱🏻‍🫲🏼' => 'Handdrock: hell Hautfaarf, mëttelhell Hautfaarf',
    '🫱🏻‍🫲🏽' => 'Handdrock: hell Hautfaarf, mëttel Hautfaarf',
    '🫱🏻‍🫲🏾' => 'Handdrock: hell Hautfaarf, mëtteldäischter Hautfaarf',
    '🫱🏻‍🫲🏿' => 'Handdrock: hell Hautfaarf, däischter Hautfaarf',
    '🫱🏼‍🫲🏻' => 'Handdrock: mëttelhell Hautfaarf, hell Hautfaarf',
    '🫱🏼‍🫲🏽' => 'Handdrock: mëttelhell Hautfaarf, mëttel Hautfaarf',
    '🫱🏼‍🫲🏾' => 'Handdrock: mëttelhell Hautfaarf, mëtteldäischter Hautfaarf',
    '🫱🏼‍🫲🏿' => 'Handdrock: mëttelhell Hautfaarf, däischter Hautfaarf',
    '🫱🏽‍🫲🏻' => 'Handdrock: mëttel Hautfaarf, hell Hautfaarf',
    '🫱🏽‍🫲🏼' => 'Handdrock: mëttel Hautfaarf, mëttelhell Hautfaarf',
    '🫱🏽‍🫲🏾' => 'Handdrock: mëttel Hautfaarf, mëtteldäischter Hautfaarf',
    '🫱🏽‍🫲🏿' => 'Handdrock: mëttel Hautfaarf, däischter Hautfaarf',
    '🫱🏾‍🫲🏻' => 'Handdrock: mëtteldäischter Hautfaarf, hell Hautfaarf',
    '🫱🏾‍🫲🏼' => 'Handdrock: mëtteldäischter Hautfaarf, mëttelhell Hautfaarf',
    '🫱🏾‍🫲🏽' => 'Handdrock: mëtteldäischter Hautfaarf, mëttel Hautfaarf',
    '🫱🏾‍🫲🏿' => 'Handdrock: mëtteldäischter Hautfaarf, däischter Hautfaarf',
    '🫱🏿‍🫲🏻' => 'Handdrock: däischter Hautfaarf, hell Hautfaarf',
    '🫱🏿‍🫲🏼' => 'Handdrock: däischter Hautfaarf, mëttelhell Hautfaarf',
    '🫱🏿‍🫲🏽' => 'Handdrock: däischter Hautfaarf, mëttel Hautfaarf',
    '🫱🏿‍🫲🏾' => 'Handdrock: däischter Hautfaarf, mëtteldäischter Hautfaarf',
    '👩‍❤‍👨' => 'verléift Koppel: Fra, Mann',
    '👨‍❤‍👨' => 'verléift Koppel: Mann, Mann',
    '👩‍❤‍👩' => 'verléift Koppel: Fra, Fra',
    '👨‍👩‍👦' => 'Famill: Mann, Fra, Jong',
    '👨‍👩‍👧' => 'Famill: Mann, Fra, Meedchen',
    '👨‍👨‍👦' => 'Famill: Mann, Mann, Jong',
    '👨‍👨‍👧' => 'Famill: Mann, Mann, Meedchen',
    '👩‍👩‍👦' => 'Famill: Fra, Fra, Jong',
    '👩‍👩‍👧' => 'Famill: Fra, Fra, Meedchen',
    '👨‍👦‍👦' => 'Famill: Mann, Jong, Jong',
    '👨‍👧‍👦' => 'Famill: Mann, Meedchen, Jong',
    '👨‍👧‍👧' => 'Famill: Mann, Meedchen, Meedchen',
    '👩‍👦‍👦' => 'Famill: Fra, Jong, Jong',
    '👩‍👧‍👦' => 'Famill: Fra, Meedchen, Jong',
    '👩‍👧‍👧' => 'Famill: Fra, Meedchen, Meedchen',
    '👱🏻‍♂' => 'blonde Mann: hell Hautfaarf',
    '👱🏼‍♂' => 'blonde Mann: mëttelhell Hautfaarf',
    '👱🏽‍♂' => 'blonde Mann: mëttel Hautfaarf',
    '👱🏾‍♂' => 'blonde Mann: mëtteldäischter Hautfaarf',
    '👱🏿‍♂' => 'blonde Mann: däischter Hautfaarf',
    '👱🏻‍♀' => 'Blondin: hell Hautfaarf',
    '👱🏼‍♀' => 'Blondin: mëttelhell Hautfaarf',
    '👱🏽‍♀' => 'Blondin: mëttel Hautfaarf',
    '👱🏾‍♀' => 'Blondin: mëtteldäischter Hautfaarf',
    '👱🏿‍♀' => 'Blondin: däischter Hautfaarf',
    '🙍🏻‍♂' => 'd’Stir fronzende Mann: hell Hautfaarf',
    '🙍🏼‍♂' => 'd’Stir fronzende Mann: mëttelhell Hautfaarf',
    '🙍🏽‍♂' => 'd’Stir fronzende Mann: mëttel Hautfaarf',
    '🙍🏾‍♂' => 'd’Stir fronzende Mann: mëtteldäischter Hautfaarf',
    '🙍🏿‍♂' => 'd’Stir fronzende Mann: däischter Hautfaarf',
    '🙍🏻‍♀' => 'd’Stir fronzend Fra: hell Hautfaarf',
    '🙍🏼‍♀' => 'd’Stir fronzend Fra: mëttelhell Hautfaarf',
    '🙍🏽‍♀' => 'd’Stir fronzend Fra: mëttel Hautfaarf',
    '🙍🏾‍♀' => 'd’Stir fronzend Fra: mëtteldäischter Hautfaarf',
    '🙍🏿‍♀' => 'd’Stir fronzend Fra: däischter Hautfaarf',
    '🙎🏻‍♂' => 'motzende Mann: hell Hautfaarf',
    '🙎🏼‍♂' => 'motzende Mann: mëttelhell Hautfaarf',
    '🙎🏽‍♂' => 'motzende Mann: mëttel Hautfaarf',
    '🙎🏾‍♂' => 'motzende Mann: mëtteldäischter Hautfaarf',
    '🙎🏿‍♂' => 'motzende Mann: däischter Hautfaarf',
    '🙎🏻‍♀' => 'motzend Fra: hell Hautfaarf',
    '🙎🏼‍♀' => 'motzend Fra: mëttelhell Hautfaarf',
    '🙎🏽‍♀' => 'motzend Fra: mëttel Hautfaarf',
    '🙎🏾‍♀' => 'motzend Fra: mëtteldäischter Hautfaarf',
    '🙎🏿‍♀' => 'motzend Fra: däischter Hautfaarf',
    '🙅🏻‍♂' => 'Mann, deen NEEN weist: hell Hautfaarf',
    '🙅🏼‍♂' => 'Mann, deen NEEN weist: mëttelhell Hautfaarf',
    '🙅🏽‍♂' => 'Mann, deen NEEN weist: mëttel Hautfaarf',
    '🙅🏾‍♂' => 'Mann, deen NEEN weist: mëtteldäischter Hautfaarf',
    '🙅🏿‍♂' => 'Mann, deen NEEN weist: däischter Hautfaarf',
    '🙅🏻‍♀' => 'Fra, déi NEEN weist: hell Hautfaarf',
    '🙅🏼‍♀' => 'Fra, déi NEEN weist: mëttelhell Hautfaarf',
    '🙅🏽‍♀' => 'Fra, déi NEEN weist: mëttel Hautfaarf',
    '🙅🏾‍♀' => 'Fra, déi NEEN weist: mëtteldäischter Hautfaarf',
    '🙅🏿‍♀' => 'Fra, déi NEEN weist: däischter Hautfaarf',
    '🙆🏻‍♂' => 'Mann, deen OK weist: hell Hautfaarf',
    '🙆🏼‍♂' => 'Mann, deen OK weist: mëttelhell Hautfaarf',
    '🙆🏽‍♂' => 'Mann, deen OK weist: mëttel Hautfaarf',
    '🙆🏾‍♂' => 'Mann, deen OK weist: mëtteldäischter Hautfaarf',
    '🙆🏿‍♂' => 'Mann, deen OK weist: däischter Hautfaarf',
    '🙆🏻‍♀' => 'Fra, déi OK weist: hell Hautfaarf',
    '🙆🏼‍♀' => 'Fra, déi OK weist: mëttelhell Hautfaarf',
    '🙆🏽‍♀' => 'Fra, déi OK weist: mëttel Hautfaarf',
    '🙆🏾‍♀' => 'Fra, déi OK weist: mëtteldäischter Hautfaarf',
    '🙆🏿‍♀' => 'Fra, déi OK weist: däischter Hautfaarf',
    '💁🏻‍♂' => 'Mann, deen d’Hand op hält: hell Hautfaarf',
    '💁🏼‍♂' => 'Mann, deen d’Hand op hält: mëttelhell Hautfaarf',
    '💁🏽‍♂' => 'Mann, deen d’Hand op hält: mëttel Hautfaarf',
    '💁🏾‍♂' => 'Mann, deen d’Hand op hält: mëtteldäischter Hautfaarf',
    '💁🏿‍♂' => 'Mann, deen d’Hand op hält: däischter Hautfaarf',
    '💁🏻‍♀' => 'Fra, déi d’Hand op hält: hell Hautfaarf',
    '💁🏼‍♀' => 'Fra, déi d’Hand op hält: mëttelhell Hautfaarf',
    '💁🏽‍♀' => 'Fra, déi d’Hand op hält: mëttel Hautfaarf',
    '💁🏾‍♀' => 'Fra, déi d’Hand op hält: mëtteldäischter Hautfaarf',
    '💁🏿‍♀' => 'Fra, déi d’Hand op hält: däischter Hautfaarf',
    '🙋🏻‍♂' => 'Mann, deen d’Hand hieft: hell Hautfaarf',
    '🙋🏼‍♂' => 'Mann, deen d’Hand hieft: mëttelhell Hautfaarf',
    '🙋🏽‍♂' => 'Mann, deen d’Hand hieft: mëttel Hautfaarf',
    '🙋🏾‍♂' => 'Mann, deen d’Hand hieft: mëtteldäischter Hautfaarf',
    '🙋🏿‍♂' => 'Mann, deen d’Hand hieft: däischter Hautfaarf',
    '🙋🏻‍♀' => 'Fra, déi d’Hand hieft: hell Hautfaarf',
    '🙋🏼‍♀' => 'Fra, déi d’Hand hieft: mëttelhell Hautfaarf',
    '🙋🏽‍♀' => 'Fra, déi d’Hand hieft: mëttel Hautfaarf',
    '🙋🏾‍♀' => 'Fra, déi d’Hand hieft: mëtteldäischter Hautfaarf',
    '🙋🏿‍♀' => 'Fra, déi d’Hand hieft: däischter Hautfaarf',
    '🙇🏻‍♂' => 'sech vernäipende Mann: hell Hautfaarf',
    '🙇🏼‍♂' => 'sech vernäipende Mann: mëttelhell Hautfaarf',
    '🙇🏽‍♂' => 'sech vernäipende Mann: mëttel Hautfaarf',
    '🙇🏾‍♂' => 'sech vernäipende Mann: mëtteldäischter Hautfaarf',
    '🙇🏿‍♂' => 'sech vernäipende Mann: däischter Hautfaarf',
    '🙇🏻‍♀' => 'sech vernäipend Fra: hell Hautfaarf',
    '🙇🏼‍♀' => 'sech vernäipend Fra: mëttelhell Hautfaarf',
    '🙇🏽‍♀' => 'sech vernäipend Fra: mëttel Hautfaarf',
    '🙇🏾‍♀' => 'sech vernäipend Fra: mëtteldäischter Hautfaarf',
    '🙇🏿‍♀' => 'sech vernäipend Fra: däischter Hautfaarf',
    '🤦🏻‍♂' => 'Mann, deen sech d’Hand widder de Kapp schléit: hell Hautfaarf',
    '🤦🏼‍♂' => 'Mann, deen sech d’Hand widder de Kapp schléit: mëttelhell Hautfaarf',
    '🤦🏽‍♂' => 'Mann, deen sech d’Hand widder de Kapp schléit: mëttel Hautfaarf',
    '🤦🏾‍♂' => 'Mann, deen sech d’Hand widder de Kapp schléit: mëtteldäischter Hautfaarf',
    '🤦🏿‍♂' => 'Mann, deen sech d’Hand widder de Kapp schléit: däischter Hautfaarf',
    '🤦🏻‍♀' => 'Fra, déi sech d’Hand widder de Kapp schléit: hell Hautfaarf',
    '🤦🏼‍♀' => 'Fra, déi sech d’Hand widder de Kapp schléit: mëttelhell Hautfaarf',
    '🤦🏽‍♀' => 'Fra, déi sech d’Hand widder de Kapp schléit: mëttel Hautfaarf',
    '🤦🏾‍♀' => 'Fra, déi sech d’Hand widder de Kapp schléit: mëtteldäischter Hautfaarf',
    '🤦🏿‍♀' => 'Fra, déi sech d’Hand widder de Kapp schléit: däischter Hautfaarf',
    '🤷🏻‍♂' => 'Mann, deen d’Schëlleren hieft: hell Hautfaarf',
    '🤷🏼‍♂' => 'Mann, deen d’Schëlleren hieft: mëttelhell Hautfaarf',
    '🤷🏽‍♂' => 'Mann, deen d’Schëlleren hieft: mëttel Hautfaarf',
    '🤷🏾‍♂' => 'Mann, deen d’Schëlleren hieft: mëtteldäischter Hautfaarf',
    '🤷🏿‍♂' => 'Mann, deen d’Schëlleren hieft: däischter Hautfaarf',
    '🤷🏻‍♀' => 'Fra, déi d’Schëlleren hieft: hell Hautfaarf',
    '🤷🏼‍♀' => 'Fra, déi d’Schëlleren hieft: mëttelhell Hautfaarf',
    '🤷🏽‍♀' => 'Fra, déi d’Schëlleren hieft: mëttel Hautfaarf',
    '🤷🏾‍♀' => 'Fra, déi d’Schëlleren hieft: mëtteldäischter Hautfaarf',
    '🤷🏿‍♀' => 'Fra, déi d’Schëlleren hieft: däischter Hautfaarf',
    '👨🏻‍⚕' => 'Medeziner: hell Hautfaarf',
    '👨🏼‍⚕' => 'Medeziner: mëttelhell Hautfaarf',
    '👨🏽‍⚕' => 'Medeziner: mëttel Hautfaarf',
    '👨🏾‍⚕' => 'Medeziner: mëtteldäischter Hautfaarf',
    '👨🏿‍⚕' => 'Medeziner: däischter Hautfaarf',
    '👩🏻‍⚕' => 'Medezinerin: hell Hautfaarf',
    '👩🏼‍⚕' => 'Medezinerin: mëttelhell Hautfaarf',
    '👩🏽‍⚕' => 'Medezinerin: mëttel Hautfaarf',
    '👩🏾‍⚕' => 'Medezinerin: mëtteldäischter Hautfaarf',
    '👩🏿‍⚕' => 'Medezinerin: däischter Hautfaarf',
    '👨🏻‍🎓' => 'Student: hell Hautfaarf',
    '👨🏼‍🎓' => 'Student: mëttelhell Hautfaarf',
    '👨🏽‍🎓' => 'Student: mëttel Hautfaarf',
    '👨🏾‍🎓' => 'Student: mëtteldäischter Hautfaarf',
    '👨🏿‍🎓' => 'Student: däischter Hautfaarf',
    '👩🏻‍🎓' => 'Studentin: hell Hautfaarf',
    '👩🏼‍🎓' => 'Studentin: mëttelhell Hautfaarf',
    '👩🏽‍🎓' => 'Studentin: mëttel Hautfaarf',
    '👩🏾‍🎓' => 'Studentin: mëtteldäischter Hautfaarf',
    '👩🏿‍🎓' => 'Studentin: däischter Hautfaarf',
    '👨🏻‍🏫' => 'Enseignant: hell Hautfaarf',
    '👨🏼‍🏫' => 'Enseignant: mëttelhell Hautfaarf',
    '👨🏽‍🏫' => 'Enseignant: mëttel Hautfaarf',
    '👨🏾‍🏫' => 'Enseignant: mëtteldäischter Hautfaarf',
    '👨🏿‍🏫' => 'Enseignant: däischter Hautfaarf',
    '👩🏻‍🏫' => 'Enseignante: hell Hautfaarf',
    '👩🏼‍🏫' => 'Enseignante: mëttelhell Hautfaarf',
    '👩🏽‍🏫' => 'Enseignante: mëttel Hautfaarf',
    '👩🏾‍🏫' => 'Enseignante: mëtteldäischter Hautfaarf',
    '👩🏿‍🏫' => 'Enseignante: däischter Hautfaarf',
    '👨🏻‍⚖' => 'Riichter: hell Hautfaarf',
    '👨🏼‍⚖' => 'Riichter: mëttelhell Hautfaarf',
    '👨🏽‍⚖' => 'Riichter: mëttel Hautfaarf',
    '👨🏾‍⚖' => 'Riichter: mëtteldäischter Hautfaarf',
    '👨🏿‍⚖' => 'Riichter: däischter Hautfaarf',
    '👩🏻‍⚖' => 'Riichterin: hell Hautfaarf',
    '👩🏼‍⚖' => 'Riichterin: mëttelhell Hautfaarf',
    '👩🏽‍⚖' => 'Riichterin: mëttel Hautfaarf',
    '👩🏾‍⚖' => 'Riichterin: mëtteldäischter Hautfaarf',
    '👩🏿‍⚖' => 'Riichterin: däischter Hautfaarf',
    '👨🏻‍🌾' => 'Bauer: hell Hautfaarf',
    '👨🏼‍🌾' => 'Bauer: mëttelhell Hautfaarf',
    '👨🏽‍🌾' => 'Bauer: mëttel Hautfaarf',
    '👨🏾‍🌾' => 'Bauer: mëtteldäischter Hautfaarf',
    '👨🏿‍🌾' => 'Bauer: däischter Hautfaarf',
    '👩🏻‍🌾' => 'Bauerefra: hell Hautfaarf',
    '👩🏼‍🌾' => 'Bauerefra: mëttelhell Hautfaarf',
    '👩🏽‍🌾' => 'Bauerefra: mëttel Hautfaarf',
    '👩🏾‍🌾' => 'Bauerefra: mëtteldäischter Hautfaarf',
    '👩🏿‍🌾' => 'Bauerefra: däischter Hautfaarf',
    '👨🏻‍🍳' => 'Chefkach: hell Hautfaarf',
    '👨🏼‍🍳' => 'Chefkach: mëttelhell Hautfaarf',
    '👨🏽‍🍳' => 'Chefkach: mëttel Hautfaarf',
    '👨🏾‍🍳' => 'Chefkach: mëtteldäischter Hautfaarf',
    '👨🏿‍🍳' => 'Chefkach: däischter Hautfaarf',
    '👩🏻‍🍳' => 'Chefkächen: hell Hautfaarf',
    '👩🏼‍🍳' => 'Chefkächen: mëttelhell Hautfaarf',
    '👩🏽‍🍳' => 'Chefkächen: mëttel Hautfaarf',
    '👩🏾‍🍳' => 'Chefkächen: mëtteldäischter Hautfaarf',
    '👩🏿‍🍳' => 'Chefkächen: däischter Hautfaarf',
    '👨🏻‍🔧' => 'Mecanicien: hell Hautfaarf',
    '👨🏼‍🔧' => 'Mecanicien: mëttelhell Hautfaarf',
    '👨🏽‍🔧' => 'Mecanicien: mëttel Hautfaarf',
    '👨🏾‍🔧' => 'Mecanicien: mëtteldäischter Hautfaarf',
    '👨🏿‍🔧' => 'Mecanicien: däischter Hautfaarf',
    '👩🏻‍🔧' => 'Mecanicienne: hell Hautfaarf',
    '👩🏼‍🔧' => 'Mecanicienne: mëttelhell Hautfaarf',
    '👩🏽‍🔧' => 'Mecanicienne: mëttel Hautfaarf',
    '👩🏾‍🔧' => 'Mecanicienne: mëtteldäischter Hautfaarf',
    '👩🏿‍🔧' => 'Mecanicienne: däischter Hautfaarf',
    '👨🏻‍🏭' => 'Aarbechter: hell Hautfaarf',
    '👨🏼‍🏭' => 'Aarbechter: mëttelhell Hautfaarf',
    '👨🏽‍🏭' => 'Aarbechter: mëttel Hautfaarf',
    '👨🏾‍🏭' => 'Aarbechter: mëtteldäischter Hautfaarf',
    '👨🏿‍🏭' => 'Aarbechter: däischter Hautfaarf',
    '👩🏻‍🏭' => 'Aarbechterin: hell Hautfaarf',
    '👩🏼‍🏭' => 'Aarbechterin: mëttelhell Hautfaarf',
    '👩🏽‍🏭' => 'Aarbechterin: mëttel Hautfaarf',
    '👩🏾‍🏭' => 'Aarbechterin: mëtteldäischter Hautfaarf',
    '👩🏿‍🏭' => 'Aarbechterin: däischter Hautfaarf',
    '👨🏻‍💼' => 'Employé: hell Hautfaarf',
    '👨🏼‍💼' => 'Employé: mëttelhell Hautfaarf',
    '👨🏽‍💼' => 'Employé: mëttel Hautfaarf',
    '👨🏾‍💼' => 'Employé: mëtteldäischter Hautfaarf',
    '👨🏿‍💼' => 'Employé: däischter Hautfaarf',
    '👩🏻‍💼' => 'Employée: hell Hautfaarf',
    '👩🏼‍💼' => 'Employée: mëttelhell Hautfaarf',
    '👩🏽‍💼' => 'Employée: mëttel Hautfaarf',
    '👩🏾‍💼' => 'Employée: mëtteldäischter Hautfaarf',
    '👩🏿‍💼' => 'Employée: däischter Hautfaarf',
    '👨🏻‍🔬' => 'Wëssenschaftler: hell Hautfaarf',
    '👨🏼‍🔬' => 'Wëssenschaftler: mëttelhell Hautfaarf',
    '👨🏽‍🔬' => 'Wëssenschaftler: mëttel Hautfaarf',
    '👨🏾‍🔬' => 'Wëssenschaftler: mëtteldäischter Hautfaarf',
    '👨🏿‍🔬' => 'Wëssenschaftler: däischter Hautfaarf',
    '👩🏻‍🔬' => 'Wëssenschaftlerin: hell Hautfaarf',
    '👩🏼‍🔬' => 'Wëssenschaftlerin: mëttelhell Hautfaarf',
    '👩🏽‍🔬' => 'Wëssenschaftlerin: mëttel Hautfaarf',
    '👩🏾‍🔬' => 'Wëssenschaftlerin: mëtteldäischter Hautfaarf',
    '👩🏿‍🔬' => 'Wëssenschaftlerin: däischter Hautfaarf',
    '👨🏻‍💻' => 'Techniker: hell Hautfaarf',
    '👨🏼‍💻' => 'Techniker: mëttelhell Hautfaarf',
    '👨🏽‍💻' => 'Techniker: mëttel Hautfaarf',
    '👨🏾‍💻' => 'Techniker: mëtteldäischter Hautfaarf',
    '👨🏿‍💻' => 'Techniker: däischter Hautfaarf',
    '👩🏻‍💻' => 'Technikerin: hell Hautfaarf',
    '👩🏼‍💻' => 'Technikerin: mëttelhell Hautfaarf',
    '👩🏽‍💻' => 'Technikerin: mëttel Hautfaarf',
    '👩🏾‍💻' => 'Technikerin: mëtteldäischter Hautfaarf',
    '👩🏿‍💻' => 'Technikerin: däischter Hautfaarf',
    '👨🏻‍🎤' => 'Sänger: hell Hautfaarf',
    '👨🏼‍🎤' => 'Sänger: mëttelhell Hautfaarf',
    '👨🏽‍🎤' => 'Sänger: mëttel Hautfaarf',
    '👨🏾‍🎤' => 'Sänger: mëtteldäischter Hautfaarf',
    '👨🏿‍🎤' => 'Sänger: däischter Hautfaarf',
    '👩🏻‍🎤' => 'Sängerin: hell Hautfaarf',
    '👩🏼‍🎤' => 'Sängerin: mëttelhell Hautfaarf',
    '👩🏽‍🎤' => 'Sängerin: mëttel Hautfaarf',
    '👩🏾‍🎤' => 'Sängerin: mëtteldäischter Hautfaarf',
    '👩🏿‍🎤' => 'Sängerin: däischter Hautfaarf',
    '👨🏻‍🎨' => 'Kënschtler: hell Hautfaarf',
    '👨🏼‍🎨' => 'Kënschtler: mëttelhell Hautfaarf',
    '👨🏽‍🎨' => 'Kënschtler: mëttel Hautfaarf',
    '👨🏾‍🎨' => 'Kënschtler: mëtteldäischter Hautfaarf',
    '👨🏿‍🎨' => 'Kënschtler: däischter Hautfaarf',
    '👩🏻‍🎨' => 'Kënschtlerin: hell Hautfaarf',
    '👩🏼‍🎨' => 'Kënschtlerin: mëttelhell Hautfaarf',
    '👩🏽‍🎨' => 'Kënschtlerin: mëttel Hautfaarf',
    '👩🏾‍🎨' => 'Kënschtlerin: mëtteldäischter Hautfaarf',
    '👩🏿‍🎨' => 'Kënschtlerin: däischter Hautfaarf',
    '👨🏻‍✈' => 'Pilot: hell Hautfaarf',
    '👨🏼‍✈' => 'Pilot: mëttelhell Hautfaarf',
    '👨🏽‍✈' => 'Pilot: mëttel Hautfaarf',
    '👨🏾‍✈' => 'Pilot: mëtteldäischter Hautfaarf',
    '👨🏿‍✈' => 'Pilot: däischter Hautfaarf',
    '👩🏻‍✈' => 'Pilotin: hell Hautfaarf',
    '👩🏼‍✈' => 'Pilotin: mëttelhell Hautfaarf',
    '👩🏽‍✈' => 'Pilotin: mëttel Hautfaarf',
    '👩🏾‍✈' => 'Pilotin: mëtteldäischter Hautfaarf',
    '👩🏿‍✈' => 'Pilotin: däischter Hautfaarf',
    '👨🏻‍🚀' => 'Astronaut: hell Hautfaarf',
    '👨🏼‍🚀' => 'Astronaut: mëttelhell Hautfaarf',
    '👨🏽‍🚀' => 'Astronaut: mëttel Hautfaarf',
    '👨🏾‍🚀' => 'Astronaut: mëtteldäischter Hautfaarf',
    '👨🏿‍🚀' => 'Astronaut: däischter Hautfaarf',
    '👩🏻‍🚀' => 'Astronautin: hell Hautfaarf',
    '👩🏼‍🚀' => 'Astronautin: mëttelhell Hautfaarf',
    '👩🏽‍🚀' => 'Astronautin: mëttel Hautfaarf',
    '👩🏾‍🚀' => 'Astronautin: mëtteldäischter Hautfaarf',
    '👩🏿‍🚀' => 'Astronautin: däischter Hautfaarf',
    '👨🏻‍🚒' => 'Pompjee: hell Hautfaarf',
    '👨🏼‍🚒' => 'Pompjee: mëttelhell Hautfaarf',
    '👨🏽‍🚒' => 'Pompjee: mëttel Hautfaarf',
    '👨🏾‍🚒' => 'Pompjee: mëtteldäischter Hautfaarf',
    '👨🏿‍🚒' => 'Pompjee: däischter Hautfaarf',
    '👩🏻‍🚒' => 'Pompjeesfra: hell Hautfaarf',
    '👩🏼‍🚒' => 'Pompjeesfra: mëttelhell Hautfaarf',
    '👩🏽‍🚒' => 'Pompjeesfra: mëttel Hautfaarf',
    '👩🏾‍🚒' => 'Pompjeesfra: mëtteldäischter Hautfaarf',
    '👩🏿‍🚒' => 'Pompjeesfra: däischter Hautfaarf',
    '👮🏻‍♂' => 'Polizist: hell Hautfaarf',
    '👮🏼‍♂' => 'Polizist: mëttelhell Hautfaarf',
    '👮🏽‍♂' => 'Polizist: mëttel Hautfaarf',
    '👮🏾‍♂' => 'Polizist: mëtteldäischter Hautfaarf',
    '👮🏿‍♂' => 'Polizist: däischter Hautfaarf',
    '👮🏻‍♀' => 'Polizistin: hell Hautfaarf',
    '👮🏼‍♀' => 'Polizistin: mëttelhell Hautfaarf',
    '👮🏽‍♀' => 'Polizistin: mëttel Hautfaarf',
    '👮🏾‍♀' => 'Polizistin: mëtteldäischter Hautfaarf',
    '👮🏿‍♀' => 'Polizistin: däischter Hautfaarf',
    '🕵🏻‍♂' => 'Detektiv: hell Hautfaarf',
    '🕵🏼‍♂' => 'Detektiv: mëttelhell Hautfaarf',
    '🕵🏽‍♂' => 'Detektiv: mëttel Hautfaarf',
    '🕵🏾‍♂' => 'Detektiv: mëtteldäischter Hautfaarf',
    '🕵🏿‍♂' => 'Detektiv: däischter Hautfaarf',
    '🕵🏻‍♀' => 'Detektivin: hell Hautfaarf',
    '🕵🏼‍♀' => 'Detektivin: mëttelhell Hautfaarf',
    '🕵🏽‍♀' => 'Detektivin: mëttel Hautfaarf',
    '🕵🏾‍♀' => 'Detektivin: mëtteldäischter Hautfaarf',
    '🕵🏿‍♀' => 'Detektivin: däischter Hautfaarf',
    '💂🏻‍♂' => 'Wiechter: hell Hautfaarf',
    '💂🏼‍♂' => 'Wiechter: mëttelhell Hautfaarf',
    '💂🏽‍♂' => 'Wiechter: mëttel Hautfaarf',
    '💂🏾‍♂' => 'Wiechter: mëtteldäischter Hautfaarf',
    '💂🏿‍♂' => 'Wiechter: däischter Hautfaarf',
    '💂🏻‍♀' => 'Wiechterin: hell Hautfaarf',
    '💂🏼‍♀' => 'Wiechterin: mëttelhell Hautfaarf',
    '💂🏽‍♀' => 'Wiechterin: mëttel Hautfaarf',
    '💂🏾‍♀' => 'Wiechterin: mëtteldäischter Hautfaarf',
    '💂🏿‍♀' => 'Wiechterin: däischter Hautfaarf',
    '👷🏻‍♂' => 'Bauaarbechter: hell Hautfaarf',
    '👷🏼‍♂' => 'Bauaarbechter: mëttelhell Hautfaarf',
    '👷🏽‍♂' => 'Bauaarbechter: mëttel Hautfaarf',
    '👷🏾‍♂' => 'Bauaarbechter: mëtteldäischter Hautfaarf',
    '👷🏿‍♂' => 'Bauaarbechter: däischter Hautfaarf',
    '👷🏻‍♀' => 'Bauaarbechterin: hell Hautfaarf',
    '👷🏼‍♀' => 'Bauaarbechterin: mëttelhell Hautfaarf',
    '👷🏽‍♀' => 'Bauaarbechterin: mëttel Hautfaarf',
    '👷🏾‍♀' => 'Bauaarbechterin: mëtteldäischter Hautfaarf',
    '👷🏿‍♀' => 'Bauaarbechterin: däischter Hautfaarf',
    '👳🏻‍♂' => 'Mann mat Turban: hell Hautfaarf',
    '👳🏼‍♂' => 'Mann mat Turban: mëttelhell Hautfaarf',
    '👳🏽‍♂' => 'Mann mat Turban: mëttel Hautfaarf',
    '👳🏾‍♂' => 'Mann mat Turban: mëtteldäischter Hautfaarf',
    '👳🏿‍♂' => 'Mann mat Turban: däischter Hautfaarf',
    '👳🏻‍♀' => 'Fra mat Turban: hell Hautfaarf',
    '👳🏼‍♀' => 'Fra mat Turban: mëttelhell Hautfaarf',
    '👳🏽‍♀' => 'Fra mat Turban: mëttel Hautfaarf',
    '👳🏾‍♀' => 'Fra mat Turban: mëtteldäischter Hautfaarf',
    '👳🏿‍♀' => 'Fra mat Turban: däischter Hautfaarf',
    '🧙🏻‍♂' => 'Zauberer: hell Hautfaarf',
    '🧙🏼‍♂' => 'Zauberer: mëttelhell Hautfaarf',
    '🧙🏽‍♂' => 'Zauberer: mëttel Hautfaarf',
    '🧙🏾‍♂' => 'Zauberer: mëtteldäischter Hautfaarf',
    '🧙🏿‍♂' => 'Zauberer: däischter Hautfaarf',
    '🧙🏻‍♀' => 'Hex: hell Hautfaarf',
    '🧙🏼‍♀' => 'Hex: mëttelhell Hautfaarf',
    '🧙🏽‍♀' => 'Hex: mëttel Hautfaarf',
    '🧙🏾‍♀' => 'Hex: mëtteldäischter Hautfaarf',
    '🧙🏿‍♀' => 'Hex: däischter Hautfaarf',
    '🧚🏻‍♂' => 'männlech Fee: hell Hautfaarf',
    '🧚🏼‍♂' => 'männlech Fee: mëttelhell Hautfaarf',
    '🧚🏽‍♂' => 'männlech Fee: mëttel Hautfaarf',
    '🧚🏾‍♂' => 'männlech Fee: mëtteldäischter Hautfaarf',
    '🧚🏿‍♂' => 'männlech Fee: däischter Hautfaarf',
    '🧚🏻‍♀' => 'weiblech Fee: hell Hautfaarf',
    '🧚🏼‍♀' => 'weiblech Fee: mëttelhell Hautfaarf',
    '🧚🏽‍♀' => 'weiblech Fee: mëttel Hautfaarf',
    '🧚🏾‍♀' => 'weiblech Fee: mëtteldäischter Hautfaarf',
    '🧚🏿‍♀' => 'weiblech Fee: däischter Hautfaarf',
    '🧛🏻‍♂' => 'Vampirmann: hell Hautfaarf',
    '🧛🏼‍♂' => 'Vampirmann: mëttelhell Hautfaarf',
    '🧛🏽‍♂' => 'Vampirmann: mëttel Hautfaarf',
    '🧛🏾‍♂' => 'Vampirmann: mëtteldäischter Hautfaarf',
    '🧛🏿‍♂' => 'Vampirmann: däischter Hautfaarf',
    '🧛🏻‍♀' => 'Vampirfra: hell Hautfaarf',
    '🧛🏼‍♀' => 'Vampirfra: mëttelhell Hautfaarf',
    '🧛🏽‍♀' => 'Vampirfra: mëttel Hautfaarf',
    '🧛🏾‍♀' => 'Vampirfra: mëtteldäischter Hautfaarf',
    '🧛🏿‍♀' => 'Vampirfra: däischter Hautfaarf',
    '🧜🏻‍♂' => 'Miermann: hell Hautfaarf',
    '🧜🏼‍♂' => 'Miermann: mëttelhell Hautfaarf',
    '🧜🏽‍♂' => 'Miermann: mëttel Hautfaarf',
    '🧜🏾‍♂' => 'Miermann: mëtteldäischter Hautfaarf',
    '🧜🏿‍♂' => 'Miermann: däischter Hautfaarf',
    '🧜🏻‍♀' => 'Mierjongfra: hell Hautfaarf',
    '🧜🏼‍♀' => 'Mierjongfra: mëttelhell Hautfaarf',
    '🧜🏽‍♀' => 'Mierjongfra: mëttel Hautfaarf',
    '🧜🏾‍♀' => 'Mierjongfra: mëtteldäischter Hautfaarf',
    '🧜🏿‍♀' => 'Mierjongfra: däischter Hautfaarf',
    '🧝🏻‍♂' => 'Elfemann: hell Hautfaarf',
    '🧝🏼‍♂' => 'Elfemann: mëttelhell Hautfaarf',
    '🧝🏽‍♂' => 'Elfemann: mëttel Hautfaarf',
    '🧝🏾‍♂' => 'Elfemann: mëtteldäischter Hautfaarf',
    '🧝🏿‍♂' => 'Elfemann: däischter Hautfaarf',
    '🧝🏻‍♀' => 'Elfefra: hell Hautfaarf',
    '🧝🏼‍♀' => 'Elfefra: mëttelhell Hautfaarf',
    '🧝🏽‍♀' => 'Elfefra: mëttel Hautfaarf',
    '🧝🏾‍♀' => 'Elfefra: mëtteldäischter Hautfaarf',
    '🧝🏿‍♀' => 'Elfefra: däischter Hautfaarf',
    '💆🏻‍♂' => 'Mann, deen eng Kappmassage kritt: hell Hautfaarf',
    '💆🏼‍♂' => 'Mann, deen eng Kappmassage kritt: mëttelhell Hautfaarf',
    '💆🏽‍♂' => 'Mann, deen eng Kappmassage kritt: mëttel Hautfaarf',
    '💆🏾‍♂' => 'Mann, deen eng Kappmassage kritt: mëtteldäischter Hautfaarf',
    '💆🏿‍♂' => 'Mann, deen eng Kappmassage kritt: däischter Hautfaarf',
    '💆🏻‍♀' => 'Fra, déi eng Kappmassage kritt: hell Hautfaarf',
    '💆🏼‍♀' => 'Fra, déi eng Kappmassage kritt: mëttelhell Hautfaarf',
    '💆🏽‍♀' => 'Fra, déi eng Kappmassage kritt: mëttel Hautfaarf',
    '💆🏾‍♀' => 'Fra, déi eng Kappmassage kritt: mëtteldäischter Hautfaarf',
    '💆🏿‍♀' => 'Fra, déi eng Kappmassage kritt: däischter Hautfaarf',
    '💇🏻‍♂' => 'Mann, deen d’Hoer geschnidde kritt: hell Hautfaarf',
    '💇🏼‍♂' => 'Mann, deen d’Hoer geschnidde kritt: mëttelhell Hautfaarf',
    '💇🏽‍♂' => 'Mann, deen d’Hoer geschnidde kritt: mëttel Hautfaarf',
    '💇🏾‍♂' => 'Mann, deen d’Hoer geschnidde kritt: mëtteldäischter Hautfaarf',
    '💇🏿‍♂' => 'Mann, deen d’Hoer geschnidde kritt: däischter Hautfaarf',
    '💇🏻‍♀' => 'Fra, déi d’Hoer geschnidde kritt: hell Hautfaarf',
    '💇🏼‍♀' => 'Fra, déi d’Hoer geschnidde kritt: mëttelhell Hautfaarf',
    '💇🏽‍♀' => 'Fra, déi d’Hoer geschnidde kritt: mëttel Hautfaarf',
    '💇🏾‍♀' => 'Fra, déi d’Hoer geschnidde kritt: mëtteldäischter Hautfaarf',
    '💇🏿‍♀' => 'Fra, déi d’Hoer geschnidde kritt: däischter Hautfaarf',
    '🚶🏻‍♂' => 'spadséierende Mann: hell Hautfaarf',
    '🚶🏼‍♂' => 'spadséierende Mann: mëttelhell Hautfaarf',
    '🚶🏽‍♂' => 'spadséierende Mann: mëttel Hautfaarf',
    '🚶🏾‍♂' => 'spadséierende Mann: mëtteldäischter Hautfaarf',
    '🚶🏿‍♂' => 'spadséierende Mann: däischter Hautfaarf',
    '🚶🏻‍♀' => 'spadséierend Fra: hell Hautfaarf',
    '🚶🏼‍♀' => 'spadséierend Fra: mëttelhell Hautfaarf',
    '🚶🏽‍♀' => 'spadséierend Fra: mëttel Hautfaarf',
    '🚶🏾‍♀' => 'spadséierend Fra: mëtteldäischter Hautfaarf',
    '🚶🏿‍♀' => 'spadséierend Fra: däischter Hautfaarf',
    '🏃🏻‍♂' => 'lafende Mann: hell Hautfaarf',
    '🏃🏼‍♂' => 'lafende Mann: mëttelhell Hautfaarf',
    '🏃🏽‍♂' => 'lafende Mann: mëttel Hautfaarf',
    '🏃🏾‍♂' => 'lafende Mann: mëtteldäischter Hautfaarf',
    '🏃🏿‍♂' => 'lafende Mann: däischter Hautfaarf',
    '🏃🏻‍♀' => 'lafend Fra: hell Hautfaarf',
    '🏃🏼‍♀' => 'lafend Fra: mëttelhell Hautfaarf',
    '🏃🏽‍♀' => 'lafend Fra: mëttel Hautfaarf',
    '🏃🏾‍♀' => 'lafend Fra: mëtteldäischter Hautfaarf',
    '🏃🏿‍♀' => 'lafend Fra: däischter Hautfaarf',
    '👯🏻‍♀' => 'Frae mat Huesoueren: hell Hautfaarf',
    '👯🏼‍♀' => 'Frae mat Huesoueren: mëttelhell Hautfaarf',
    '👯🏽‍♀' => 'Frae mat Huesoueren: mëttel Hautfaarf',
    '👯🏾‍♀' => 'Frae mat Huesoueren: mëtteldäischter Hautfaarf',
    '👯🏿‍♀' => 'Frae mat Huesoueren: däischter Hautfaarf',
    '👯🏻‍♂' => 'Männer mat Huesoueren: hell Hautfaarf',
    '👯🏼‍♂' => 'Männer mat Huesoueren: mëttelhell Hautfaarf',
    '👯🏽‍♂' => 'Männer mat Huesoueren: mëttel Hautfaarf',
    '👯🏾‍♂' => 'Männer mat Huesoueren: mëtteldäischter Hautfaarf',
    '👯🏿‍♂' => 'Männer mat Huesoueren: däischter Hautfaarf',
    '🧖🏻‍♂' => 'Mann am Dampbad: hell Hautfaarf',
    '🧖🏼‍♂' => 'Mann am Dampbad: mëttelhell Hautfaarf',
    '🧖🏽‍♂' => 'Mann am Dampbad: mëttel Hautfaarf',
    '🧖🏾‍♂' => 'Mann am Dampbad: mëtteldäischter Hautfaarf',
    '🧖🏿‍♂' => 'Mann am Dampbad: däischter Hautfaarf',
    '🧖🏻‍♀' => 'Fra am Dampbad: hell Hautfaarf',
    '🧖🏼‍♀' => 'Fra am Dampbad: mëttelhell Hautfaarf',
    '🧖🏽‍♀' => 'Fra am Dampbad: mëttel Hautfaarf',
    '🧖🏾‍♀' => 'Fra am Dampbad: mëtteldäischter Hautfaarf',
    '🧖🏿‍♀' => 'Fra am Dampbad: däischter Hautfaarf',
    '🧗🏻‍♂' => 'Klëmmer: hell Hautfaarf',
    '🧗🏼‍♂' => 'Klëmmer: mëttelhell Hautfaarf',
    '🧗🏽‍♂' => 'Klëmmer: mëttel Hautfaarf',
    '🧗🏾‍♂' => 'Klëmmer: mëtteldäischter Hautfaarf',
    '🧗🏿‍♂' => 'Klëmmer: däischter Hautfaarf',
    '🧗🏻‍♀' => 'Klëmmerin: hell Hautfaarf',
    '🧗🏼‍♀' => 'Klëmmerin: mëttelhell Hautfaarf',
    '🧗🏽‍♀' => 'Klëmmerin: mëttel Hautfaarf',
    '🧗🏾‍♀' => 'Klëmmerin: mëtteldäischter Hautfaarf',
    '🧗🏿‍♀' => 'Klëmmerin: däischter Hautfaarf',
    '🏌🏻‍♂' => 'Golfer: hell Hautfaarf',
    '🏌🏼‍♂' => 'Golfer: mëttelhell Hautfaarf',
    '🏌🏽‍♂' => 'Golfer: mëttel Hautfaarf',
    '🏌🏾‍♂' => 'Golfer: mëtteldäischter Hautfaarf',
    '🏌🏿‍♂' => 'Golfer: däischter Hautfaarf',
    '🏌🏻‍♀' => 'Golferin: hell Hautfaarf',
    '🏌🏼‍♀' => 'Golferin: mëttelhell Hautfaarf',
    '🏌🏽‍♀' => 'Golferin: mëttel Hautfaarf',
    '🏌🏾‍♀' => 'Golferin: mëtteldäischter Hautfaarf',
    '🏌🏿‍♀' => 'Golferin: däischter Hautfaarf',
    '🏄🏻‍♂' => 'Surfer: hell Hautfaarf',
    '🏄🏼‍♂' => 'Surfer: mëttelhell Hautfaarf',
    '🏄🏽‍♂' => 'Surfer: mëttel Hautfaarf',
    '🏄🏾‍♂' => 'Surfer: mëtteldäischter Hautfaarf',
    '🏄🏿‍♂' => 'Surfer: däischter Hautfaarf',
    '🏄🏻‍♀' => 'Surferin: hell Hautfaarf',
    '🏄🏼‍♀' => 'Surferin: mëttelhell Hautfaarf',
    '🏄🏽‍♀' => 'Surferin: mëttel Hautfaarf',
    '🏄🏾‍♀' => 'Surferin: mëtteldäischter Hautfaarf',
    '🏄🏿‍♀' => 'Surferin: däischter Hautfaarf',
    '🚣🏻‍♂' => 'rudderende Mann: hell Hautfaarf',
    '🚣🏼‍♂' => 'rudderende Mann: mëttelhell Hautfaarf',
    '🚣🏽‍♂' => 'rudderende Mann: mëttel Hautfaarf',
    '🚣🏾‍♂' => 'rudderende Mann: mëtteldäischter Hautfaarf',
    '🚣🏿‍♂' => 'rudderende Mann: däischter Hautfaarf',
    '🚣🏻‍♀' => 'rudderend Fra: hell Hautfaarf',
    '🚣🏼‍♀' => 'rudderend Fra: mëttelhell Hautfaarf',
    '🚣🏽‍♀' => 'rudderend Fra: mëttel Hautfaarf',
    '🚣🏾‍♀' => 'rudderend Fra: mëtteldäischter Hautfaarf',
    '🚣🏿‍♀' => 'rudderend Fra: däischter Hautfaarf',
    '🏊🏻‍♂' => 'Schwëmmer: hell Hautfaarf',
    '🏊🏼‍♂' => 'Schwëmmer: mëttelhell Hautfaarf',
    '🏊🏽‍♂' => 'Schwëmmer: mëttel Hautfaarf',
    '🏊🏾‍♂' => 'Schwëmmer: mëtteldäischter Hautfaarf',
    '🏊🏿‍♂' => 'Schwëmmer: däischter Hautfaarf',
    '🏊🏻‍♀' => 'Schwëmmerin: hell Hautfaarf',
    '🏊🏼‍♀' => 'Schwëmmerin: mëttelhell Hautfaarf',
    '🏊🏽‍♀' => 'Schwëmmerin: mëttel Hautfaarf',
    '🏊🏾‍♀' => 'Schwëmmerin: mëtteldäischter Hautfaarf',
    '🏊🏿‍♀' => 'Schwëmmerin: däischter Hautfaarf',
    '⛹🏻‍♂' => 'mam Ball dribbelende Mann: hell Hautfaarf',
    '⛹🏼‍♂' => 'mam Ball dribbelende Mann: mëttelhell Hautfaarf',
    '⛹🏽‍♂' => 'mam Ball dribbelende Mann: mëttel Hautfaarf',
    '⛹🏾‍♂' => 'mam Ball dribbelende Mann: mëtteldäischter Hautfaarf',
    '⛹🏿‍♂' => 'mam Ball dribbelende Mann: däischter Hautfaarf',
    '⛹🏻‍♀' => 'mam Ball dribbelend Fra: hell Hautfaarf',
    '⛹🏼‍♀' => 'mam Ball dribbelend Fra: mëttelhell Hautfaarf',
    '⛹🏽‍♀' => 'mam Ball dribbelend Fra: mëttel Hautfaarf',
    '⛹🏾‍♀' => 'mam Ball dribbelend Fra: mëtteldäischter Hautfaarf',
    '⛹🏿‍♀' => 'mam Ball dribbelend Fra: däischter Hautfaarf',
    '🏋🏻‍♂' => 'Gewiichthiewer: hell Hautfaarf',
    '🏋🏼‍♂' => 'Gewiichthiewer: mëttelhell Hautfaarf',
    '🏋🏽‍♂' => 'Gewiichthiewer: mëttel Hautfaarf',
    '🏋🏾‍♂' => 'Gewiichthiewer: mëtteldäischter Hautfaarf',
    '🏋🏿‍♂' => 'Gewiichthiewer: däischter Hautfaarf',
    '🏋🏻‍♀' => 'Gewiichthiewerin: hell Hautfaarf',
    '🏋🏼‍♀' => 'Gewiichthiewerin: mëttelhell Hautfaarf',
    '🏋🏽‍♀' => 'Gewiichthiewerin: mëttel Hautfaarf',
    '🏋🏾‍♀' => 'Gewiichthiewerin: mëtteldäischter Hautfaarf',
    '🏋🏿‍♀' => 'Gewiichthiewerin: däischter Hautfaarf',
    '🚴🏻‍♂' => 'Vëlosfuerer: hell Hautfaarf',
    '🚴🏼‍♂' => 'Vëlosfuerer: mëttelhell Hautfaarf',
    '🚴🏽‍♂' => 'Vëlosfuerer: mëttel Hautfaarf',
    '🚴🏾‍♂' => 'Vëlosfuerer: mëtteldäischter Hautfaarf',
    '🚴🏿‍♂' => 'Vëlosfuerer: däischter Hautfaarf',
    '🚴🏻‍♀' => 'Vëlosfuererin: hell Hautfaarf',
    '🚴🏼‍♀' => 'Vëlosfuererin: mëttelhell Hautfaarf',
    '🚴🏽‍♀' => 'Vëlosfuererin: mëttel Hautfaarf',
    '🚴🏾‍♀' => 'Vëlosfuererin: mëtteldäischter Hautfaarf',
    '🚴🏿‍♀' => 'Vëlosfuererin: däischter Hautfaarf',
    '🚵🏻‍♂' => 'Mountainbikesfuerer: hell Hautfaarf',
    '🚵🏼‍♂' => 'Mountainbikesfuerer: mëttelhell Hautfaarf',
    '🚵🏽‍♂' => 'Mountainbikesfuerer: mëttel Hautfaarf',
    '🚵🏾‍♂' => 'Mountainbikesfuerer: mëtteldäischter Hautfaarf',
    '🚵🏿‍♂' => 'Mountainbikesfuerer: däischter Hautfaarf',
    '🚵🏻‍♀' => 'Mountainbikesfuererin: hell Hautfaarf',
    '🚵🏼‍♀' => 'Mountainbikesfuererin: mëttelhell Hautfaarf',
    '🚵🏽‍♀' => 'Mountainbikesfuererin: mëttel Hautfaarf',
    '🚵🏾‍♀' => 'Mountainbikesfuererin: mëtteldäischter Hautfaarf',
    '🚵🏿‍♀' => 'Mountainbikesfuererin: däischter Hautfaarf',
    '🤸🏻‍♂' => 'Mann, deen d’Rad schléit: hell Hautfaarf',
    '🤸🏼‍♂' => 'Mann, deen d’Rad schléit: mëttelhell Hautfaarf',
    '🤸🏽‍♂' => 'Mann, deen d’Rad schléit: mëttel Hautfaarf',
    '🤸🏾‍♂' => 'Mann, deen d’Rad schléit: mëtteldäischter Hautfaarf',
    '🤸🏿‍♂' => 'Mann, deen d’Rad schléit: däischter Hautfaarf',
    '🤸🏻‍♀' => 'Fra, déi d’Rad schléit: hell Hautfaarf',
    '🤸🏼‍♀' => 'Fra, déi d’Rad schléit: mëttelhell Hautfaarf',
    '🤸🏽‍♀' => 'Fra, déi d’Rad schléit: mëttel Hautfaarf',
    '🤸🏾‍♀' => 'Fra, déi d’Rad schléit: mëtteldäischter Hautfaarf',
    '🤸🏿‍♀' => 'Fra, déi d’Rad schléit: däischter Hautfaarf',
    '🤼🏻‍♀' => 'Wrestlerinnen: hell Hautfaarf',
    '🤼🏼‍♀' => 'Wrestlerinnen: mëttelhell Hautfaarf',
    '🤼🏽‍♀' => 'Wrestlerinnen: mëttel Hautfaarf',
    '🤼🏾‍♀' => 'Wrestlerinnen: mëtteldäischter Hautfaarf',
    '🤼🏿‍♀' => 'Wrestlerinnen: däischter Hautfaarf',
    '🤼🏻‍♂' => 'Wrestler: hell Hautfaarf',
    '🤼🏼‍♂' => 'Wrestler: mëttelhell Hautfaarf',
    '🤼🏽‍♂' => 'Wrestler: mëttel Hautfaarf',
    '🤼🏾‍♂' => 'Wrestler: mëtteldäischter Hautfaarf',
    '🤼🏿‍♂' => 'Wrestler: däischter Hautfaarf',
    '🤽🏻‍♂' => 'Waasserballspiller: hell Hautfaarf',
    '🤽🏼‍♂' => 'Waasserballspiller: mëttelhell Hautfaarf',
    '🤽🏽‍♂' => 'Waasserballspiller: mëttel Hautfaarf',
    '🤽🏾‍♂' => 'Waasserballspiller: mëtteldäischter Hautfaarf',
    '🤽🏿‍♂' => 'Waasserballspiller: däischter Hautfaarf',
    '🤽🏻‍♀' => 'Waasserballspillerin: hell Hautfaarf',
    '🤽🏼‍♀' => 'Waasserballspillerin: mëttelhell Hautfaarf',
    '🤽🏽‍♀' => 'Waasserballspillerin: mëttel Hautfaarf',
    '🤽🏾‍♀' => 'Waasserballspillerin: mëtteldäischter Hautfaarf',
    '🤽🏿‍♀' => 'Waasserballspillerin: däischter Hautfaarf',
    '🤾🏻‍♂' => 'Handballspiller: hell Hautfaarf',
    '🤾🏼‍♂' => 'Handballspiller: mëttelhell Hautfaarf',
    '🤾🏽‍♂' => 'Handballspiller: mëttel Hautfaarf',
    '🤾🏾‍♂' => 'Handballspiller: mëtteldäischter Hautfaarf',
    '🤾🏿‍♂' => 'Handballspiller: däischter Hautfaarf',
    '🤾🏻‍♀' => 'Handballspillerin: hell Hautfaarf',
    '🤾🏼‍♀' => 'Handballspillerin: mëttelhell Hautfaarf',
    '🤾🏽‍♀' => 'Handballspillerin: mëttel Hautfaarf',
    '🤾🏾‍♀' => 'Handballspillerin: mëtteldäischter Hautfaarf',
    '🤾🏿‍♀' => 'Handballspillerin: däischter Hautfaarf',
    '🤹🏻‍♂' => 'jongléierende Mann: hell Hautfaarf',
    '🤹🏼‍♂' => 'jongléierende Mann: mëttelhell Hautfaarf',
    '🤹🏽‍♂' => 'jongléierende Mann: mëttel Hautfaarf',
    '🤹🏾‍♂' => 'jongléierende Mann: mëtteldäischter Hautfaarf',
    '🤹🏿‍♂' => 'jongléierende Mann: däischter Hautfaarf',
    '🤹🏻‍♀' => 'jongléierend Fra: hell Hautfaarf',
    '🤹🏼‍♀' => 'jongléierend Fra: mëttelhell Hautfaarf',
    '🤹🏽‍♀' => 'jongléierend Fra: mëttel Hautfaarf',
    '🤹🏾‍♀' => 'jongléierend Fra: mëtteldäischter Hautfaarf',
    '🤹🏿‍♀' => 'jongléierend Fra: däischter Hautfaarf',
    '🧘🏻‍♂' => 'Mann a Lotuspositioun: hell Hautfaarf',
    '🧘🏼‍♂' => 'Mann a Lotuspositioun: mëttelhell Hautfaarf',
    '🧘🏽‍♂' => 'Mann a Lotuspositioun: mëttel Hautfaarf',
    '🧘🏾‍♂' => 'Mann a Lotuspositioun: mëtteldäischter Hautfaarf',
    '🧘🏿‍♂' => 'Mann a Lotuspositioun: däischter Hautfaarf',
    '🧘🏻‍♀' => 'Fra a Lotuspositioun: hell Hautfaarf',
    '🧘🏼‍♀' => 'Fra a Lotuspositioun: mëttelhell Hautfaarf',
    '🧘🏽‍♀' => 'Fra a Lotuspositioun: mëttel Hautfaarf',
    '🧘🏾‍♀' => 'Fra a Lotuspositioun: mëtteldäischter Hautfaarf',
    '🧘🏿‍♀' => 'Fra a Lotuspositioun: däischter Hautfaarf',
    '👨‍👦' => 'Famill: Mann, Jong',
    '👨‍👧' => 'Famill: Mann, Meedchen',
    '👩‍👦' => 'Famill: Fra, Jong',
    '👩‍👧' => 'Famill: Fra, Meedchen',
    '👁‍🗨' => 'A an enger Spriechblos',
    '👱‍♂' => 'blonde Mann',
    '👱‍♀' => 'Blondin',
    '🙍‍♂' => 'd’Stir fronzende Mann',
    '🙍‍♀' => 'd’Stir fronzend Fra',
    '🙎‍♂' => 'motzende Mann',
    '🙎‍♀' => 'motzend Fra',
    '🙅‍♂' => 'Mann, deen NEEN weist',
    '🙅‍♀' => 'Fra, déi NEEN weist',
    '🙆‍♂' => 'Mann, deen OK weist',
    '🙆‍♀' => 'Fra, déi OK weist',
    '💁‍♂' => 'Mann, deen d’Hand op hält',
    '💁‍♀' => 'Fra, déi d’Hand op hält',
    '🙋‍♂' => 'Mann, deen d’Hand hieft',
    '🙋‍♀' => 'Fra, déi d’Hand hieft',
    '🙇‍♂' => 'sech vernäipende Mann',
    '🙇‍♀' => 'sech vernäipend Fra',
    '🤦‍♂' => 'Mann, deen sech d’Hand widder de Kapp schléit',
    '🤦‍♀' => 'Fra, déi sech d’Hand widder de Kapp schléit',
    '🤷‍♂' => 'Mann, deen d’Schëlleren hieft',
    '🤷‍♀' => 'Fra, déi d’Schëlleren hieft',
    '👨‍⚕' => 'Medeziner',
    '👩‍⚕' => 'Medezinerin',
    '👨‍🎓' => 'Student',
    '👩‍🎓' => 'Studentin',
    '👨‍🏫' => 'Enseignant',
    '👩‍🏫' => 'Enseignante',
    '👨‍⚖' => 'Riichter',
    '👩‍⚖' => 'Riichterin',
    '👨‍🌾' => 'Bauer',
    '👩‍🌾' => 'Bauerefra',
    '👨‍🍳' => 'Chefkach',
    '👩‍🍳' => 'Chefkächen',
    '👨‍🔧' => 'Mecanicien',
    '👩‍🔧' => 'Mecanicienne',
    '👨‍🏭' => 'Aarbechter',
    '👩‍🏭' => 'Aarbechterin',
    '👨‍💼' => 'Employé',
    '👩‍💼' => 'Employée',
    '👨‍🔬' => 'Wëssenschaftler',
    '👩‍🔬' => 'Wëssenschaftlerin',
    '👨‍💻' => 'Techniker',
    '👩‍💻' => 'Technikerin',
    '👨‍🎤' => 'Sänger',
    '👩‍🎤' => 'Sängerin',
    '👨‍🎨' => 'Kënschtler',
    '👩‍🎨' => 'Kënschtlerin',
    '👨‍✈' => 'Pilot',
    '👩‍✈' => 'Pilotin',
    '👨‍🚀' => 'Astronaut',
    '👩‍🚀' => 'Astronautin',
    '👨‍🚒' => 'Pompjee',
    '👩‍🚒' => 'Pompjeesfra',
    '👮‍♂' => 'Polizist',
    '👮‍♀' => 'Polizistin',
    '🕵‍♂' => 'Detektiv',
    '🕵‍♀' => 'Detektivin',
    '💂‍♂' => 'Wiechter',
    '💂‍♀' => 'Wiechterin',
    '👷‍♂' => 'Bauaarbechter',
    '👷‍♀' => 'Bauaarbechterin',
    '👳‍♂' => 'Mann mat Turban',
    '👳‍♀' => 'Fra mat Turban',
    '🧙‍♂' => 'Zauberer',
    '🧙‍♀' => 'Hex',
    '🧚‍♂' => 'männlech Fee',
    '🧚‍♀' => 'weiblech Fee',
    '🧛‍♂' => 'Vampirmann',
    '🧛‍♀' => 'Vampirfra',
    '🧜‍♂' => 'Miermann',
    '🧜‍♀' => 'Mierjongfra',
    '🧝‍♂' => 'Elfemann',
    '🧝‍♀' => 'Elfefra',
    '🧞‍♂' => 'Geniemann',
    '🧞‍♀' => 'Geniefra',
    '🧟‍♂' => 'Zombiemann',
    '🧟‍♀' => 'Zombiefra',
    '💆‍♂' => 'Mann, deen eng Kappmassage kritt',
    '💆‍♀' => 'Fra, déi eng Kappmassage kritt',
    '💇‍♂' => 'Mann, deen d’Hoer geschnidde kritt',
    '💇‍♀' => 'Fra, déi d’Hoer geschnidde kritt',
    '🚶‍♂' => 'spadséierende Mann',
    '🚶‍♀' => 'spadséierend Fra',
    '🏃‍♂' => 'lafende Mann',
    '🏃‍♀' => 'lafend Fra',
    '👯‍♂' => 'Männer mat Huesoueren',
    '👯‍♀' => 'Frae mat Huesoueren',
    '🧖‍♂' => 'Mann am Dampbad',
    '🧖‍♀' => 'Fra am Dampbad',
    '🧗‍♂' => 'Klëmmer',
    '🧗‍♀' => 'Klëmmerin',
    '🏌‍♂' => 'Golfer',
    '🏌‍♀' => 'Golferin',
    '🏄‍♂' => 'Surfer',
    '🏄‍♀' => 'Surferin',
    '🚣‍♂' => 'rudderende Mann',
    '🚣‍♀' => 'rudderend Fra',
    '🏊‍♂' => 'Schwëmmer',
    '🏊‍♀' => 'Schwëmmerin',
    '⛹‍♂' => 'mam Ball dribbelende Mann',
    '⛹‍♀' => 'mam Ball dribbelend Fra',
    '🏋‍♂' => 'Gewiichthiewer',
    '🏋‍♀' => 'Gewiichthiewerin',
    '🚴‍♂' => 'Vëlosfuerer',
    '🚴‍♀' => 'Vëlosfuererin',
    '🚵‍♂' => 'Mountainbikesfuerer',
    '🚵‍♀' => 'Mountainbikesfuererin',
    '🤸‍♂' => 'Mann, deen d’Rad schléit',
    '🤸‍♀' => 'Fra, déi d’Rad schléit',
    '🤼‍♂' => 'Wrestler',
    '🤼‍♀' => 'Wrestlerinnen',
    '🤽‍♂' => 'Waasserballspiller',
    '🤽‍♀' => 'Waasserballspillerin',
    '🤾‍♂' => 'Handballspiller',
    '🤾‍♀' => 'Handballspillerin',
    '🤹‍♂' => 'jongléierende Mann',
    '🤹‍♀' => 'jongléierend Fra',
    '🧘‍♂' => 'Mann a Lotuspositioun',
    '🧘‍♀' => 'Fra a Lotuspositioun',
    '🏳‍🌈' => 'Reeboufändel',
    '👋🏻' => 'wénkend Hand: hell Hautfaarf',
    '👋🏼' => 'wénkend Hand: mëttelhell Hautfaarf',
    '👋🏽' => 'wénkend Hand: mëttel Hautfaarf',
    '👋🏾' => 'wénkend Hand: mëtteldäischter Hautfaarf',
    '👋🏿' => 'wénkend Hand: däischter Hautfaarf',
    '🤚🏻' => 'héichgehalenen Handréck: hell Hautfaarf',
    '🤚🏼' => 'héichgehalenen Handréck: mëttelhell Hautfaarf',
    '🤚🏽' => 'héichgehalenen Handréck: mëttel Hautfaarf',
    '🤚🏾' => 'héichgehalenen Handréck: mëtteldäischter Hautfaarf',
    '🤚🏿' => 'héichgehalenen Handréck: däischter Hautfaarf',
    '🖐🏻' => 'gehuewen Hand mat ausgestreckte Fanger: hell Hautfaarf',
    '🖐🏼' => 'gehuewen Hand mat ausgestreckte Fanger: mëttelhell Hautfaarf',
    '🖐🏽' => 'gehuewen Hand mat ausgestreckte Fanger: mëttel Hautfaarf',
    '🖐🏾' => 'gehuewen Hand mat ausgestreckte Fanger: mëtteldäischter Hautfaarf',
    '🖐🏿' => 'gehuewen Hand mat ausgestreckte Fanger: däischter Hautfaarf',
    '✋🏻' => 'héichgehalen Hand: hell Hautfaarf',
    '✋🏼' => 'héichgehalen Hand: mëttelhell Hautfaarf',
    '✋🏽' => 'héichgehalen Hand: mëttel Hautfaarf',
    '✋🏾' => 'héichgehalen Hand: mëtteldäischter Hautfaarf',
    '✋🏿' => 'héichgehalen Hand: däischter Hautfaarf',
    '🖖🏻' => 'Vulcan-Grouss: hell Hautfaarf',
    '🖖🏼' => 'Vulcan-Grouss: mëttelhell Hautfaarf',
    '🖖🏽' => 'Vulcan-Grouss: mëttel Hautfaarf',
    '🖖🏾' => 'Vulcan-Grouss: mëtteldäischter Hautfaarf',
    '🖖🏿' => 'Vulcan-Grouss: däischter Hautfaarf',
    '👌🏻' => 'OK-Handzeechen: hell Hautfaarf',
    '👌🏼' => 'OK-Handzeechen: mëttelhell Hautfaarf',
    '👌🏽' => 'OK-Handzeechen: mëttel Hautfaarf',
    '👌🏾' => 'OK-Handzeechen: mëtteldäischter Hautfaarf',
    '👌🏿' => 'OK-Handzeechen: däischter Hautfaarf',
    '✌🏻' => 'Victoire-Handzeechen: hell Hautfaarf',
    '✌🏼' => 'Victoire-Handzeechen: mëttelhell Hautfaarf',
    '✌🏽' => 'Victoire-Handzeechen: mëttel Hautfaarf',
    '✌🏾' => 'Victoire-Handzeechen: mëtteldäischter Hautfaarf',
    '✌🏿' => 'Victoire-Handzeechen: däischter Hautfaarf',
    '🤞🏻' => 'gekräizt Fanger: hell Hautfaarf',
    '🤞🏼' => 'gekräizt Fanger: mëttelhell Hautfaarf',
    '🤞🏽' => 'gekräizt Fanger: mëttel Hautfaarf',
    '🤞🏾' => 'gekräizt Fanger: mëtteldäischter Hautfaarf',
    '🤞🏿' => 'gekräizt Fanger: däischter Hautfaarf',
    '🤟🏻' => 'Léift-Geste: hell Hautfaarf',
    '🤟🏼' => 'Léift-Geste: mëttelhell Hautfaarf',
    '🤟🏽' => 'Léift-Geste: mëttel Hautfaarf',
    '🤟🏾' => 'Léift-Geste: mëtteldäischter Hautfaarf',
    '🤟🏿' => 'Léift-Geste: däischter Hautfaarf',
    '🤘🏻' => 'Mano cornuta, Harenzeechen: hell Hautfaarf',
    '🤘🏼' => 'Mano cornuta, Harenzeechen: mëttelhell Hautfaarf',
    '🤘🏽' => 'Mano cornuta, Harenzeechen: mëttel Hautfaarf',
    '🤘🏾' => 'Mano cornuta, Harenzeechen: mëtteldäischter Hautfaarf',
    '🤘🏿' => 'Mano cornuta, Harenzeechen: däischter Hautfaarf',
    '🤙🏻' => 'Telefon-Handzeechen: hell Hautfaarf',
    '🤙🏼' => 'Telefon-Handzeechen: mëttelhell Hautfaarf',
    '🤙🏽' => 'Telefon-Handzeechen: mëttel Hautfaarf',
    '🤙🏾' => 'Telefon-Handzeechen: mëtteldäischter Hautfaarf',
    '🤙🏿' => 'Telefon-Handzeechen: däischter Hautfaarf',
    '👈🏻' => 'no lénks weisende Fanger vun hanne gesinn: hell Hautfaarf',
    '👈🏼' => 'no lénks weisende Fanger vun hanne gesinn: mëttelhell Hautfaarf',
    '👈🏽' => 'no lénks weisende Fanger vun hanne gesinn: mëttel Hautfaarf',
    '👈🏾' => 'no lénks weisende Fanger vun hanne gesinn: mëtteldäischter Hautfaarf',
    '👈🏿' => 'no lénks weisende Fanger vun hanne gesinn: däischter Hautfaarf',
    '👉🏻' => 'no riets weisende Fanger vun hanne gesinn: hell Hautfaarf',
    '👉🏼' => 'no riets weisende Fanger vun hanne gesinn: mëttelhell Hautfaarf',
    '👉🏽' => 'no riets weisende Fanger vun hanne gesinn: mëttel Hautfaarf',
    '👉🏾' => 'no riets weisende Fanger vun hanne gesinn: mëtteldäischter Hautfaarf',
    '👉🏿' => 'no riets weisende Fanger vun hanne gesinn: däischter Hautfaarf',
    '👆🏻' => 'no uewe weisende Fanger vun hanne gesinn: hell Hautfaarf',
    '👆🏼' => 'no uewe weisende Fanger vun hanne gesinn: mëttelhell Hautfaarf',
    '👆🏽' => 'no uewe weisende Fanger vun hanne gesinn: mëttel Hautfaarf',
    '👆🏾' => 'no uewe weisende Fanger vun hanne gesinn: mëtteldäischter Hautfaarf',
    '👆🏿' => 'no uewe weisende Fanger vun hanne gesinn: däischter Hautfaarf',
    '🖕🏻' => 'Mëttelfanger: hell Hautfaarf',
    '🖕🏼' => 'Mëttelfanger: mëttelhell Hautfaarf',
    '🖕🏽' => 'Mëttelfanger: mëttel Hautfaarf',
    '🖕🏾' => 'Mëttelfanger: mëtteldäischter Hautfaarf',
    '🖕🏿' => 'Mëttelfanger: däischter Hautfaarf',
    '👇🏻' => 'no ënne weisende Fanger vun hanne gesinn: hell Hautfaarf',
    '👇🏼' => 'no ënne weisende Fanger vun hanne gesinn: mëttelhell Hautfaarf',
    '👇🏽' => 'no ënne weisende Fanger vun hanne gesinn: mëttel Hautfaarf',
    '👇🏾' => 'no ënne weisende Fanger vun hanne gesinn: mëtteldäischter Hautfaarf',
    '👇🏿' => 'no ënne weisende Fanger vun hanne gesinn: däischter Hautfaarf',
    '☝🏻' => 'no uewe weisende Fanger: hell Hautfaarf',
    '☝🏼' => 'no uewe weisende Fanger: mëttelhell Hautfaarf',
    '☝🏽' => 'no uewe weisende Fanger: mëttel Hautfaarf',
    '☝🏾' => 'no uewe weisende Fanger: mëtteldäischter Hautfaarf',
    '☝🏿' => 'no uewe weisende Fanger: däischter Hautfaarf',
    '👍🏻' => 'Daum no uewen: hell Hautfaarf',
    '👍🏼' => 'Daum no uewen: mëttelhell Hautfaarf',
    '👍🏽' => 'Daum no uewen: mëttel Hautfaarf',
    '👍🏾' => 'Daum no uewen: mëtteldäischter Hautfaarf',
    '👍🏿' => 'Daum no uewen: däischter Hautfaarf',
    '👎🏻' => 'Daum no ënnen: hell Hautfaarf',
    '👎🏼' => 'Daum no ënnen: mëttelhell Hautfaarf',
    '👎🏽' => 'Daum no ënnen: mëttel Hautfaarf',
    '👎🏾' => 'Daum no ënnen: mëtteldäischter Hautfaarf',
    '👎🏿' => 'Daum no ënnen: däischter Hautfaarf',
    '✊🏻' => 'héichgehale Fauscht: hell Hautfaarf',
    '✊🏼' => 'héichgehale Fauscht: mëttelhell Hautfaarf',
    '✊🏽' => 'héichgehale Fauscht: mëttel Hautfaarf',
    '✊🏾' => 'héichgehale Fauscht: mëtteldäischter Hautfaarf',
    '✊🏿' => 'héichgehale Fauscht: däischter Hautfaarf',
    '👊🏻' => 'entgéintkommend Fauscht: hell Hautfaarf',
    '👊🏼' => 'entgéintkommend Fauscht: mëttelhell Hautfaarf',
    '👊🏽' => 'entgéintkommend Fauscht: mëttel Hautfaarf',
    '👊🏾' => 'entgéintkommend Fauscht: mëtteldäischter Hautfaarf',
    '👊🏿' => 'entgéintkommend Fauscht: däischter Hautfaarf',
    '🤛🏻' => 'lénksgeriicht Fauscht: hell Hautfaarf',
    '🤛🏼' => 'lénksgeriicht Fauscht: mëttelhell Hautfaarf',
    '🤛🏽' => 'lénksgeriicht Fauscht: mëttel Hautfaarf',
    '🤛🏾' => 'lénksgeriicht Fauscht: mëtteldäischter Hautfaarf',
    '🤛🏿' => 'lénksgeriicht Fauscht: däischter Hautfaarf',
    '🤜🏻' => 'rietsgeriicht Fauscht: hell Hautfaarf',
    '🤜🏼' => 'rietsgeriicht Fauscht: mëttelhell Hautfaarf',
    '🤜🏽' => 'rietsgeriicht Fauscht: mëttel Hautfaarf',
    '🤜🏾' => 'rietsgeriicht Fauscht: mëtteldäischter Hautfaarf',
    '🤜🏿' => 'rietsgeriicht Fauscht: däischter Hautfaarf',
    '👏🏻' => 'klappend Hänn: hell Hautfaarf',
    '👏🏼' => 'klappend Hänn: mëttelhell Hautfaarf',
    '👏🏽' => 'klappend Hänn: mëttel Hautfaarf',
    '👏🏾' => 'klappend Hänn: mëtteldäischter Hautfaarf',
    '👏🏿' => 'klappend Hänn: däischter Hautfaarf',
    '🙌🏻' => 'Hänn an d’Luucht: hell Hautfaarf',
    '🙌🏼' => 'Hänn an d’Luucht: mëttelhell Hautfaarf',
    '🙌🏽' => 'Hänn an d’Luucht: mëttel Hautfaarf',
    '🙌🏾' => 'Hänn an d’Luucht: mëtteldäischter Hautfaarf',
    '🙌🏿' => 'Hänn an d’Luucht: däischter Hautfaarf',
    '👐🏻' => 'oppen Hänn: hell Hautfaarf',
    '👐🏼' => 'oppen Hänn: mëttelhell Hautfaarf',
    '👐🏽' => 'oppen Hänn: mëttel Hautfaarf',
    '👐🏾' => 'oppen Hänn: mëtteldäischter Hautfaarf',
    '👐🏿' => 'oppen Hänn: däischter Hautfaarf',
    '🤲🏻' => 'zesummegefaalten Hänn: hell Hautfaarf',
    '🤲🏼' => 'zesummegefaalten Hänn: mëttelhell Hautfaarf',
    '🤲🏽' => 'zesummegefaalten Hänn: mëttel Hautfaarf',
    '🤲🏾' => 'zesummegefaalten Hänn: mëtteldäischter Hautfaarf',
    '🤲🏿' => 'zesummegefaalten Hänn: däischter Hautfaarf',
    '🤝🏻' => 'Handdrock: hell Hautfaarf',
    '🤝🏼' => 'Handdrock: mëttelhell Hautfaarf',
    '🤝🏽' => 'Handdrock: mëttel Hautfaarf',
    '🤝🏾' => 'Handdrock: mëtteldäischter Hautfaarf',
    '🤝🏿' => 'Handdrock: däischter Hautfaarf',
    '🙏🏻' => 'gefaalten Hänn: hell Hautfaarf',
    '🙏🏼' => 'gefaalten Hänn: mëttelhell Hautfaarf',
    '🙏🏽' => 'gefaalten Hänn: mëttel Hautfaarf',
    '🙏🏾' => 'gefaalten Hänn: mëtteldäischter Hautfaarf',
    '🙏🏿' => 'gefaalten Hänn: däischter Hautfaarf',
    '✍🏻' => 'schreiwend Hand: hell Hautfaarf',
    '✍🏼' => 'schreiwend Hand: mëttelhell Hautfaarf',
    '✍🏽' => 'schreiwend Hand: mëttel Hautfaarf',
    '✍🏾' => 'schreiwend Hand: mëtteldäischter Hautfaarf',
    '✍🏿' => 'schreiwend Hand: däischter Hautfaarf',
    '💅🏻' => 'Neellack: hell Hautfaarf',
    '💅🏼' => 'Neellack: mëttelhell Hautfaarf',
    '💅🏽' => 'Neellack: mëttel Hautfaarf',
    '💅🏾' => 'Neellack: mëtteldäischter Hautfaarf',
    '💅🏿' => 'Neellack: däischter Hautfaarf',
    '🤳🏻' => 'Selfie: hell Hautfaarf',
    '🤳🏼' => 'Selfie: mëttelhell Hautfaarf',
    '🤳🏽' => 'Selfie: mëttel Hautfaarf',
    '🤳🏾' => 'Selfie: mëtteldäischter Hautfaarf',
    '🤳🏿' => 'Selfie: däischter Hautfaarf',
    '💪🏻' => 'ugespaante Bizeps: hell Hautfaarf',
    '💪🏼' => 'ugespaante Bizeps: mëttelhell Hautfaarf',
    '💪🏽' => 'ugespaante Bizeps: mëttel Hautfaarf',
    '💪🏾' => 'ugespaante Bizeps: mëtteldäischter Hautfaarf',
    '💪🏿' => 'ugespaante Bizeps: däischter Hautfaarf',
    '👂🏻' => 'Ouer: hell Hautfaarf',
    '👂🏼' => 'Ouer: mëttelhell Hautfaarf',
    '👂🏽' => 'Ouer: mëttel Hautfaarf',
    '👂🏾' => 'Ouer: mëtteldäischter Hautfaarf',
    '👂🏿' => 'Ouer: däischter Hautfaarf',
    '👃🏻' => 'Nues: hell Hautfaarf',
    '👃🏼' => 'Nues: mëttelhell Hautfaarf',
    '👃🏽' => 'Nues: mëttel Hautfaarf',
    '👃🏾' => 'Nues: mëtteldäischter Hautfaarf',
    '👃🏿' => 'Nues: däischter Hautfaarf',
    '👶🏻' => 'Puppelchen: hell Hautfaarf',
    '👶🏼' => 'Puppelchen: mëttelhell Hautfaarf',
    '👶🏽' => 'Puppelchen: mëttel Hautfaarf',
    '👶🏾' => 'Puppelchen: mëtteldäischter Hautfaarf',
    '👶🏿' => 'Puppelchen: däischter Hautfaarf',
    '🧒🏻' => 'Kand: hell Hautfaarf',
    '🧒🏼' => 'Kand: mëttelhell Hautfaarf',
    '🧒🏽' => 'Kand: mëttel Hautfaarf',
    '🧒🏾' => 'Kand: mëtteldäischter Hautfaarf',
    '🧒🏿' => 'Kand: däischter Hautfaarf',
    '👦🏻' => 'Jong: hell Hautfaarf',
    '👦🏼' => 'Jong: mëttelhell Hautfaarf',
    '👦🏽' => 'Jong: mëttel Hautfaarf',
    '👦🏾' => 'Jong: mëtteldäischter Hautfaarf',
    '👦🏿' => 'Jong: däischter Hautfaarf',
    '👧🏻' => 'Meedchen: hell Hautfaarf',
    '👧🏼' => 'Meedchen: mëttelhell Hautfaarf',
    '👧🏽' => 'Meedchen: mëttel Hautfaarf',
    '👧🏾' => 'Meedchen: mëtteldäischter Hautfaarf',
    '👧🏿' => 'Meedchen: däischter Hautfaarf',
    '🧑🏻' => 'Erwuessenen: hell Hautfaarf',
    '🧑🏼' => 'Erwuessenen: mëttelhell Hautfaarf',
    '🧑🏽' => 'Erwuessenen: mëttel Hautfaarf',
    '🧑🏾' => 'Erwuessenen: mëtteldäischter Hautfaarf',
    '🧑🏿' => 'Erwuessenen: däischter Hautfaarf',
    '👱🏻' => 'blond Persoun: hell Hautfaarf',
    '👱🏼' => 'blond Persoun: mëttelhell Hautfaarf',
    '👱🏽' => 'blond Persoun: mëttel Hautfaarf',
    '👱🏾' => 'blond Persoun: mëtteldäischter Hautfaarf',
    '👱🏿' => 'blond Persoun: däischter Hautfaarf',
    '👨🏻' => 'Mann: hell Hautfaarf',
    '👨🏼' => 'Mann: mëttelhell Hautfaarf',
    '👨🏽' => 'Mann: mëttel Hautfaarf',
    '👨🏾' => 'Mann: mëtteldäischter Hautfaarf',
    '👨🏿' => 'Mann: däischter Hautfaarf',
    '🧔🏻' => 'Persoun mat Baart: hell Hautfaarf',
    '🧔🏼' => 'Persoun mat Baart: mëttelhell Hautfaarf',
    '🧔🏽' => 'Persoun mat Baart: mëttel Hautfaarf',
    '🧔🏾' => 'Persoun mat Baart: mëtteldäischter Hautfaarf',
    '🧔🏿' => 'Persoun mat Baart: däischter Hautfaarf',
    '👩🏻' => 'Fra: hell Hautfaarf',
    '👩🏼' => 'Fra: mëttelhell Hautfaarf',
    '👩🏽' => 'Fra: mëttel Hautfaarf',
    '👩🏾' => 'Fra: mëtteldäischter Hautfaarf',
    '👩🏿' => 'Fra: däischter Hautfaarf',
    '🧓🏻' => 'eeleren Erwuessenen: hell Hautfaarf',
    '🧓🏼' => 'eeleren Erwuessenen: mëttelhell Hautfaarf',
    '🧓🏽' => 'eeleren Erwuessenen: mëttel Hautfaarf',
    '🧓🏾' => 'eeleren Erwuessenen: mëtteldäischter Hautfaarf',
    '🧓🏿' => 'eeleren Erwuessenen: däischter Hautfaarf',
    '👴🏻' => 'ale Mann: hell Hautfaarf',
    '👴🏼' => 'ale Mann: mëttelhell Hautfaarf',
    '👴🏽' => 'ale Mann: mëttel Hautfaarf',
    '👴🏾' => 'ale Mann: mëtteldäischter Hautfaarf',
    '👴🏿' => 'ale Mann: däischter Hautfaarf',
    '👵🏻' => 'al Fra: hell Hautfaarf',
    '👵🏼' => 'al Fra: mëttelhell Hautfaarf',
    '👵🏽' => 'al Fra: mëttel Hautfaarf',
    '👵🏾' => 'al Fra: mëtteldäischter Hautfaarf',
    '👵🏿' => 'al Fra: däischter Hautfaarf',
    '🙍🏻' => 'd’Stir fronzend Persoun: hell Hautfaarf',
    '🙍🏼' => 'd’Stir fronzend Persoun: mëttelhell Hautfaarf',
    '🙍🏽' => 'd’Stir fronzend Persoun: mëttel Hautfaarf',
    '🙍🏾' => 'd’Stir fronzend Persoun: mëtteldäischter Hautfaarf',
    '🙍🏿' => 'd’Stir fronzend Persoun: däischter Hautfaarf',
    '🙎🏻' => 'motzend Persoun: hell Hautfaarf',
    '🙎🏼' => 'motzend Persoun: mëttelhell Hautfaarf',
    '🙎🏽' => 'motzend Persoun: mëttel Hautfaarf',
    '🙎🏾' => 'motzend Persoun: mëtteldäischter Hautfaarf',
    '🙎🏿' => 'motzend Persoun: däischter Hautfaarf',
    '🙅🏻' => 'Persoun, déi NEEN weist: hell Hautfaarf',
    '🙅🏼' => 'Persoun, déi NEEN weist: mëttelhell Hautfaarf',
    '🙅🏽' => 'Persoun, déi NEEN weist: mëttel Hautfaarf',
    '🙅🏾' => 'Persoun, déi NEEN weist: mëtteldäischter Hautfaarf',
    '🙅🏿' => 'Persoun, déi NEEN weist: däischter Hautfaarf',
    '🙆🏻' => 'Persoun, déi OK weist: hell Hautfaarf',
    '🙆🏼' => 'Persoun, déi OK weist: mëttelhell Hautfaarf',
    '🙆🏽' => 'Persoun, déi OK weist: mëttel Hautfaarf',
    '🙆🏾' => 'Persoun, déi OK weist: mëtteldäischter Hautfaarf',
    '🙆🏿' => 'Persoun, déi OK weist: däischter Hautfaarf',
    '💁🏻' => 'Persoun, déi d’Hand op hält: hell Hautfaarf',
    '💁🏼' => 'Persoun, déi d’Hand op hält: mëttelhell Hautfaarf',
    '💁🏽' => 'Persoun, déi d’Hand op hält: mëttel Hautfaarf',
    '💁🏾' => 'Persoun, déi d’Hand op hält: mëtteldäischter Hautfaarf',
    '💁🏿' => 'Persoun, déi d’Hand op hält: däischter Hautfaarf',
    '🙋🏻' => 'Persoun, déi d’Hand hieft: hell Hautfaarf',
    '🙋🏼' => 'Persoun, déi d’Hand hieft: mëttelhell Hautfaarf',
    '🙋🏽' => 'Persoun, déi d’Hand hieft: mëttel Hautfaarf',
    '🙋🏾' => 'Persoun, déi d’Hand hieft: mëtteldäischter Hautfaarf',
    '🙋🏿' => 'Persoun, déi d’Hand hieft: däischter Hautfaarf',
    '🙇🏻' => 'sech vernäipend Persoun: hell Hautfaarf',
    '🙇🏼' => 'sech vernäipend Persoun: mëttelhell Hautfaarf',
    '🙇🏽' => 'sech vernäipend Persoun: mëttel Hautfaarf',
    '🙇🏾' => 'sech vernäipend Persoun: mëtteldäischter Hautfaarf',
    '🙇🏿' => 'sech vernäipend Persoun: däischter Hautfaarf',
    '🤦🏻' => 'Persoun, déi sech d’Hand widder de Kapp schléit: hell Hautfaarf',
    '🤦🏼' => 'Persoun, déi sech d’Hand widder de Kapp schléit: mëttelhell Hautfaarf',
    '🤦🏽' => 'Persoun, déi sech d’Hand widder de Kapp schléit: mëttel Hautfaarf',
    '🤦🏾' => 'Persoun, déi sech d’Hand widder de Kapp schléit: mëtteldäischter Hautfaarf',
    '🤦🏿' => 'Persoun, déi sech d’Hand widder de Kapp schléit: däischter Hautfaarf',
    '🤷🏻' => 'Persoun, déi d’Schëlleren hieft: hell Hautfaarf',
    '🤷🏼' => 'Persoun, déi d’Schëlleren hieft: mëttelhell Hautfaarf',
    '🤷🏽' => 'Persoun, déi d’Schëlleren hieft: mëttel Hautfaarf',
    '🤷🏾' => 'Persoun, déi d’Schëlleren hieft: mëtteldäischter Hautfaarf',
    '🤷🏿' => 'Persoun, déi d’Schëlleren hieft: däischter Hautfaarf',
    '👮🏻' => 'Polizist(in): hell Hautfaarf',
    '👮🏼' => 'Polizist(in): mëttelhell Hautfaarf',
    '👮🏽' => 'Polizist(in): mëttel Hautfaarf',
    '👮🏾' => 'Polizist(in): mëtteldäischter Hautfaarf',
    '👮🏿' => 'Polizist(in): däischter Hautfaarf',
    '🕵🏻' => 'Detektiv(in): hell Hautfaarf',
    '🕵🏼' => 'Detektiv(in): mëttelhell Hautfaarf',
    '🕵🏽' => 'Detektiv(in): mëttel Hautfaarf',
    '🕵🏾' => 'Detektiv(in): mëtteldäischter Hautfaarf',
    '🕵🏿' => 'Detektiv(in): däischter Hautfaarf',
    '💂🏻' => 'Wiechter(in): hell Hautfaarf',
    '💂🏼' => 'Wiechter(in): mëttelhell Hautfaarf',
    '💂🏽' => 'Wiechter(in): mëttel Hautfaarf',
    '💂🏾' => 'Wiechter(in): mëtteldäischter Hautfaarf',
    '💂🏿' => 'Wiechter(in): däischter Hautfaarf',
    '👷🏻' => 'Bauaarbechter(in) mat Helm: hell Hautfaarf',
    '👷🏼' => 'Bauaarbechter(in) mat Helm: mëttelhell Hautfaarf',
    '👷🏽' => 'Bauaarbechter(in) mat Helm: mëttel Hautfaarf',
    '👷🏾' => 'Bauaarbechter(in) mat Helm: mëtteldäischter Hautfaarf',
    '👷🏿' => 'Bauaarbechter(in) mat Helm: däischter Hautfaarf',
    '🤴🏻' => 'Prënz: hell Hautfaarf',
    '🤴🏼' => 'Prënz: mëttelhell Hautfaarf',
    '🤴🏽' => 'Prënz: mëttel Hautfaarf',
    '🤴🏾' => 'Prënz: mëtteldäischter Hautfaarf',
    '🤴🏿' => 'Prënz: däischter Hautfaarf',
    '👸🏻' => 'Prinzessin: hell Hautfaarf',
    '👸🏼' => 'Prinzessin: mëttelhell Hautfaarf',
    '👸🏽' => 'Prinzessin: mëttel Hautfaarf',
    '👸🏾' => 'Prinzessin: mëtteldäischter Hautfaarf',
    '👸🏿' => 'Prinzessin: däischter Hautfaarf',
    '👳🏻' => 'Persoun mat Turban: hell Hautfaarf',
    '👳🏼' => 'Persoun mat Turban: mëttelhell Hautfaarf',
    '👳🏽' => 'Persoun mat Turban: mëttel Hautfaarf',
    '👳🏾' => 'Persoun mat Turban: mëtteldäischter Hautfaarf',
    '👳🏿' => 'Persoun mat Turban: däischter Hautfaarf',
    '👲🏻' => 'Mann mat chineseschem Hutt: hell Hautfaarf',
    '👲🏼' => 'Mann mat chineseschem Hutt: mëttelhell Hautfaarf',
    '👲🏽' => 'Mann mat chineseschem Hutt: mëttel Hautfaarf',
    '👲🏾' => 'Mann mat chineseschem Hutt: mëtteldäischter Hautfaarf',
    '👲🏿' => 'Mann mat chineseschem Hutt: däischter Hautfaarf',
    '🧕🏻' => 'Fra mat Schleier: hell Hautfaarf',
    '🧕🏼' => 'Fra mat Schleier: mëttelhell Hautfaarf',
    '🧕🏽' => 'Fra mat Schleier: mëttel Hautfaarf',
    '🧕🏾' => 'Fra mat Schleier: mëtteldäischter Hautfaarf',
    '🧕🏿' => 'Fra mat Schleier: däischter Hautfaarf',
    '🤵🏻' => 'Mann am Kostüm: hell Hautfaarf',
    '🤵🏼' => 'Mann am Kostüm: mëttelhell Hautfaarf',
    '🤵🏽' => 'Mann am Kostüm: mëttel Hautfaarf',
    '🤵🏾' => 'Mann am Kostüm: mëtteldäischter Hautfaarf',
    '🤵🏿' => 'Mann am Kostüm: däischter Hautfaarf',
    '👰🏻' => 'Braut mat Schleier: hell Hautfaarf',
    '👰🏼' => 'Braut mat Schleier: mëttelhell Hautfaarf',
    '👰🏽' => 'Braut mat Schleier: mëttel Hautfaarf',
    '👰🏾' => 'Braut mat Schleier: mëtteldäischter Hautfaarf',
    '👰🏿' => 'Braut mat Schleier: däischter Hautfaarf',
    '🤰🏻' => 'schwanger Fra: hell Hautfaarf',
    '🤰🏼' => 'schwanger Fra: mëttelhell Hautfaarf',
    '🤰🏽' => 'schwanger Fra: mëttel Hautfaarf',
    '🤰🏾' => 'schwanger Fra: mëtteldäischter Hautfaarf',
    '🤰🏿' => 'schwanger Fra: däischter Hautfaarf',
    '🤱🏻' => 'stëllend Fra: hell Hautfaarf',
    '🤱🏼' => 'stëllend Fra: mëttelhell Hautfaarf',
    '🤱🏽' => 'stëllend Fra: mëttel Hautfaarf',
    '🤱🏾' => 'stëllend Fra: mëtteldäischter Hautfaarf',
    '🤱🏿' => 'stëllend Fra: däischter Hautfaarf',
    '👼🏻' => 'Engelchen: hell Hautfaarf',
    '👼🏼' => 'Engelchen: mëttelhell Hautfaarf',
    '👼🏽' => 'Engelchen: mëttel Hautfaarf',
    '👼🏾' => 'Engelchen: mëtteldäischter Hautfaarf',
    '👼🏿' => 'Engelchen: däischter Hautfaarf',
    '🎅🏻' => 'Kleeschen: hell Hautfaarf',
    '🎅🏼' => 'Kleeschen: mëttelhell Hautfaarf',
    '🎅🏽' => 'Kleeschen: mëttel Hautfaarf',
    '🎅🏾' => 'Kleeschen: mëtteldäischter Hautfaarf',
    '🎅🏿' => 'Kleeschen: däischter Hautfaarf',
    '🤶🏻' => 'Dem Kleesche seng Fra: hell Hautfaarf',
    '🤶🏼' => 'Dem Kleesche seng Fra: mëttelhell Hautfaarf',
    '🤶🏽' => 'Dem Kleesche seng Fra: mëttel Hautfaarf',
    '🤶🏾' => 'Dem Kleesche seng Fra: mëtteldäischter Hautfaarf',
    '🤶🏿' => 'Dem Kleesche seng Fra: däischter Hautfaarf',
    '🧙🏻' => 'Zauberer(in): hell Hautfaarf',
    '🧙🏼' => 'Zauberer(in): mëttelhell Hautfaarf',
    '🧙🏽' => 'Zauberer(in): mëttel Hautfaarf',
    '🧙🏾' => 'Zauberer(in): mëtteldäischter Hautfaarf',
    '🧙🏿' => 'Zauberer(in): däischter Hautfaarf',
    '🧚🏻' => 'Fee: hell Hautfaarf',
    '🧚🏼' => 'Fee: mëttelhell Hautfaarf',
    '🧚🏽' => 'Fee: mëttel Hautfaarf',
    '🧚🏾' => 'Fee: mëtteldäischter Hautfaarf',
    '🧚🏿' => 'Fee: däischter Hautfaarf',
    '🧛🏻' => 'Vampir: hell Hautfaarf',
    '🧛🏼' => 'Vampir: mëttelhell Hautfaarf',
    '🧛🏽' => 'Vampir: mëttel Hautfaarf',
    '🧛🏾' => 'Vampir: mëtteldäischter Hautfaarf',
    '🧛🏿' => 'Vampir: däischter Hautfaarf',
    '🧜🏻' => 'Mierpersoun: hell Hautfaarf',
    '🧜🏼' => 'Mierpersoun: mëttelhell Hautfaarf',
    '🧜🏽' => 'Mierpersoun: mëttel Hautfaarf',
    '🧜🏾' => 'Mierpersoun: mëtteldäischter Hautfaarf',
    '🧜🏿' => 'Mierpersoun: däischter Hautfaarf',
    '🧝🏻' => 'Elf: hell Hautfaarf',
    '🧝🏼' => 'Elf: mëttelhell Hautfaarf',
    '🧝🏽' => 'Elf: mëttel Hautfaarf',
    '🧝🏾' => 'Elf: mëtteldäischter Hautfaarf',
    '🧝🏿' => 'Elf: däischter Hautfaarf',
    '💆🏻' => 'Persoun, déi eng Kappmassage kritt: hell Hautfaarf',
    '💆🏼' => 'Persoun, déi eng Kappmassage kritt: mëttelhell Hautfaarf',
    '💆🏽' => 'Persoun, déi eng Kappmassage kritt: mëttel Hautfaarf',
    '💆🏾' => 'Persoun, déi eng Kappmassage kritt: mëtteldäischter Hautfaarf',
    '💆🏿' => 'Persoun, déi eng Kappmassage kritt: däischter Hautfaarf',
    '💇🏻' => 'Persoun, déi d’Hoer geschnidde kritt: hell Hautfaarf',
    '💇🏼' => 'Persoun, déi d’Hoer geschnidde kritt: mëttelhell Hautfaarf',
    '💇🏽' => 'Persoun, déi d’Hoer geschnidde kritt: mëttel Hautfaarf',
    '💇🏾' => 'Persoun, déi d’Hoer geschnidde kritt: mëtteldäischter Hautfaarf',
    '💇🏿' => 'Persoun, déi d’Hoer geschnidde kritt: däischter Hautfaarf',
    '🚶🏻' => 'spadséierend Persoun: hell Hautfaarf',
    '🚶🏼' => 'spadséierend Persoun: mëttelhell Hautfaarf',
    '🚶🏽' => 'spadséierend Persoun: mëttel Hautfaarf',
    '🚶🏾' => 'spadséierend Persoun: mëtteldäischter Hautfaarf',
    '🚶🏿' => 'spadséierend Persoun: däischter Hautfaarf',
    '🏃🏻' => 'lafend Persoun: hell Hautfaarf',
    '🏃🏼' => 'lafend Persoun: mëttelhell Hautfaarf',
    '🏃🏽' => 'lafend Persoun: mëttel Hautfaarf',
    '🏃🏾' => 'lafend Persoun: mëtteldäischter Hautfaarf',
    '🏃🏿' => 'lafend Persoun: däischter Hautfaarf',
    '💃🏻' => 'danzend Fra: hell Hautfaarf',
    '💃🏼' => 'danzend Fra: mëttelhell Hautfaarf',
    '💃🏽' => 'danzend Fra: mëttel Hautfaarf',
    '💃🏾' => 'danzend Fra: mëtteldäischter Hautfaarf',
    '💃🏿' => 'danzend Fra: däischter Hautfaarf',
    '🕺🏻' => 'danzende Mann: hell Hautfaarf',
    '🕺🏼' => 'danzende Mann: mëttelhell Hautfaarf',
    '🕺🏽' => 'danzende Mann: mëttel Hautfaarf',
    '🕺🏾' => 'danzende Mann: mëtteldäischter Hautfaarf',
    '🕺🏿' => 'danzende Mann: däischter Hautfaarf',
    '🕴🏻' => 'levitéierende Man am Kostüm: hell Hautfaarf',
    '🕴🏼' => 'levitéierende Man am Kostüm: mëttelhell Hautfaarf',
    '🕴🏽' => 'levitéierende Man am Kostüm: mëttel Hautfaarf',
    '🕴🏾' => 'levitéierende Man am Kostüm: mëtteldäischter Hautfaarf',
    '🕴🏿' => 'levitéierende Man am Kostüm: däischter Hautfaarf',
    '👯🏻' => 'Persoun mat Huesoueren: hell Hautfaarf',
    '👯🏼' => 'Persoun mat Huesoueren: mëttelhell Hautfaarf',
    '👯🏽' => 'Persoun mat Huesoueren: mëttel Hautfaarf',
    '👯🏾' => 'Persoun mat Huesoueren: mëtteldäischter Hautfaarf',
    '👯🏿' => 'Persoun mat Huesoueren: däischter Hautfaarf',
    '🧖🏻' => 'Persoun am Dampbad: hell Hautfaarf',
    '🧖🏼' => 'Persoun am Dampbad: mëttelhell Hautfaarf',
    '🧖🏽' => 'Persoun am Dampbad: mëttel Hautfaarf',
    '🧖🏾' => 'Persoun am Dampbad: mëtteldäischter Hautfaarf',
    '🧖🏿' => 'Persoun am Dampbad: däischter Hautfaarf',
    '🧗🏻' => 'Klëmmer(in): hell Hautfaarf',
    '🧗🏼' => 'Klëmmer(in): mëttelhell Hautfaarf',
    '🧗🏽' => 'Klëmmer(in): mëttel Hautfaarf',
    '🧗🏾' => 'Klëmmer(in): mëtteldäischter Hautfaarf',
    '🧗🏿' => 'Klëmmer(in): däischter Hautfaarf',
    '🏇🏻' => 'Päerdscourse: hell Hautfaarf',
    '🏇🏼' => 'Päerdscourse: mëttelhell Hautfaarf',
    '🏇🏽' => 'Päerdscourse: mëttel Hautfaarf',
    '🏇🏾' => 'Päerdscourse: mëtteldäischter Hautfaarf',
    '🏇🏿' => 'Päerdscourse: däischter Hautfaarf',
    '🏂🏻' => 'Snowboarder: hell Hautfaarf',
    '🏂🏼' => 'Snowboarder: mëttelhell Hautfaarf',
    '🏂🏽' => 'Snowboarder: mëttel Hautfaarf',
    '🏂🏾' => 'Snowboarder: mëtteldäischter Hautfaarf',
    '🏂🏿' => 'Snowboarder: däischter Hautfaarf',
    '🏌🏻' => 'Golferspiller: hell Hautfaarf',
    '🏌🏼' => 'Golferspiller: mëttelhell Hautfaarf',
    '🏌🏽' => 'Golferspiller: mëttel Hautfaarf',
    '🏌🏾' => 'Golferspiller: mëtteldäischter Hautfaarf',
    '🏌🏿' => 'Golferspiller: däischter Hautfaarf',
    '🏄🏻' => 'Surfer(in): hell Hautfaarf',
    '🏄🏼' => 'Surfer(in): mëttelhell Hautfaarf',
    '🏄🏽' => 'Surfer(in): mëttel Hautfaarf',
    '🏄🏾' => 'Surfer(in): mëtteldäischter Hautfaarf',
    '🏄🏿' => 'Surfer(in): däischter Hautfaarf',
    '🚣🏻' => 'rudderend Persoun: hell Hautfaarf',
    '🚣🏼' => 'rudderend Persoun: mëttelhell Hautfaarf',
    '🚣🏽' => 'rudderend Persoun: mëttel Hautfaarf',
    '🚣🏾' => 'rudderend Persoun: mëtteldäischter Hautfaarf',
    '🚣🏿' => 'rudderend Persoun: däischter Hautfaarf',
    '🏊🏻' => 'Schwëmmer(in): hell Hautfaarf',
    '🏊🏼' => 'Schwëmmer(in): mëttelhell Hautfaarf',
    '🏊🏽' => 'Schwëmmer(in): mëttel Hautfaarf',
    '🏊🏾' => 'Schwëmmer(in): mëtteldäischter Hautfaarf',
    '🏊🏿' => 'Schwëmmer(in): däischter Hautfaarf',
    '⛹🏻' => 'mam Ball dribbelend Persoun: hell Hautfaarf',
    '⛹🏼' => 'mam Ball dribbelend Persoun: mëttelhell Hautfaarf',
    '⛹🏽' => 'mam Ball dribbelend Persoun: mëttel Hautfaarf',
    '⛹🏾' => 'mam Ball dribbelend Persoun: mëtteldäischter Hautfaarf',
    '⛹🏿' => 'mam Ball dribbelend Persoun: däischter Hautfaarf',
    '🏋🏻' => 'Gewiichthiewer(in): hell Hautfaarf',
    '🏋🏼' => 'Gewiichthiewer(in): mëttelhell Hautfaarf',
    '🏋🏽' => 'Gewiichthiewer(in): mëttel Hautfaarf',
    '🏋🏾' => 'Gewiichthiewer(in): mëtteldäischter Hautfaarf',
    '🏋🏿' => 'Gewiichthiewer(in): däischter Hautfaarf',
    '🚴🏻' => 'Vëlosfuerer(in): hell Hautfaarf',
    '🚴🏼' => 'Vëlosfuerer(in): mëttelhell Hautfaarf',
    '🚴🏽' => 'Vëlosfuerer(in): mëttel Hautfaarf',
    '🚴🏾' => 'Vëlosfuerer(in): mëtteldäischter Hautfaarf',
    '🚴🏿' => 'Vëlosfuerer(in): däischter Hautfaarf',
    '🚵🏻' => 'Mountainbikesfuerer(in): hell Hautfaarf',
    '🚵🏼' => 'Mountainbikesfuerer(in): mëttelhell Hautfaarf',
    '🚵🏽' => 'Mountainbikesfuerer(in): mëttel Hautfaarf',
    '🚵🏾' => 'Mountainbikesfuerer(in): mëtteldäischter Hautfaarf',
    '🚵🏿' => 'Mountainbikesfuerer(in): däischter Hautfaarf',
    '🤸🏻' => 'Persoun, déi d’Rad schléit: hell Hautfaarf',
    '🤸🏼' => 'Persoun, déi d’Rad schléit: mëttelhell Hautfaarf',
    '🤸🏽' => 'Persoun, déi d’Rad schléit: mëttel Hautfaarf',
    '🤸🏾' => 'Persoun, déi d’Rad schléit: mëtteldäischter Hautfaarf',
    '🤸🏿' => 'Persoun, déi d’Rad schléit: däischter Hautfaarf',
    '🤼🏻' => 'Wrestling: hell Hautfaarf',
    '🤼🏼' => 'Wrestling: mëttelhell Hautfaarf',
    '🤼🏽' => 'Wrestling: mëttel Hautfaarf',
    '🤼🏾' => 'Wrestling: mëtteldäischter Hautfaarf',
    '🤼🏿' => 'Wrestling: däischter Hautfaarf',
    '🤽🏻' => 'Waasserballspiller(in): hell Hautfaarf',
    '🤽🏼' => 'Waasserballspiller(in): mëttelhell Hautfaarf',
    '🤽🏽' => 'Waasserballspiller(in): mëttel Hautfaarf',
    '🤽🏾' => 'Waasserballspiller(in): mëtteldäischter Hautfaarf',
    '🤽🏿' => 'Waasserballspiller(in): däischter Hautfaarf',
    '🤾🏻' => 'Handballspiller(in): hell Hautfaarf',
    '🤾🏼' => 'Handballspiller(in): mëttelhell Hautfaarf',
    '🤾🏽' => 'Handballspiller(in): mëttel Hautfaarf',
    '🤾🏾' => 'Handballspiller(in): mëtteldäischter Hautfaarf',
    '🤾🏿' => 'Handballspiller(in): däischter Hautfaarf',
    '🤹🏻' => 'jongléierend Persoun: hell Hautfaarf',
    '🤹🏼' => 'jongléierend Persoun: mëttelhell Hautfaarf',
    '🤹🏽' => 'jongléierend Persoun: mëttel Hautfaarf',
    '🤹🏾' => 'jongléierend Persoun: mëtteldäischter Hautfaarf',
    '🤹🏿' => 'jongléierend Persoun: däischter Hautfaarf',
    '🧘🏻' => 'Persoun a Lotuspositioun: hell Hautfaarf',
    '🧘🏼' => 'Persoun a Lotuspositioun: mëttelhell Hautfaarf',
    '🧘🏽' => 'Persoun a Lotuspositioun: mëttel Hautfaarf',
    '🧘🏾' => 'Persoun a Lotuspositioun: mëtteldäischter Hautfaarf',
    '🧘🏿' => 'Persoun a Lotuspositioun: däischter Hautfaarf',
    '🛀🏻' => 'Persoun an der Bidden: hell Hautfaarf',
    '🛀🏼' => 'Persoun an der Bidden: mëttelhell Hautfaarf',
    '🛀🏽' => 'Persoun an der Bidden: mëttel Hautfaarf',
    '🛀🏾' => 'Persoun an der Bidden: mëtteldäischter Hautfaarf',
    '🛀🏿' => 'Persoun an der Bidden: däischter Hautfaarf',
    '🛌🏻' => 'Persoun am Bett: hell Hautfaarf',
    '🛌🏼' => 'Persoun am Bett: mëttelhell Hautfaarf',
    '🛌🏽' => 'Persoun am Bett: mëttel Hautfaarf',
    '🛌🏾' => 'Persoun am Bett: mëtteldäischter Hautfaarf',
    '🛌🏿' => 'Persoun am Bett: däischter Hautfaarf',
    '👭🏻' => 'zwou Fraen Hand an Hand: hell Hautfaarf',
    '👭🏼' => 'zwou Fraen Hand an Hand: mëttelhell Hautfaarf',
    '👭🏽' => 'zwou Fraen Hand an Hand: mëttel Hautfaarf',
    '👭🏾' => 'zwou Fraen Hand an Hand: mëtteldäischter Hautfaarf',
    '👭🏿' => 'zwou Fraen Hand an Hand: däischter Hautfaarf',
    '👫🏻' => 'Mann a Fra Hand an Hand: hell Hautfaarf',
    '👫🏼' => 'Mann a Fra Hand an Hand: mëttelhell Hautfaarf',
    '👫🏽' => 'Mann a Fra Hand an Hand: mëttel Hautfaarf',
    '👫🏾' => 'Mann a Fra Hand an Hand: mëtteldäischter Hautfaarf',
    '👫🏿' => 'Mann a Fra Hand an Hand: däischter Hautfaarf',
    '👬🏻' => 'zwee Männer Hand an Hand: hell Hautfaarf',
    '👬🏼' => 'zwee Männer Hand an Hand: mëttelhell Hautfaarf',
    '👬🏽' => 'zwee Männer Hand an Hand: mëttel Hautfaarf',
    '👬🏾' => 'zwee Männer Hand an Hand: mëtteldäischter Hautfaarf',
    '👬🏿' => 'zwee Männer Hand an Hand: däischter Hautfaarf',
    '💏🏻' => 'Kuss: hell Hautfaarf',
    '💏🏼' => 'Kuss: mëttelhell Hautfaarf',
    '💏🏽' => 'Kuss: mëttel Hautfaarf',
    '💏🏾' => 'Kuss: mëtteldäischter Hautfaarf',
    '💏🏿' => 'Kuss: däischter Hautfaarf',
    '💑🏻' => 'verléift Koppel: hell Hautfaarf',
    '💑🏼' => 'verléift Koppel: mëttelhell Hautfaarf',
    '💑🏽' => 'verléift Koppel: mëttel Hautfaarf',
    '💑🏾' => 'verléift Koppel: mëtteldäischter Hautfaarf',
    '💑🏿' => 'verléift Koppel: däischter Hautfaarf',
    '🏻' => 'hell Hautfaarf',
    '🏼' => 'mëttelhell Hautfaarf',
    '🏽' => 'mëttel Hautfaarf',
    '🏾' => 'mëtteldäischter Hautfaarf',
    '🏿' => 'däischter Hautfaarf',
    '😀' => 'Grinsgesiicht',
    '😃' => 'laachend Gesiicht mat oppenem Mond',
    '😄' => 'laachend Gesiicht mat oppenem Mond a laachenden Aen',
    '😁' => 'Grinsgesiicht mat laachenden Aen',
    '😆' => 'laachend Gesiicht mat oppenem Mond an zouen Aen',
    '😅' => 'laachend Gesiicht mat oppenem Mond a kalem Schweess',
    '🤣' => 'vu Laache rullend',
    '😂' => 'Gesiicht mat Freedtréinen',
    '🙂' => 'Gesiicht mat engem liichte Laachen',
    '🙃' => 'op der Kopp',
    '😉' => 'A zoudréckend',
    '😊' => 'laachend Gesiicht mat laachenden Aen',
    '😇' => 'laachend Gesiicht mat Hellegeschäin',
    '😍' => 'laachend Gesiicht mat Häerzeraen',
    '🤩' => 'Stärenaen',
    '😘' => 'e Kuss schéckend',
    '😗' => 'kussend',
    '☺' => 'laachend Gesiicht',
    '😚' => 'kussend mat zouen Aen',
    '😙' => 'kussend mat laachenden Aen',
    '😋' => 'gutt Iesse genéissend',
    '😛' => 'd’Zong erausstreckend',
    '😜' => 'd’Zong erausstreckend mat zougedrécktem A',
    '🤪' => 'verréckt Gesiicht',
    '😝' => 'd’Zong erausstreckend mat zouen Aen',
    '🤑' => 'geldgiereg',
    '🤗' => 'Ëmaarmung',
    '🤭' => 'Gesiicht mat Hand virum Mond',
    '🤫' => 'Gesiicht mam Fanger virum Mond',
    '🤔' => 'nodenklech',
    '🤐' => 'verschlossene Mond',
    '🤨' => 'Gesiicht mat gehuewenem Aperhoer',
    '😐' => 'neutraalt Gesiicht',
    '😑' => 'Gesiicht ouni Ausdrock',
    '😶' => 'Gesiicht ouni Mond',
    '😏' => 'schmunzelend',
    '😒' => 'onzefridden',
    '🙄' => 'Ae verdréinend',
    '😬' => 'Grimass schneidend Gesiicht',
    '🤥' => 'Ligenergesiicht',
    '😌' => 'erliichtert',
    '😔' => 'besuergt',
    '😪' => 'schléifreg',
    '🤤' => 'sabbelend Gesiicht',
    '😴' => 'ageschlof',
    '😷' => 'Gesiicht mat Doktersmask',
    '🤒' => 'Gesiicht mat Thermometer',
    '🤕' => 'Gesiicht mat Kappverband',
    '🤢' => 'iwwelt Gesiicht',
    '🤮' => 'Gesiicht wat sech iwwergëtt',
    '🤧' => 'néitsend Gesiicht',
    '😵' => 'schwindelegt Gesiicht',
    '🤯' => 'explodéierende Kapp',
    '🤠' => 'Gesiicht mat Cowboyshutt',
    '😎' => 'laachend Gesiicht mat Sonnebrëll',
    '🤓' => 'Nerd',
    '🧐' => 'Gesiicht mat Monokel',
    '😕' => 'konfus',
    '😟' => 'beonrouegt',
    '🙁' => 'd’Stir liicht fronzend',
    '☹' => 'd’Stir fronzend',
    '😮' => 'Gesiicht mat oppenem Mond',
    '😯' => 'flüsterend',
    '😲' => 'erstaunt',
    '😳' => 'rout ugelafent Gesiicht',
    '😦' => 'd’Stir fronzend Gesiicht mat oppenem Mond',
    '😧' => 'gequäält Gesiicht',
    '😨' => 'verängschtegt Gesiicht',
    '😰' => 'Gesiicht mat oppenem Mond a kalem Schweess',
    '😥' => 'enttäuscht mä erliichtert',
    '😢' => 'kräischend',
    '😭' => 'haart kräischend Gesiicht',
    '😱' => 'vun Angscht jäizend Gesiicht',
    '😖' => 'frustréiert',
    '😣' => 'duerhalend',
    '😞' => 'enttäuscht',
    '😓' => 'mat kalem Schweess eroflafend',
    '😩' => 'erschëpft Gesiicht',
    '😫' => 'midd',
    '😤' => 'mat Damp aus der Nues',
    '😡' => 'motzend Gesiicht',
    '😠' => 'rosent Gesiicht',
    '🤬' => 'Gesiicht mat Zeeche virum Mond',
    '😈' => 'laachend Gesiicht mat Haren',
    '👿' => 'rosent Gesiicht mat Haren',
    '💀' => 'Doudekapp',
    '☠' => 'Doudekapp a gekräizt Schanken',
    '💩' => 'Koup Schäiss',
    '🤡' => 'Clownegesiicht',
    '👹' => 'Ongeheier',
    '👺' => 'Kobold',
    '👻' => 'Geescht',
    '👽' => 'Alien',
    '👾' => 'Alienmonster',
    '🤖' => 'Roboter',
    '😺' => 'laachend Kazegesiicht mat oppenem Mond',
    '😸' => 'grinsend Kazegesiicht mat laachenden Aen',
    '😹' => 'Kazegesiicht mat Freedtréinen',
    '😻' => 'laachend Kazegesiicht mat Häerzeraen',
    '😼' => 'Kazegesiicht mat dreckegem Grinsen',
    '😽' => 'kussend Kazegesiicht mat zouen Aen',
    '🙀' => 'erschëpft Kazegesiicht',
    '😿' => 'kräischend Kazegesiicht',
    '😾' => 'motzend Kazegesiicht',
    '🙈' => 'Aen zouhalenden Af',
    '🙉' => 'Oueren zouhalenden Af',
    '🙊' => 'Mond zouhalenden Af',
    '💌' => 'Libesbréif',
    '💘' => 'Häerz mat Feil',
    '💝' => 'Häerz mat Putsch',
    '💖' => 'glënnerend Häerz',
    '💗' => 'wuessend Häerz',
    '💓' => 'klappend Häerz',
    '💞' => 'dréiend Häerzer',
    '💕' => 'zwee Häerzer',
    '💟' => 'Häerzdekoratioun',
    '❣' => 'fettgedréckt Häerzausruffzeechen',
    '💔' => 'gebrachent Häerz',
    '❤' => 'rout Häerz',
    '🧡' => 'oranget Häerz',
    '💛' => 'gielt Häerz',
    '💚' => 'gréngt Häerz',
    '💙' => 'blot Häerz',
    '💜' => 'mooft Häerz',
    '🖤' => 'schwaarzt Häerz',
    '💋' => 'Kussmond',
    '💯' => 'honnert Punkten',
    '💢' => 'Rosereiszeechen',
    '💥' => 'Kollisioun',
    '💫' => 'Schwindel',
    '💦' => 'Schweessdrëpsen',
    '💨' => 'séier fort',
    '🕳' => 'Lach',
    '💬' => 'Spriechblos',
    '🗨' => 'lénks Spriechblos',
    '🗯' => 'riets Rosereispriechblos',
    '💭' => 'Denkblos',
    '💤' => 'zzz',
    '👋' => 'wénkend Hand',
    '🤚' => 'héichgehalenen Handréck',
    '🖐' => 'gehuewen Hand mat ausgestreckte Fanger',
    '✋' => 'héichgehalen Hand',
    '🖖' => 'Vulcan-Grouss',
    '👌' => 'OK-Handzeechen',
    '✌' => 'Victoire-Handzeechen',
    '🤞' => 'gekräizt Fanger',
    '🤟' => 'Léift-Geste',
    '🤘' => 'Mano cornuta, Harenzeechen',
    '🤙' => 'Telefon-Handzeechen',
    '👈' => 'no lénks weisende Fanger vun hanne gesinn',
    '👉' => 'no riets weisende Fanger vun hanne gesinn',
    '👆' => 'no uewe weisende Fanger vun hanne gesinn',
    '🖕' => 'Mëttelfanger',
    '👇' => 'no ënne weisende Fanger vun hanne gesinn',
    '☝' => 'no uewe weisende Fanger',
    '👍' => 'Daum no uewen',
    '👎' => 'Daum no ënnen',
    '✊' => 'héichgehale Fauscht',
    '👊' => 'entgéintkommend Fauscht',
    '🤛' => 'lénksgeriicht Fauscht',
    '🤜' => 'rietsgeriicht Fauscht',
    '👏' => 'klappend Hänn',
    '🙌' => 'Hänn an d’Luucht',
    '👐' => 'oppen Hänn',
    '🤲' => 'zesummegefaalten Hänn',
    '🤝' => 'Handdrock',
    '🙏' => 'gefaalten Hänn',
    '✍' => 'schreiwend Hand',
    '💅' => 'Neellack',
    '🤳' => 'Selfie',
    '💪' => 'ugespaante Bizeps',
    '👂' => 'Ouer',
    '👃' => 'Nues',
    '🧠' => 'Gehir',
    '👀' => 'Aen',
    '👁' => 'A',
    '👅' => 'Zong',
    '👄' => 'Mond',
    '👶' => 'Puppelchen',
    '🧒' => 'Kand',
    '👦' => 'Jong',
    '👧' => 'Meedchen',
    '🧑' => 'Erwuessenen',
    '👱' => 'blond Persoun',
    '👨' => 'Mann',
    '🧔' => 'Persoun mat Baart',
    '👩' => 'Fra',
    '🧓' => 'eeleren Erwuessenen',
    '👴' => 'ale Mann',
    '👵' => 'al Fra',
    '🙍' => 'd’Stir fronzend Persoun',
    '🙎' => 'motzend Persoun',
    '🙅' => 'Persoun, déi NEEN weist',
    '🙆' => 'Persoun, déi OK weist',
    '💁' => 'Persoun, déi d’Hand op hält',
    '🙋' => 'Persoun, déi d’Hand hieft',
    '🙇' => 'sech vernäipend Persoun',
    '🤦' => 'Persoun, déi sech d’Hand widder de Kapp schléit',
    '🤷' => 'Persoun, déi d’Schëlleren hieft',
    '👮' => 'Polizist(in)',
    '🕵' => 'Detektiv(in)',
    '💂' => 'Wiechter(in)',
    '👷' => 'Bauaarbechter(in) mat Helm',
    '🤴' => 'Prënz',
    '👸' => 'Prinzessin',
    '👳' => 'Persoun mat Turban',
    '👲' => 'Mann mat chineseschem Hutt',
    '🧕' => 'Fra mat Schleier',
    '🤵' => 'Mann am Kostüm',
    '👰' => 'Braut mat Schleier',
    '🤰' => 'schwanger Fra',
    '🤱' => 'stëllend Fra',
    '👼' => 'Engelchen',
    '🎅' => 'Kleeschen',
    '🤶' => 'Dem Kleesche seng Fra',
    '🧙' => 'Zauberer(in)',
    '🧚' => 'Fee',
    '🧛' => 'Vampir',
    '🧜' => 'Mierpersoun',
    '🧝' => 'Elf',
    '🧞' => 'Genie',
    '🧟' => 'Zombie',
    '💆' => 'Persoun, déi eng Kappmassage kritt',
    '💇' => 'Persoun, déi d’Hoer geschnidde kritt',
    '🚶' => 'spadséierend Persoun',
    '🏃' => 'lafend Persoun',
    '💃' => 'danzend Fra',
    '🕺' => 'danzende Mann',
    '🕴' => 'levitéierende Man am Kostüm',
    '👯' => 'Persoun mat Huesoueren',
    '🧖' => 'Persoun am Dampbad',
    '🧗' => 'Klëmmer(in)',
    '🤺' => 'fechtend Persoun',
    '🏇' => 'Päerdscourse',
    '⛷' => 'Skifuerer',
    '🏂' => 'Snowboarder',
    '🏌' => 'Golferspiller',
    '🏄' => 'Surfer(in)',
    '🚣' => 'rudderend Persoun',
    '🏊' => 'Schwëmmer(in)',
    '⛹' => 'mam Ball dribbelend Persoun',
    '🏋' => 'Gewiichthiewer(in)',
    '🚴' => 'Vëlosfuerer(in)',
    '🚵' => 'Mountainbikesfuerer(in)',
    '🤸' => 'Persoun, déi d’Rad schléit',
    '🤼' => 'Wrestling',
    '🤽' => 'Waasserballspiller(in)',
    '🤾' => 'Handballspiller(in)',
    '🤹' => 'jongléierend Persoun',
    '🧘' => 'Persoun a Lotuspositioun',
    '🛀' => 'Persoun an der Bidden',
    '🛌' => 'Persoun am Bett',
    '👭' => 'zwou Fraen Hand an Hand',
    '👫' => 'Mann a Fra Hand an Hand',
    '👬' => 'zwee Männer Hand an Hand',
    '💏' => 'Kuss',
    '💑' => 'verléift Koppel',
    '🗣' => 'schwätzende Kapp',
    '👤' => 'mënschlech Silhouette',
    '👥' => 'mënschlech Silhouetten',
    '👪' => 'Famill',
    '👣' => 'Foussofdréck',
    '🐵' => 'Afegesiicht',
    '🐒' => 'Af',
    '🦍' => 'Gorilla',
    '🐶' => 'Hondsgesiicht',
    '🐕' => 'Hond',
    '🐩' => 'Puddel',
    '🐺' => 'Wollefsgesiicht',
    '🦊' => 'Fuussgesiicht',
    '🐱' => 'Kazegesiicht',
    '🐈' => 'Kaz',
    '🦁' => 'Léifsgesiicht',
    '🐯' => 'Tigersgesiicht',
    '🐅' => 'Tiger',
    '🐆' => 'Leopard',
    '🐴' => 'Päerdsgesiicht',
    '🐎' => 'Päerd',
    '🦄' => 'Einhornsgesiicht',
    '🦓' => 'Zebra',
    '🦌' => 'Hirsch',
    '🐮' => 'Kousgesiicht',
    '🐂' => 'Ochs',
    '🐃' => 'Waasserbüffel',
    '🐄' => 'Kou',
    '🐷' => 'Schwéngsgesiicht',
    '🐖' => 'Schwäin',
    '🐗' => 'Wëllschwäin',
    '🐽' => 'Schwéngsnues',
    '🐏' => 'Widder',
    '🐑' => 'Mudderschof',
    '🐐' => 'Geess',
    '🐪' => 'Dromedar',
    '🐫' => 'Kaméil',
    '🦒' => 'Giraff',
    '🐘' => 'Elefant',
    '🦏' => 'Nashorn',
    '🐭' => 'Mausgesiicht',
    '🐁' => 'Maus',
    '🐀' => 'Rat',
    '🐹' => 'Hamstersgesiicht',
    '🐰' => 'Huesgesiicht',
    '🐇' => 'Hues',
    '🐿' => 'Kaweechelchen',
    '🦔' => 'Kéiseker',
    '🦇' => 'Fliedermaus',
    '🐻' => 'Bieregesiicht',
    '🐨' => 'Koalabier',
    '🐼' => 'Pandasgesiicht',
    '🐾' => 'Pattenofdréck',
    '🦃' => 'Schnuddelhong',
    '🐔' => 'Hong',
    '🐓' => 'Hunn',
    '🐣' => 'Jippelchen am Ee',
    '🐤' => 'Jippelchen',
    '🐥' => 'Jippelche vu vir',
    '🐦' => 'Vugel',
    '🐧' => 'Pinguin',
    '🕊' => 'Dauf',
    '🦅' => 'Adler',
    '🦆' => 'Int',
    '🦉' => 'Eil',
    '🐸' => 'Fräschegesiicht',
    '🐊' => 'Krokodil',
    '🐢' => 'Deckelsmouk',
    '🦎' => 'Eidechs',
    '🐍' => 'Schlaang',
    '🐲' => 'Draachegesiicht',
    '🐉' => 'Draach',
    '🦕' => 'Dinosaurier',
    '🦖' => 'T-Rex',
    '🐳' => 'sprëtzende Wal',
    '🐋' => 'Wal',
    '🐬' => 'Delfin',
    '🐟' => 'Fësch',
    '🐠' => 'tropesche Fësch',
    '🐡' => 'Kugelfësch',
    '🦈' => 'Hai',
    '🐙' => 'Tëntefësch',
    '🐚' => 'Spiralmuschel',
    '🦀' => 'Kriibs',
    '🦐' => 'Crevette',
    '🦑' => 'Calamar',
    '🐌' => 'Schleek',
    '🦋' => 'Päiperlek',
    '🐛' => 'Kiewerlek',
    '🐜' => 'Seejomes',
    '🐝' => 'Bei',
    '🐞' => 'Himmelsdéierchen',
    '🦗' => 'Cricket',
    '🕷' => 'Spann',
    '🕸' => 'Spannennetz',
    '🦂' => 'Skorpioun',
    '💐' => 'Blummebouquet',
    '🌸' => 'Kiischtebléi',
    '💮' => 'wäiss Blumm',
    '🏵' => 'Rosett',
    '🌹' => 'Rous',
    '🥀' => 'verwielegt Blumm',
    '🌺' => 'Hibiskus',
    '🌻' => 'Sonneblumm',
    '🌼' => 'Margréitchen',
    '🌷' => 'Tulp',
    '🌱' => 'Keimling',
    '🌲' => 'Dännebam',
    '🌳' => 'Lafbam',
    '🌴' => 'Palm',
    '🌵' => 'Kaktus',
    '🌾' => 'Räishallem',
    '🌿' => 'Kräider',
    '☘' => 'Kléi',
    '🍀' => 'véierbliederegt Kléiblat',
    '🍁' => 'Ahornblat',
    '🍂' => 'Hierschtblat',
    '🍃' => 'am Wand fléiend Blat',
    '🍄' => 'Champignon',
    '🍇' => 'Drauwen',
    '🍈' => 'Meloun',
    '🍉' => 'Waassermeloun',
    '🍊' => 'Mandarine',
    '🍋' => 'Zitroun',
    '🍌' => 'Banann',
    '🍍' => 'Ananas',
    '🍎' => 'rouden Apel',
    '🍏' => 'gréngen Apel',
    '🍐' => 'Bir (Fruucht)',
    '🍑' => 'Piisch',
    '🍒' => 'Kiischten',
    '🍓' => 'Äerdbier',
    '🥝' => 'Kiwi',
    '🍅' => 'Tomat',
    '🥥' => 'Kokosnoss',
    '🥑' => 'Avocado',
    '🍆' => 'Aubergine',
    '🥔' => 'Gromper',
    '🥕' => 'Wuerzel',
    '🌽' => 'Mais',
    '🌶' => 'Peperoni',
    '🥒' => 'Kornischong',
    '🥦' => 'Brokkoli',
    '🥜' => 'Kakuett',
    '🌰' => 'Käscht',
    '🍞' => 'Brout',
    '🥐' => 'Croissant',
    '🥖' => 'Baguette',
    '🥨' => 'Bretzel',
    '🥞' => 'Paangecher',
    '🧀' => 'Stéck Kéis',
    '🍖' => 'Fleeschschank',
    '🍗' => 'Pouletssträmpel',
    '🥩' => 'Stéck Fleesch',
    '🥓' => 'Speck',
    '🍔' => 'Hamburger',
    '🍟' => 'Fritten',
    '🍕' => 'Pizza',
    '🌭' => 'Hot Dog',
    '🥪' => 'Sandwich',
    '🌮' => 'Taco',
    '🌯' => 'Burrito',
    '🥙' => 'Kebab',
    '🥚' => 'Ee',
    '🍳' => 'Pan mat Spigelee',
    '🥘' => 'Kasseroll mat Iessen',
    '🍲' => 'Plat an enger Kasseroll',
    '🥣' => 'Boll mat Läffel',
    '🥗' => 'gréng Zalot',
    '🍿' => 'Popcorn',
    '🥫' => 'Iessen an der Béchs',
    '🍱' => 'Bento-Box',
    '🍘' => 'Räiskichelcher',
    '🍙' => 'Räisball',
    '🍚' => 'gekachte Räis',
    '🍛' => 'Curry mat Räis',
    '🍜' => 'Schossel mat Nuddelen',
    '🍝' => 'Spagetti',
    '🍠' => 'Séissgromper',
    '🍢' => 'Oden',
    '🍣' => 'Sushi',
    '🍤' => 'Scampi-Tempura',
    '🍥' => 'gerullte Fëschkichelchen',
    '🍡' => 'Dango',
    '🥟' => 'Ravioli',
    '🥠' => 'Gléckskichelchen',
    '🥡' => 'Takeout-Këscht',
    '🍦' => 'Softice',
    '🍧' => 'Waasserglace',
    '🍨' => 'Glace',
    '🍩' => 'Donut',
    '🍪' => 'Kichelchen',
    '🎂' => 'Gebuertsdagskuch',
    '🍰' => 'Stéck Kuch',
    '🥧' => 'Taart',
    '🍫' => 'Tablett Schockela',
    '🍬' => 'Kamell',
    '🍭' => 'Lutsch',
    '🍮' => 'Pudding',
    '🍯' => 'Hunneg',
    '🍼' => 'Biberon',
    '🥛' => 'Glas Mëllech',
    '☕' => 'waarmt Gedrénks',
    '🍵' => 'Taass ouni Hänk',
    '🍶' => 'Sake',
    '🍾' => 'Fläsch mat knallendem Stopp',
    '🍷' => 'Wäiglas',
    '🍸' => 'Cocktailglas',
    '🍹' => 'exotescht Gedrénks',
    '🍺' => 'Klensch',
    '🍻' => 'prostend Béierklenschen',
    '🥂' => 'prostend Glieser',
    '🥃' => 'Whiskyglas',
    '🥤' => 'Glas mat Stréihallem',
    '🥢' => 'asiatesch Béngelen',
    '🍽' => 'Forschett a Messer mat Teller',
    '🍴' => 'Forschett a Messer',
    '🥄' => 'Läffel',
    '🔪' => 'Kichemesser',
    '🏺' => 'Amphore',
    '🌍' => 'Globus (zentréiert op Europa an Afrika)',
    '🌎' => 'Globus (zentréiert op Nord-/Südamerika)',
    '🌏' => 'Globus (zentréiert op Asien an Australien)',
    '🌐' => 'Meridianglobus',
    '🗺' => 'Weltkaart',
    '🗾' => 'Kaart vu Japan',
    '🏔' => 'mat Schnéi bedeckte Bierg',
    '⛰' => 'Bierg',
    '🌋' => 'Vulkan',
    '🗻' => 'Mount Fuji',
    '🏕' => 'Camping',
    '🏖' => 'Plage mat Sonneprabbeli',
    '🏜' => 'Wüst',
    '🏝' => 'Wüsteninsel',
    '🏞' => 'Nationalpark',
    '🏟' => 'Stadion',
    '🏛' => 'klassescht Gebai',
    '🏗' => 'Kran',
    '🏘' => 'Haiser',
    '🏚' => 'eidelt Haus',
    '🏠' => 'Haus',
    '🏡' => 'Haus mat Gaart',
    '🏢' => 'Bürosgebai',
    '🏣' => 'japanesche Postbüro',
    '🏤' => 'Postbüro',
    '🏥' => 'Spidol',
    '🏦' => 'Bank',
    '🏨' => 'Hotel',
    '🏩' => 'Love Hotel',
    '🏪' => 'Supermarché',
    '🏫' => 'Schoul',
    '🏬' => 'Akafszenter',
    '🏭' => 'Fabrik',
    '🏯' => 'japanescht Schlass',
    '🏰' => 'Schlass',
    '💒' => 'Hochzäit',
    '🗼' => 'Tokyo Tower',
    '🗽' => 'Fräiheetsstatu',
    '⛪' => 'Kierch',
    '🕌' => 'Moschee',
    '🕍' => 'Synagog',
    '⛩' => 'Shinto-Schräin',
    '🕋' => 'Kaaba',
    '⛲' => 'Sprangbuer',
    '⛺' => 'Zelt',
    '🌁' => 'niwweleg',
    '🌃' => 'Stärenhimmel',
    '🏙' => 'Stadlandschaft',
    '🌄' => 'Sonnenopgang an de Bierger',
    '🌅' => 'Sonnenopgang',
    '🌆' => 'Stad an der Dämmerung',
    '🌇' => 'Sonnenënnergang',
    '🌉' => 'Bréck nuets',
    '♨' => 'waarm Quellen',
    '🎠' => 'Karussellpäerdchen',
    '🎡' => 'Riserad',
    '🎢' => 'Achterbahn',
    '💈' => 'Coifferssail',
    '🎪' => 'Zirkuszelt',
    '🚂' => 'Lokomotiv',
    '🚃' => 'Zuchwaggon',
    '🚄' => 'Schnellzuch',
    '🚅' => 'Schnellzuch mat Fligernues',
    '🚆' => 'Zuch',
    '🚇' => 'Metro',
    '🚈' => 'Stadbunn',
    '🚉' => 'Haltestell',
    '🚊' => 'Tram',
    '🚝' => 'Monorail',
    '🚞' => 'Biergzuch',
    '🚋' => 'Tramwaggon',
    '🚌' => 'Bus',
    '🚍' => 'entgéintkommende Bus',
    '🚎' => 'Trolleybus',
    '🚐' => 'Minibus',
    '🚑' => 'Ambulanz',
    '🚒' => 'Pompjeeswon',
    '🚓' => 'Policeauto',
    '🚔' => 'entgéintkommende Policeauto',
    '🚕' => 'Taxi',
    '🚖' => 'entgéintkommenden Taxi',
    '🚗' => 'Auto',
    '🚘' => 'entgéintkommenden Auto',
    '🚙' => 'SUV',
    '🚚' => 'Liwwerwon',
    '🚛' => 'Sattelschlepper',
    '🚜' => 'Trakter',
    '🏎' => 'Courseauto',
    '🏍' => 'Motorrad',
    '🛵' => 'Scooter',
    '🚲' => 'Vëlo',
    '🛴' => 'Trottinette',
    '🚏' => 'Bushaltestell',
    '🛣' => 'Schnellstrooss',
    '🛤' => 'Schinnen',
    '🛢' => 'Uelegfaass',
    '⛽' => 'Tankstell',
    '🚨' => 'Gyrophar',
    '🚥' => 'horizontal rout Luucht',
    '🚦' => 'vertikal rout Luucht',
    '🛑' => 'Stoppschëld',
    '🚧' => 'Stroossebarrière',
    '⚓' => 'Anker',
    '⛵' => 'Segelboot',
    '🛶' => 'Kanu',
    '🚤' => 'Schnellboot',
    '🛳' => 'Passagéierschëff',
    '⛴' => 'Fähr',
    '🛥' => 'Motorboot',
    '🚢' => 'Schëff',
    '✈' => 'Fliger',
    '🛩' => 'klenge Fliger',
    '🛫' => 'Fligersdepart',
    '🛬' => 'Fligersarrivée',
    '💺' => 'Sëtz',
    '🚁' => 'Helikopter',
    '🚟' => 'Schwiefbunn',
    '🚠' => 'Biergseelbunn',
    '🚡' => 'Loftseelbunn',
    '🛰' => 'Satellit',
    '🚀' => 'Rakéit',
    '🛸' => 'UFO',
    '🛎' => 'Hotelpageschell',
    '⌛' => 'Sandauer',
    '⏳' => 'Sandauer mat lafendem Sand',
    '⌚' => 'Auer',
    '⏰' => 'Wecker',
    '⏱' => 'Stoppauer',
    '⏲' => 'Timer',
    '🕰' => 'Kamäinauer',
    '🕛' => 'zwielef Auer',
    '🕧' => 'hallwer eng',
    '🕐' => 'eng Auer',
    '🕜' => 'hallwer zwou',
    '🕑' => 'zwou Auer',
    '🕝' => 'hallwer dräi',
    '🕒' => 'dräi Auer',
    '🕞' => 'hallwer véier',
    '🕓' => 'véier Auer',
    '🕟' => 'hallwer fënnef',
    '🕔' => 'fënnef Auer',
    '🕠' => 'hallwer sechs',
    '🕕' => 'sechs Auer',
    '🕡' => 'hallwer siwen',
    '🕖' => 'siwen Auer',
    '🕢' => 'hallwer aacht',
    '🕗' => 'aacht Auer',
    '🕣' => 'hallwer néng',
    '🕘' => 'néng Auer',
    '🕤' => 'hallwer zéng',
    '🕙' => 'zéng Auer',
    '🕥' => 'hallwer eelef',
    '🕚' => 'eelef Auer',
    '🕦' => 'hallwer zwielef',
    '🌑' => 'Neimound',
    '🌒' => 'Séchelmound am éischte Véierel',
    '🌓' => 'zouhuelenden Hallefmound',
    '🌔' => 'Séchelmound am zweete Véierel',
    '🌕' => 'Vollmound',
    '🌖' => 'Séchelmound am drëtte Véierel',
    '🌗' => 'ofhuelenden Hallefmound',
    '🌘' => 'Séchelmound am leschte Véierel',
    '🌙' => 'Moundséchel',
    '🌚' => 'Neimoundgesiicht',
    '🌛' => 'zouhuelenden Hallefmoundgesiicht',
    '🌜' => 'ofhuelenden Hallefmoundgesiicht',
    '🌡' => 'Thermometer',
    '☀' => 'Sonn',
    '🌝' => 'Vollmoundgesiicht',
    '🌞' => 'Sonnegesiicht',
    '⭐' => 'mëttelgrousse wäisse Stär',
    '🌟' => 'liichtende Stär',
    '🌠' => 'Stäreschnäiz',
    '🌌' => 'Mëllechstrooss',
    '☁' => 'Wollek',
    '⛅' => 'Sonn hannert Wolleken',
    '⛈' => 'Wollek mat Blëtz a Reen',
    '🌤' => 'Sonn hannert kleng Wolleken',
    '🌥' => 'Sonn hannert grouss Wolleken',
    '🌦' => 'Sonn hannert Reewollek',
    '🌧' => 'Wollek mat Reen',
    '🌨' => 'Wollek mat Schnéi',
    '🌩' => 'Wollek mat Blëtz',
    '🌪' => 'Tornado',
    '🌫' => 'Niwwel',
    '🌬' => 'Wandgesiicht',
    '🌀' => 'Zyklon',
    '🌈' => 'Reebou',
    '🌂' => 'zoue Prabbeli',
    '☂' => 'Prabbeli',
    '☔' => 'Prabbeli mat Reendrëpsen',
    '⛱' => 'Prabbeli um Buedem',
    '⚡' => 'Héichspannung',
    '❄' => 'Schnéiflack',
    '☃' => 'Schnéimännchen',
    '⛄' => 'Schnéimännchen ouni Schnéi',
    '☄' => 'Komet',
    '🔥' => 'Feier',
    '💧' => 'Drëpschen',
    '🌊' => 'Waasserwell',
    '🎃' => 'Halloweenkürbis',
    '🎄' => 'Chrëschtbeemchen',
    '🎆' => 'Freedefeier',
    '🎇' => 'Späizmännchen',
    '✨' => 'fonkelend Stären',
    '🎈' => 'Ballon',
    '🎉' => 'Pochette-surprise',
    '🎊' => 'Konfettiball',
    '🎋' => 'Tanabata-Bam',
    '🎍' => 'Dännendekoratioun',
    '🎎' => 'Japanesch Poppen',
    '🎏' => 'Koi-Kaarpe-Fändelen',
    '🎐' => 'Wandspill',
    '🎑' => 'Moundbetruechtungszeremonie',
    '🎀' => 'Band',
    '🎁' => 'Kaddo',
    '🎗' => 'Commemoratiounsband',
    '🎟' => 'Entréesticket',
    '🎫' => 'Billjee',
    '🎖' => 'Militärmedail',
    '🏆' => 'Coupe',
    '🏅' => 'Sportsmedail',
    '🥇' => 'Goldmedail',
    '🥈' => 'Sëlwermedail',
    '🥉' => 'Bronzemedail',
    '⚽' => 'Fussball',
    '⚾' => 'Baseball',
    '🏀' => 'Basketball',
    '🏐' => 'Volleyball',
    '🏈' => 'American Football',
    '🏉' => 'Rugby',
    '🎾' => 'Tennis',
    '🎳' => 'Bowling',
    '🏏' => 'Cricketmatch',
    '🏑' => 'Feldhockey',
    '🏒' => 'Äishockey',
    '🏓' => 'Pingpong',
    '🏸' => 'Badminton',
    '🥊' => 'Boxhändchen',
    '🥋' => 'Kampfsportstenue',
    '🥅' => 'Goalnetz',
    '⛳' => 'Golflach mat Fändel',
    '⛸' => 'Schlittschong',
    '🎣' => 'Fëscheraangel',
    '🎽' => 'Laftricot',
    '🎿' => 'Skier',
    '🛷' => 'Schlitt',
    '🥌' => 'Curling-Steen',
    '🎯' => 'an d’Mëtt getraff',
    '🔫' => 'Pistoul',
    '🎱' => 'Billardkugel',
    '🔮' => 'Kristallkugel',
    '🎮' => 'Videospill',
    '🕹' => 'Joystick',
    '🎰' => 'Spillautomat',
    '🎲' => 'Spillwierfel',
    '♠' => 'Schëppen',
    '♥' => 'Häerzer',
    '♦' => 'Rauten',
    '♣' => 'Kräizer',
    '🃏' => 'Joker',
    '🀄' => 'Rouden Draach (Mahjong)',
    '🎴' => 'Spillkaarte mat Blummen',
    '🎭' => 'duerstellend Konscht',
    '🖼' => 'agerummt Bild',
    '🎨' => 'Faarfpalett',
    '👓' => 'Brëll',
    '🕶' => 'Sonnebrëll',
    '👔' => 'Krawatt',
    '👕' => 'T-Shirt',
    '👖' => 'Jeans',
    '🧣' => 'Schal',
    '🧤' => 'Händchen',
    '🧥' => 'Mantel',
    '🧦' => 'Strëmp',
    '👗' => 'Rack',
    '👘' => 'Kimono',
    '👙' => 'Bikini',
    '👚' => 'Fraekleedung',
    '👛' => 'Portmonni',
    '👜' => 'Posch',
    '👝' => 'Clutch',
    '🛍' => 'Akafstuten',
    '🎒' => 'Schoulsak',
    '👞' => 'Männerschong',
    '👟' => 'Lafschong',
    '👠' => 'Tallekeschong',
    '👡' => 'Fraesandal',
    '👢' => 'Fraestiwwel',
    '👑' => 'Kroun',
    '👒' => 'Fraenhutt',
    '🎩' => 'Zilinder',
    '🎓' => 'Diplomiwwerreechungshutt',
    '🧢' => 'Kap mat Bild',
    '⛑' => 'Rettungsdéngscht',
    '📿' => 'Rousekranz',
    '💄' => 'Lëppestëft',
    '💍' => 'Rank',
    '💎' => 'Diamant',
    '🔇' => 'Lautsprecher op lautlos',
    '🔈' => 'Lautsprecher op lues agestallt',
    '🔉' => 'Lautsprecher op mëttel agestallt',
    '🔊' => 'Lautsprecher op haart agestallt',
    '📢' => 'Lautsprecher',
    '📣' => 'Megafon',
    '📯' => 'Posttroter',
    '🔔' => 'Klack',
    '🔕' => 'duerchgestrache Klack',
    '🎼' => 'Partitioun',
    '🎵' => 'Museksnout',
    '🎶' => 'Museksnouten',
    '🎙' => 'Studiosmikro',
    '🎚' => 'Reegler',
    '🎛' => 'Steierungsknäppercher',
    '🎤' => 'Mikro',
    '🎧' => 'Kopfhörer',
    '📻' => 'Radio',
    '🎷' => 'Saxofon',
    '🎺' => 'Trompett',
    '🎸' => 'Gittar',
    '🎹' => 'Keyboard',
    '🎻' => 'Gei',
    '🥁' => 'Trommel',
    '📱' => 'Handy',
    '📲' => 'Handy mat feil',
    '☎' => 'Telefon',
    '📞' => 'Telefonshörer',
    '📟' => 'Pager',
    '📠' => 'Fax',
    '🔋' => 'Batterie',
    '🔌' => 'Stecker',
    '💻' => 'Laptop',
    '🖥' => 'Desktopcomputer',
    '🖨' => 'Drécker',
    '⌨' => 'Tastatur',
    '🖱' => 'Computermaus',
    '🖲' => 'Trackball',
    '💽' => 'Minidisk',
    '💾' => 'Diskett',
    '💿' => 'CD',
    '📀' => 'DVD',
    '🎥' => 'Kamera',
    '🎞' => 'Filmklappen',
    '📽' => 'Filmprojekter',
    '🎬' => 'Filmklapp',
    '📺' => 'Fernseh',
    '📷' => 'Fotoapparat',
    '📸' => 'Fotoapparat mat Blëtz',
    '📹' => 'Videokamera',
    '📼' => 'Videokassett',
    '🔍' => 'no lénks geriicht Lupp',
    '🔎' => 'no riets geriicht Lupp',
    '🕯' => 'Käerz',
    '💡' => 'Bir',
    '🔦' => 'Täscheluucht',
    '🏮' => 'roude Lampion',
    '📔' => 'dekoréierten Notizblock',
    '📕' => 'zouent Buch',
    '📖' => 'oppent Buch',
    '📗' => 'gréngt Buch',
    '📘' => 'blot Buch',
    '📙' => 'oranget Buch',
    '📚' => 'Bicher',
    '📓' => 'Notizblock',
    '📒' => 'Haaptbuch',
    '📃' => 'opgerullte Säit',
    '📜' => 'Schrëftrullo',
    '📄' => 'bedréckt Säit',
    '📰' => 'Zeitung',
    '🗞' => 'opgerullt Zeitung',
    '📑' => 'Lieszeechestickeren',
    '🔖' => 'Lieszeechen',
    '🏷' => 'Etikett',
    '💰' => 'Geldsak',
    '💴' => 'Yen',
    '💵' => 'Dollar',
    '💶' => 'Euro',
    '💷' => 'Pound',
    '💸' => 'Geldschäiner mat Flilleken',
    '💳' => 'Kreditkaart',
    '💹' => 'steigende Coursdiagramm mat Yen',
    '✉' => 'Enveloppe',
    '📧' => 'E-Mail',
    '📨' => 'antreffende Bréif',
    '📩' => 'Enveloppe mat Feil',
    '📤' => 'Fach fir erausgoend Post',
    '📥' => 'Fach fir erakommend Post',
    '📦' => 'Pak',
    '📫' => 'zoue Bréifkëscht mat Fändel no uewen',
    '📪' => 'zoue Bréifkëscht mat Fändel no ënnen',
    '📬' => 'oppe Bréifkëscht mat Fändel no uewen',
    '📭' => 'oppe Bréifkëscht mat Fändel no ënnen',
    '📮' => 'Bréifboîte',
    '🗳' => 'Urn mat Stëmmziedel',
    '✏' => 'Bläistëft',
    '✒' => 'schwaarz Fieder',
    '🖋' => 'Füllfieder',
    '🖊' => 'Bic',
    '🖌' => 'Pinsel',
    '🖍' => 'Faarf',
    '📝' => 'Memo',
    '💼' => 'Aktekoffer',
    '📁' => 'Fichiersdossier',
    '📂' => 'oppene Fichiersdossier',
    '🗂' => 'Intercalairen',
    '📅' => 'Kalenner',
    '📆' => 'Ofräisskalenner',
    '🗒' => 'Réngelchersnotizblock',
    '🗓' => 'Réngelcherskalenner',
    '📇' => 'Indexkaart',
    '📈' => 'steigenden Diagramm',
    '📉' => 'senkenden Diagramm',
    '📊' => 'Balkendiagramm',
    '📋' => 'Notizbriet',
    '📌' => 'Punaise',
    '📍' => 'ronn Punaise',
    '📎' => 'Bürosklamer',
    '🖇' => 'verbonne Bürosklameren',
    '📏' => 'Lineal',
    '📐' => 'Zeechendräieck',
    '✂' => 'Schéier',
    '🗃' => 'Fichierskëscht',
    '🗄' => 'Fichiersschaf',
    '🗑' => 'Dreckskëscht',
    '🔒' => 'zouent Schlass',
    '🔓' => 'oppent Schlass',
    '🔏' => 'zouent Schlass mat Bic',
    '🔐' => 'zouent Schlass mat Schlëssel',
    '🔑' => 'Schlëssel',
    '🗝' => 'ale Schlëssel',
    '🔨' => 'Hummer',
    '⛏' => 'Piosch',
    '⚒' => 'Hummer a Piosch',
    '🛠' => 'Hummer a Schrauweschlëssel',
    '🗡' => 'Dolch',
    '⚔' => 'gekräizt Schwäerter',
    '💣' => 'Bomm',
    '🏹' => 'Bou mat Feiler',
    '🛡' => 'Schëld',
    '🔧' => 'Schrauweschlëssel',
    '🔩' => 'Mudder a Schrauf',
    '⚙' => 'Zännrad',
    '🗜' => 'Schraufstack',
    '⚖' => 'Wo',
    '🔗' => 'Glidd',
    '⛓' => 'Ketten',
    '⚗' => 'Alembique',
    '🔬' => 'Mikroskop',
    '🔭' => 'Teleskop',
    '📡' => 'Satellittenantenn',
    '💉' => 'Sprëtz',
    '💊' => 'Pëll',
    '🚪' => 'Dier',
    '🛏' => 'Bett',
    '🛋' => 'Couche a Luucht',
    '🚽' => 'Toilett',
    '🚿' => 'Dusch',
    '🛁' => 'Buedbidden',
    '🛒' => 'Akafsweenchen',
    '🚬' => 'Zigarett',
    '⚰' => 'Sarg',
    '⚱' => 'Urn',
    '🗿' => 'Moai-Statu',
    '🏧' => 'Bancomat',
    '🚮' => 'Poubelleszeechen',
    '🚰' => 'Drénkwaasser',
    '♿' => 'Rollstullzeechen',
    '🚹' => 'Männertoilett',
    '🚺' => 'Fraentoilett',
    '🚻' => 'Toiletten',
    '🚼' => 'Bëbeeszeechen',
    '🚾' => 'WC-Zeechen',
    '🛂' => 'Passkontroll',
    '🛃' => 'Douane',
    '🛄' => 'Gepäckausgab',
    '🛅' => 'Gepäckschléissfach',
    '⚠' => 'Warnung',
    '🚸' => 'opgepasst Kanner',
    '⛔' => 'keen Accès',
    '🚫' => 'verbueden',
    '🚳' => 'keng Vëloen',
    '🚭' => 'Fëmme verbueden',
    '🚯' => 'keng Poubelle',
    '🚱' => 'keen Drénkwaasser',
    '🚷' => 'Foussgänger verbueden',
    '📵' => 'Handye verbueden',
    '🔞' => 'ënner uechzéng Joer verbueden',
    '☢' => 'radioaktiv',
    '☣' => 'Ëmweltgefor',
    '⬆' => 'Feil no uewen',
    '↗' => 'Feil no uewen a riets',
    '➡' => 'Feil no riets',
    '↘' => 'Feil no ënnen a riets',
    '⬇' => 'Feil no ënnen',
    '↙' => 'Feil no ënnen a lénks',
    '⬅' => 'Feil no lénks',
    '↖' => 'Feil no uewen a lénks',
    '↕' => 'Feil no uewen an ënnen',
    '↔' => 'Feil no lénks a riets',
    '↩' => 'Rietsfeil mat Lénkskéier',
    '↪' => 'Lénksfeil mat Rietskéier',
    '⤴' => 'Rietsfeil mat Kéier no uewen',
    '⤵' => 'Rietsfeil mat Kéier no ënnen',
    '🔃' => 'vertikal Feiler an Zärerichtung',
    '🔄' => 'vertikal Feiler géint Zärerichtung',
    '🔙' => 'ZERÉCK-Feil',
    '🔚' => 'ENN-Feil',
    '🔛' => 'UN!-Feil',
    '🔜' => 'GESCHWËNN-Feil',
    '🔝' => 'TOP-Feil',
    '🛐' => 'Gotteshaus',
    '⚛' => 'Atomzeechen',
    '🕉' => 'OM',
    '✡' => 'Davidstär',
    '☸' => 'Dharma-Rad',
    '☯' => 'Yin-Yang',
    '✝' => 'latäinescht Kräiz',
    '☦' => 'orthodoxt Kräiz',
    '☪' => 'Stär an Hallefmound',
    '☮' => 'Friddenszeechen',
    '🕎' => 'Menorah',
    '🔯' => 'sechszackege Stär mat Punkt an der Mëtt',
    '♈' => 'Widder (Stärzeechen)',
    '♉' => 'Stéier',
    '♊' => 'Zwilling',
    '♋' => 'Kriibs (Stärzeechen)',
    '♌' => 'Léif',
    '♍' => 'Jongfra',
    '♎' => 'Wo (Stärzeechen)',
    '♏' => 'Skorpioun (Stärzeechen)',
    '♐' => 'Schütze',
    '♑' => 'Steebock',
    '♒' => 'Waassermann',
    '♓' => 'Fësch (Stärzeechen)',
    '⛎' => 'Schlaangenträger (Ophiuchus)',
    '🔀' => 'Zoufallslecture-Knäppchen',
    '🔁' => 'Widderhuelknäppchen',
    '🔂' => 'Widderhuelknäppche fir ee Lidd',
    '▶' => 'Ofspillknäppchen',
    '⏩' => 'Schnellvirlafknäppchen',
    '⏭' => 'Knäppche „Nächst Lidd“',
    '⏯' => 'Ofspill- oder Pausknäppchen',
    '◀' => 'Récklafknäppchen',
    '⏪' => 'Schnellrécklafknäppchen',
    '⏮' => 'Knäppchen „Lescht Lidd“',
    '🔼' => 'Knäppchen „No uewen“',
    '⏫' => 'Knäppchen „Séier no uewen“',
    '🔽' => 'Knäppchen „No ënnen“',
    '⏬' => 'Knäppchen „Séier no ënnen“',
    '⏸' => 'Pausknäppchen',
    '⏹' => 'Stoppknäppchen',
    '⏺' => 'Opnamknäppchen',
    '⏏' => 'Auswerfknäppchen',
    '🎦' => 'Kino',
    '🔅' => 'Dimmerknäppchen',
    '🔆' => 'Ophellknäppchen',
    '📶' => 'Empfangbalken',
    '📳' => 'Vibratiounsmodus',
    '📴' => 'Handy aus',
    '♀' => 'weiblecht Zeechen',
    '♂' => 'männlecht Zeechen',
    '✖' => 'fettgedrécktent Multiplikatiounszeechen',
    '➕' => 'fettgedrécktent Pluszeechen',
    '➖' => 'fettgedrécktent Minuszeechen',
    '➗' => 'fettgedrécktent Divisiounszeechen',
    '‼' => 'duebelt Ausruffzeechen',
    '⁉' => 'Ausrufffragezeechen',
    '❓' => 'Fragezeechen',
    '❔' => 'wäisst Fragezeechen',
    '❕' => 'wäisst Ausruffzeechen',
    '❗' => 'Ausruffzeechen',
    '〰' => 'gewellte Stréch',
    '💱' => 'Wiesselcours',
    '💲' => 'déckt Dollarzeechen',
    '⚕' => 'medezinescht Symbol',
    '♻' => 'Recycling-Zeechen',
    '⚜' => 'Lilie',
    '🔱' => 'Dräizack',
    '📛' => 'Nummschëld',
    '🔰' => 'Ufängerzeechen (Japan)',
    '⭕' => 'groussen décke Krees',
    '✅' => 'fettgedréckte wäisse Kreepchen',
    '☑' => 'Urn mat Kreepchen',
    '✔' => 'fettgedréckte Kreepchen',
    '❌' => 'Kräizzeechen',
    '❎' => 'X-Knäppchen',
    '➰' => 'Schleef',
    '➿' => 'duebel Schleef',
    '〽' => 'Deelzeechen',
    '✳' => 'aachtzackege Stärchen',
    '✴' => 'aachtzackege Stär',
    '❇' => 'Fonken',
    '™' => 'Markenzeechen',
    '🔠' => 'Groussbuschtawen (Latäin)',
    '🔡' => 'Klengbuschtawen (Latäin)',
    '🔢' => 'Zueleneingab',
    '🔣' => 'Symbolereingab',
    '🔤' => 'Buschtaweneingab (Latäin)',
    '🅰' => 'A-Knäppchen (Bluttgrupp)',
    '🆎' => 'AB-Knäppchen (Bluttgrupp)',
    '🅱' => 'B-Knäppchen (Bluttgrupp)',
    '🆑' => 'CL-Knäppchen',
    '🆒' => 'COOL-Knäppchen',
    '🆓' => 'FRÄI-Knäppchen',
    'ℹ' => 'Informatioun',
    '🆔' => 'ID-Knäppchen',
    'Ⓜ' => 'agekreesten M',
    '🆕' => 'NEI-Knäppchen',
    '🆖' => 'NG-Knäppchen',
    '🅾' => 'O-Knäppchen (Bluttgrupp)',
    '🆗' => 'OK-Knäppchen',
    '🅿' => 'P-Knäppchen',
    '🆘' => 'SOS-Knäppchen',
    '🆙' => 'UP!-Knäppchen',
    '🆚' => 'VS-Knäppchen',
    '🈁' => 'japanesche Knäppchen ’hei’',
    '🈂' => 'japanesche Knäppchen ’Serviceännerung’',
    '🈷' => 'japanesche Knäppchen ’mountleche Betrag’',
    '🈶' => 'japanesche Knäppchen ’net gratis’',
    '🈯' => 'japanesche Knäppchen ’reservéiert’',
    '🉐' => 'japanesche Knäppchen ’Schnäppchen’',
    '🈹' => 'japanesche Knäppchen ’Rabatt’',
    '🈚' => 'japanesche Knäppchen ’gratis’',
    '🈲' => 'japanesche Knäppchen ’verbueden’',
    '🉑' => 'japanesche Knäppchen ’acceptabel’',
    '🈸' => 'japanesche Knäppchen ’Applikatioun’',
    '🈴' => 'japanesche Knäppchen ’Ofkommes’',
    '🈳' => 'japanesche Knäppchen ’fräi’',
    '㊗' => 'japanesche Knäppchen ’Gléckwënsch’',
    '㊙' => 'japanesche Knäppchen ’Geheimnis’',
    '🈺' => 'japanesche Knäppchen ’op fir Geschäfter’',
    '🈵' => 'japanesche Knäppchen ’net fräi’',
    '🔴' => 'roude Krees',
    '🔵' => 'bloe Krees',
    '⚫' => 'schwaarze Krees',
    '⚪' => 'wäisse Krees',
    '⬛' => 'schwaarze grousse Quadrat',
    '⬜' => 'wäisse grousse Quadrat',
    '◼' => 'mëttelgrousse schwaarze Quadrat',
    '◻' => 'mëttelgrousse wäisse Quadrat',
    '◾' => 'schwaarze mëttelklenge Quadrat',
    '◽' => 'wäisse mëttelklenge Quadrat',
    '▪' => 'klenge schwaarze Quadrat',
    '▫' => 'klenge wäisse Quadrat',
    '🔶' => 'grouss orange Raut',
    '🔷' => 'grouss blo Raut',
    '🔸' => 'kleng orange Raut',
    '🔹' => 'kleng blo Raut',
    '🔺' => 'rouden Dräieck mat der Spëtzt no uewen',
    '🔻' => 'rouden Dräieck mat der Spëtzt no ënnen',
    '💠' => 'Raut mat engem Punkt an der Mëtt',
    '🔘' => 'Optiounsknäppchen',
    '🔳' => 'wäisse véiereckege Knäppchen',
    '🔲' => 'schwaarze véiereckege Knäppchen',
    '🏁' => 'karéierte Fändel',
    '🚩' => 'dräieckege Fändel',
    '🎌' => 'gekräizt Fändelen',
    '🏴' => 'schwaarze Fändel',
    '🏳' => 'wäisse Fändel',
];
